#[non_exhaustive]pub enum Easing {
Show 35 variants
Linear,
EaseInQuad,
EaseOutQuad,
EaseInOutQuad,
EaseInCubic,
EaseOutCubic,
EaseInOutCubic,
EaseInQuart,
EaseOutQuart,
EaseInOutQuart,
EaseInQuint,
EaseOutQuint,
EaseInOutQuint,
EaseInSine,
EaseOutSine,
EaseInOutSine,
EaseInExpo,
EaseOutExpo,
EaseInOutExpo,
EaseInCirc,
EaseOutCirc,
EaseInOutCirc,
EaseInElastic,
EaseOutElastic,
EaseInOutElastic,
EaseInBack,
EaseOutBack,
EaseInOutBack,
EaseInBounce,
EaseOutBounce,
EaseInOutBounce,
Ease,
EaseIn,
EaseOut,
EaseInOut,
}Expand description
Describes the available easing functions for use with
TimedAnimation.
New values may be added to this enumeration over time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Linear
Linear tweening.
EaseInQuad
Quadratic tweening.
EaseOutQuad
Quadratic tweening, inverse of [enum@Adw.Easing.ease-in-quad].
EaseInOutQuad
Quadratic tweening, combining [enum@Adw.Easing.ease-in-quad] and [enum@Adw.Easing.ease-out-quad].
EaseInCubic
Cubic tweening.
EaseOutCubic
Cubic tweening, inverse of [enum@Adw.Easing.ease-in-cubic].
EaseInOutCubic
Cubic tweening, combining [enum@Adw.Easing.ease-in-cubic] and [enum@Adw.Easing.ease-out-cubic].
EaseInQuart
Quartic tweening.
EaseOutQuart
Quartic tweening, inverse of [enum@Adw.Easing.ease-in-quart].
EaseInOutQuart
Quartic tweening, combining [enum@Adw.Easing.ease-in-quart] and [enum@Adw.Easing.ease-out-quart].
EaseInQuint
Quintic tweening.
EaseOutQuint
Quintic tweening, inverse of [enum@Adw.Easing.ease-in-quint].
EaseInOutQuint
Quintic tweening, combining [enum@Adw.Easing.ease-in-quint] and [enum@Adw.Easing.ease-out-quint].
EaseInSine
Sine wave tweening.
EaseOutSine
Sine wave tweening, inverse of [enum@Adw.Easing.ease-in-sine].
EaseInOutSine
Sine wave tweening, combining [enum@Adw.Easing.ease-in-sine] and [enum@Adw.Easing.ease-out-sine].
EaseInExpo
Exponential tweening.
EaseOutExpo
Exponential tweening, inverse of [enum@Adw.Easing.ease-in-expo].
EaseInOutExpo
Exponential tweening, combining [enum@Adw.Easing.ease-in-expo] and [enum@Adw.Easing.ease-out-expo].
EaseInCirc
Circular tweening.
EaseOutCirc
Circular tweening, inverse of [enum@Adw.Easing.ease-in-circ].
EaseInOutCirc
Circular tweening, combining [enum@Adw.Easing.ease-in-circ] and [enum@Adw.Easing.ease-out-circ].
EaseInElastic
Elastic tweening, with offshoot on start.
EaseOutElastic
Elastic tweening, with offshoot on end, inverse of [enum@Adw.Easing.ease-in-elastic].
EaseInOutElastic
Elastic tweening, with offshoot on both ends, combining [enum@Adw.Easing.ease-in-elastic] and [enum@Adw.Easing.ease-out-elastic].
EaseInBack
Overshooting cubic tweening, with backtracking on start.
EaseOutBack
Overshooting cubic tweening, with backtracking on end, inverse of [enum@Adw.Easing.ease-in-back].
EaseInOutBack
Overshooting cubic tweening, with backtracking on both ends, combining [enum@Adw.Easing.ease-in-back] and [enum@Adw.Easing.ease-out-back].
EaseInBounce
Exponentially decaying parabolic (bounce) tweening, on start.
EaseOutBounce
Exponentially decaying parabolic (bounce) tweening, with bounce on end, inverse of [enum@Adw.Easing.ease-in-bounce].
EaseInOutBounce
Exponentially decaying parabolic (bounce) tweening, with bounce on both ends, combining [enum@Adw.Easing.ease-in-bounce] and [enum@Adw.Easing.ease-out-bounce].
Ease
v1_7 only.Cubic bezier tweening, with control points in (0.25, 0.1) and (0.25, 1.0).
Increases in velocity towards the middle of the animation, slowing back down at the end.
EaseIn
v1_7 only.Cubic bezier tweening, with control points in (0.42, 0.0) and (1.0, 1.0).
Starts off slowly, with the speed of the animation increasing until complete.
EaseOut
v1_7 only.Cubic bezier tweening, with control points in (0.0, 0.0) and (0.58, 1.0).
Starts quickly, slowing down the animation until complete.
EaseInOut
v1_7 only.Cubic bezier tweening, with control points in (0.42, 0.0) and (0.58, 1.0).
Starts off slowly, speeds up in the middle, and then slows down again.
Implementations