#[non_exhaustive]pub enum WrapPolicy {
Minimum,
Natural,
}Available on crate feature
v1_7 only.Expand description
Describes line wrapping behavior in a WrapLayout or WrapBox.
See wrap-policy and wrap-policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Minimum
Fit as many children into each line as possible, shrinking them down to their minimum size before wrapping to the next line.
Natural
Wrap to the next line as soon as the previous line cannot fit any more children without shrinking them past their natural size.