pub trait PreferencesPageExt: IsA<PreferencesPage> + 'static {
Show 25 methods
// Provided methods
fn add(&self, group: &impl IsA<PreferencesGroup>) { ... }
fn banner(&self) -> Option<Banner> { ... }
fn description(&self) -> GString { ... }
fn is_description_centered(&self) -> bool { ... }
fn group(&self, index: u32) -> Option<PreferencesGroup> { ... }
fn icon_name(&self) -> Option<GString> { ... }
fn name(&self) -> Option<GString> { ... }
fn title(&self) -> GString { ... }
fn uses_underline(&self) -> bool { ... }
fn insert(&self, group: &impl IsA<PreferencesGroup>, index: i32) { ... }
fn remove(&self, group: &impl IsA<PreferencesGroup>) { ... }
fn scroll_to_top(&self) { ... }
fn set_banner(&self, banner: Option<&Banner>) { ... }
fn set_description(&self, description: &str) { ... }
fn set_description_centered(&self, centered: bool) { ... }
fn set_icon_name(&self, icon_name: Option<&str>) { ... }
fn set_name(&self, name: Option<&str>) { ... }
fn set_title(&self, title: &str) { ... }
fn set_use_underline(&self, use_underline: bool) { ... }
fn connect_banner_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_description_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_description_centered_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_icon_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_use_underline_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn add(&self, group: &impl IsA<PreferencesGroup>)
fn add(&self, group: &impl IsA<PreferencesGroup>)
Available on crate feature v1_7 only.
v1_7 only.Sourcefn description(&self) -> GString
Available on crate feature v1_4 only.
fn description(&self) -> GString
v1_4 only.Sourcefn is_description_centered(&self) -> bool
Available on crate feature v1_6 only.
fn is_description_centered(&self) -> bool
v1_6 only.Sourcefn group(&self, index: u32) -> Option<PreferencesGroup>
Available on crate feature v1_8 only.
fn group(&self, index: u32) -> Option<PreferencesGroup>
v1_8 only.Sourcefn uses_underline(&self) -> bool
fn uses_underline(&self) -> bool
Gets whether an embedded underline in the title indicates a mnemonic.
Returns
whether an embedded underline in the title indicates a mnemonic
Sourcefn insert(&self, group: &impl IsA<PreferencesGroup>, index: i32)
Available on crate feature v1_8 only.
fn insert(&self, group: &impl IsA<PreferencesGroup>, index: i32)
v1_8 only.Sourcefn remove(&self, group: &impl IsA<PreferencesGroup>)
fn remove(&self, group: &impl IsA<PreferencesGroup>)
Sourcefn scroll_to_top(&self)
Available on crate feature v1_3 only.
fn scroll_to_top(&self)
v1_3 only.Scrolls the scrolled window of @self to the top.
Available on crate feature v1_7 only.
v1_7 only.Sets the banner displayed at the top of the page.
banner
the banner to display at the top of the page
Sourcefn set_description(&self, description: &str)
Available on crate feature v1_4 only.
fn set_description(&self, description: &str)
v1_4 only.Sets the description of @self.
The description is displayed at the top of the page.
description
the description
Sourcefn set_description_centered(&self, centered: bool)
Available on crate feature v1_6 only.
fn set_description_centered(&self, centered: bool)
v1_6 only.Sourcefn set_icon_name(&self, icon_name: Option<&str>)
fn set_icon_name(&self, icon_name: Option<&str>)
Sourcefn set_use_underline(&self, use_underline: bool)
fn set_use_underline(&self, use_underline: bool)
Sets whether an embedded underline in the title indicates a mnemonic.
use_underline
TRUE if underlines in the text indicate mnemonics
Available on crate feature
v1_7 only.fn connect_description_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Available on crate feature
v1_4 only.fn connect_description_centered_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Available on crate feature
v1_6 only.fn connect_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_title_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_use_underline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.