pub struct AboutDialog { /* private fields */ }v1_5 only.Expand description
A dialog showing information about the application.
an about dialog is typically opened when the user activates the About …
item in the application’s primary menu. All parts of the dialog are optional.
Main page
AboutDialog prominently displays the application’s icon, name, developer
name and version. They can be set with the application-icon,
application-name,
developer-name and version
respectively.
What’s New
AboutDialog provides a way for applications to display their release
notes, set with the release-notes property.
Release notes are formatted the same way as AppStream descriptions.
The supported formatting options are:
- Paragraph (
<p>) - Ordered list (
<ol>), with list items (<li>) - Unordered list (
<ul>), with list items (<li>)
Within paragraphs and list items, emphasis (<em>) and inline code
(<code>) text styles are supported. The emphasis is rendered in italic,
while inline code is shown in a monospaced font.
Any text outside paragraphs or list items is ignored.
Nested lists are not supported.
Only one version can be shown at a time. By default, the displayed version
number matches version. Use
release-notes-version to override it.
Details
The Details page displays the application comments and links.
The comments can be set with the comments property.
Unlike [comments][struct@crate::Gtk::AboutDialog#comments], this string can be long and
detailed. It can also contain links and Pango markup.
To set the application website, use website.
To add extra links below the website, use add_link().
If the Details page doesn’t have any other content besides website, the website will be displayed on the main page instead.
Troubleshooting
AboutDialog displays the following two links on the main page:
- Support Questions, set with the
support-urlproperty, - Report an Issue, set with the
issue-urlproperty.
Additionally, applications can provide debugging information. It will be
shown separately on the Troubleshooting page. Use the
debug-info property to specify it.
It’s intended to be attached to issue reports when reporting issues against the application. As such, it cannot contain markup or links.
AboutDialog provides a quick way to save debug information to a file.
When saving, debug-info-filename would be used as
the suggested filename.
Credits and Acknowledgements
The Credits page has the following default sections:
- Developers, set with the
developersproperty, - Designers, set with the
designersproperty, - Artists, set with the
artistsproperty, - Documenters, set with the
documentersproperty, - Translators, set with the
translator-creditsproperty.
When setting translator credits, use the strings "translator-credits" or
"translator_credits" and mark them as translatable.
The default sections that don’t contain any names won’t be displayed.
The Credits page can also contain an arbitrary number of extra sections below
the default ones. Use add_credit_section() to add them.
The Acknowledgements page can be used to acknowledge additional people and
organizations for their non-development contributions. Use
add_acknowledgement_section() to add sections to it. For
example, it can be used to list backers in a crowdfunded project or to give
special thanks.
Each of the people or organizations can have an email address or a website
specified. To add a email address, use a string like
Edgar Allan Poe <edgar@poe.com>. To specify a website with a title, use a
string like The GNOME Project https://www.gnome.org:
Legal
The Legal page displays the copyright and licensing information for the application and other modules.
The copyright string is set with the copyright
property and should be a short string of one or two lines, for example:
© 2022 Example.
Licensing information can be quickly set from a list of known licenses with
the license-type property. If the application’s
license is not in the list, license can be used
instead.
To add information about other modules, such as application dependencies or
data, use add_legal_section().
Other applications
AboutDialog can show links to your other apps at the end of the main
page. To add them, use add_other_app().
Constructing
To make constructing an AboutDialog as convenient as possible, you can
use the function show_about_dialog() which constructs and shows a
dialog.
⚠️ The following code is in c ⚠️
static void
show_about (GtkApplication *app)
{
const char *developers[] = {
"Angela Avery",
NULL
};
const char *designers[] = {
"GNOME Design Team",
NULL
};
adw_show_about_dialog (GTK_WIDGET (gtk_application_get_active_window (app)),
"application-name", _("Example"),
"application-icon", "org.example.App",
"version", "1.2.3",
"copyright", "© 2022 Angela Avery",
"issue-url", "https://gitlab.gnome.org/example/example/-/issues/",
"license-type", GTK_LICENSE_GPL_3_0,
"developers", developers,
"designers", designers,
"translator-credits", _("translator-credits"),
NULL);
}CSS nodes
AboutDialog has a main CSS node with the name dialog and the
style class .about.
Properties
application-icon
The name of the application icon.
The icon is displayed at the top of the main page.
Readable | Writeable
application-name
The name of the application.
The name is displayed at the top of the main page.
Readable | Writeable
artists
The list of artists of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersdocumenterstranslator-creditsAboutDialog::add_credit_section()AboutDialog::add_acknowledgement_section()
Readable | Writeable
comments
The comments about the application.
Comments will be shown on the Details page, above links.
Unlike [comments][struct@crate::Gtk::AboutDialog#comments], this string can be long and
detailed. It can also contain links and Pango markup.
Readable | Writeable
copyright
The copyright information.
This should be a short string of one or two lines, for example:
© 2022 Example.
The copyright information will be displayed on the Legal page, above the application license.
AboutDialog::add_legal_section() can be used to add copyright
information for the application dependencies or other components.
Readable | Writeable
debug-info
The debug information.
Debug information will be shown on the Troubleshooting page. It’s intended to be attached to issue reports when reporting issues against the application.
AboutDialog provides a quick way to save debug information to a file.
When saving, debug-info-filename would be used as
the suggested filename.
Debug information cannot contain markup or links.
Readable | Writeable
debug-info-filename
The debug information filename.
It will be used as the suggested filename when saving debug information to a file.
See debug-info.
Readable | Writeable
designers
The list of designers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersartistsdocumenterstranslator-creditsAboutDialog::add_credit_section()AboutDialog::add_acknowledgement_section()
Readable | Writeable
developer-name
The developer name.
The developer name is displayed on the main page, under the application name.
If the application is developed by multiple people, the developer name can
be set to values like “AppName team”, “AppName developers” or
“The AppName project”, and the individual contributors can be listed on the
Credits page, with developers and related
properties.
Readable | Writeable
developers
The list of developers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
designersartistsdocumenterstranslator-creditsAboutDialog::add_credit_section()AboutDialog::add_acknowledgement_section()
Readable | Writeable
documenters
The list of documenters of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersartiststranslator-creditsAboutDialog::add_credit_section()AboutDialog::add_acknowledgement_section()
Readable | Writeable
issue-url
The URL for the application’s issue tracker.
The issue tracker link is displayed on the main page.
Readable | Writeable
license
The license text.
This can be used to set a custom text for the license if it can’t be set
via license-type.
When set, license-type will be set to
GTK_LICENSE_CUSTOM.
The license text will be displayed on the Legal page, below the copyright information.
License text can contain Pango markup and links.
AboutDialog::add_legal_section() can be used to add license
information for the application dependencies or other components.
Readable | Writeable
license-type
The license type.
Allows to set the application’s license froma list of known licenses.
If the application’s license is not in the list,
license can be used instead. The license type will
be automatically set to GTK_LICENSE_CUSTOM in that case.
If set to GTK_LICENSE_UNKNOWN, no information will be displayed.
If the license type is different from GTK_LICENSE_CUSTOM.
license will be cleared out.
The license description will be displayed on the Legal page, below the copyright information.
AboutDialog::add_legal_section() can be used to add license
information for the application dependencies or other components.
Readable | Writeable
release-notes
The release notes of the application.
Release notes are displayed on the the What’s New page.
Release notes are formatted the same way as AppStream descriptions.
The supported formatting options are:
- Paragraph (
<p>) - Ordered list (
<ol>), with list items (<li>) - Unordered list (
<ul>), with list items (<li>)
Within paragraphs and list items, emphasis (<em>) and inline code
(<code>) text styles are supported. The emphasis is rendered in italic,
while inline code is shown in a monospaced font.
Any text outside paragraphs or list items is ignored.
Nested lists are not supported.
AboutDialog displays the version above the release notes. If set, the
release-notes-version of the property will be used
as the version; otherwise, version is used.
Readable | Writeable
release-notes-version
The version described by the application’s release notes.
The release notes version is displayed on the What’s New page, above the release notes.
If not set, version will be used instead.
For example, an application with the current version 2.0.2 might want to keep the release notes from 2.0.0, and set the release notes version accordingly.
See release-notes.
Readable | Writeable
support-url
The URL of the application’s support page.
The support page link is displayed on the main page.
Readable | Writeable
translator-credits
The translator credits string.
It will be displayed on the Credits page.
This string should be "translator-credits" or "translator_credits" and
should be marked as translatable.
The string may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersartistsdocumentersAboutDialog::add_credit_section()AboutDialog::add_acknowledgement_section()
Readable | Writeable
version
The version of the application.
The version is displayed on the main page.
If release-notes-version is not set, the version
will also be displayed above the release notes on the What’s New page.
Readable | Writeable
website
The URL of the application’s website.
Website is displayed on the Details page, below comments, or on the main page if the Details page doesn’t have any other content.
Applications can add other links below, see AboutDialog::add_link().
Readable | Writeable
Dialog
can-close
Whether the dialog can be closed.
If set to FALSE, the close button, shortcuts and
AdwDialogExt::close() will result in close-attempt being
emitted instead, and bottom sheet close swipe will be disabled.
AdwDialogExt::force_close() still works.
Readable | Writeable
child
The child widget of the Dialog.
Readable | Writeable
content-height
The height of the dialog’s contents.
Set it to -1 to reset it to the content’s natural height.
See also: default-height
Readable | Writeable
content-width
The width of the dialog’s contents.
Set it to -1 to reset it to the content’s natural width.
See also: default-width
Readable | Writeable
current-breakpoint
The current breakpoint.
Readable
default-widget
The default widget.
It’s activated when the user presses Enter.
Readable | Writeable
focus-widget
The focus widget.
Readable | Writeable
follows-content-size
Whether to size content automatically.
If set to TRUE, always use the content’s natural size instead of
content-width and content-height. If
the content resizes, the dialog will immediately resize as well.
See also: resizable
Readable | Writeable
presentation-mode
The dialog’s presentation mode.
When set to ADW_DIALOG_AUTO, the dialog appears as a bottom sheet when
the following condition is met: max-width: 450px or max-height: 360px,
and as a floating window otherwise.
Set it to ADW_DIALOG_FLOATING or ADW_DIALOG_BOTTOM_SHEET to always
present it a floating window or a bottom sheet respectively, regardless of
available size.
Presentation mode does nothing for dialogs presented as a window.
Readable | Writeable
title
The title of the dialog.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Signals
activate-link
Emitted when a URL is activated.
Applications may connect to it to override the default behavior, which is
to call show_uri().
Dialog
close-attempt
Emitted when the close button or shortcut is used, or
AdwDialogExt::close() is called while can-close is set to
FALSE.
closed
Emitted when the dialog is successfully closed.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
AdwDialogExt, gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, gtk::prelude::ShortcutManagerExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AboutDialog
impl AboutDialog
Sourcepub fn new() -> AboutDialog
pub fn new() -> AboutDialog
Sourcepub fn from_appdata(
resource_path: &str,
release_notes_version: Option<&str>,
) -> AboutDialog
Available on non-MSVC only.
pub fn from_appdata( resource_path: &str, release_notes_version: Option<&str>, ) -> AboutDialog
Creates a new AboutDialog using AppStream metadata.
This automatically sets the following properties with the following AppStream values:
application-iconis set from the<id>application-nameis set from the<name>developer-nameis set from the<name>within<developer>versionis set from the version of the latest releasewebsiteis set from the<url type="homepage">support-urlis set from the<url type="help">issue-urlis set from the<url type="bugtracker">license-typeis set from the<project_license>. If the license type retrieved from AppStream is not listed ingtk::License, it will be set toGTK_LICENCE_CUSTOM.
If @release_notes_version is not NULL,
release-notes-version is set to match it, while
release-notes is set from the AppStream release
description for that version.
resource_path
The resource to use
release_notes_version
The version to retrieve release notes for
Returns
the newly created AboutDialog
Sourcepub fn builder() -> AboutDialogBuilder
pub fn builder() -> AboutDialogBuilder
Creates a new builder-pattern struct instance to construct AboutDialog objects.
This method returns an instance of AboutDialogBuilder which can be used to create AboutDialog objects.
Sourcepub fn add_acknowledgement_section(&self, name: Option<&str>, people: &[&str])
pub fn add_acknowledgement_section(&self, name: Option<&str>, people: &[&str])
Adds a section to the Acknowledgements page.
This can be used to acknowledge additional people and organizations for their non-development contributions - for example, backers in a crowdfunded project.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
name
the section name
people
the list of names
Sourcepub fn add_credit_section(&self, name: Option<&str>, people: &[&str])
pub fn add_credit_section(&self, name: Option<&str>, people: &[&str])
Sourcepub fn add_legal_section(
&self,
title: &str,
copyright: Option<&str>,
license_type: License,
license: Option<&str>,
)
pub fn add_legal_section( &self, title: &str, copyright: Option<&str>, license_type: License, license: Option<&str>, )
Adds an extra section to the Legal page.
Extra sections will be displayed below the application’s own information.
The parameters @copyright, @license_type and @license will be used to present
the it the same way as copyright,
license-type and license are
for the application’s own information.
See those properties for more details.
This can be useful to attribute the application dependencies or data.
Examples:
⚠️ The following code is in c ⚠️
adw_about_dialog_add_legal_section (ADW_ABOUT_DIALOG (about),
_("Copyright and a known license"),
"© 2022 Example",
GTK_LICENSE_LGPL_2_1,
NULL);
adw_about_dialog_add_legal_section (ADW_ABOUT_DIALOG (about),
_("Copyright and custom license"),
"© 2022 Example",
GTK_LICENSE_CUSTOM,
"Custom license text");
adw_about_dialog_add_legal_section (ADW_ABOUT_DIALOG (about),
_("Copyright only"),
"© 2022 Example",
GTK_LICENSE_UNKNOWN,
NULL);
adw_about_dialog_add_legal_section (ADW_ABOUT_DIALOG (about),
_("Custom license only"),
NULL,
GTK_LICENSE_CUSTOM,
"Something completely custom here.");title
the name of the section
copyright
a copyright string
license_type
the type of license
license
custom license information
Sourcepub fn add_other_app(&self, appid: &str, name: &str, summary: &str)
Available on crate feature v1_7 only.
pub fn add_other_app(&self, appid: &str, name: &str, summary: &str)
v1_7 only.Adds another application to @self.
The application will be displayed at the bottom of the main page, in a separate section. Each added application will be presented as a row with @title and @summary, as well as an icon with the name @appid. Clicking the row will show @appid in the software center app.
This can be used to link to your other applications if you have multiple.
Example:
⚠️ The following code is in c ⚠️
adw_about_dialog_add_other_app (ADW_ABOUT_DIALOG (about),
"org.gnome.Boxes",
_("Boxes"),
_("Virtualization made simple"));appid
the application ID
name
the application name
summary
the application summary
Sourcepub fn application_icon(&self) -> GString
pub fn application_icon(&self) -> GString
Sourcepub fn application_name(&self) -> GString
pub fn application_name(&self) -> GString
Sourcepub fn debug_info(&self) -> GString
pub fn debug_info(&self) -> GString
Sourcepub fn debug_info_filename(&self) -> GString
pub fn debug_info_filename(&self) -> GString
Sourcepub fn developer_name(&self) -> GString
pub fn developer_name(&self) -> GString
Sourcepub fn developers(&self) -> Vec<GString>
pub fn developers(&self) -> Vec<GString>
Sourcepub fn documenters(&self) -> Vec<GString>
pub fn documenters(&self) -> Vec<GString>
Sourcepub fn license_type(&self) -> License
pub fn license_type(&self) -> License
Sourcepub fn release_notes(&self) -> GString
pub fn release_notes(&self) -> GString
Sourcepub fn release_notes_version(&self) -> GString
pub fn release_notes_version(&self) -> GString
Sourcepub fn support_url(&self) -> GString
pub fn support_url(&self) -> GString
Sourcepub fn translator_credits(&self) -> GString
pub fn translator_credits(&self) -> GString
Sourcepub fn set_application_icon(&self, application_icon: &str)
pub fn set_application_icon(&self, application_icon: &str)
Sets the name of the application icon for @self.
The icon is displayed at the top of the main page.
application_icon
the application icon name
Sourcepub fn set_application_name(&self, application_name: &str)
pub fn set_application_name(&self, application_name: &str)
Sets the application name for @self.
The name is displayed at the top of the main page.
application_name
the application name
Sourcepub fn set_artists(&self, artists: &[&str])
pub fn set_artists(&self, artists: &[&str])
Sets the list of artists of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersdocumenterstranslator-creditsadd_credit_section()add_acknowledgement_section()
artists
the list of artists
Sourcepub fn set_comments(&self, comments: &str)
pub fn set_comments(&self, comments: &str)
Sets the comments about the application.
Comments will be shown on the Details page, above links.
Unlike [comments][struct@crate::Gtk::AboutDialog#comments], this string can be long and
detailed. It can also contain links and Pango markup.
comments
the comments
Sourcepub fn set_copyright(&self, copyright: &str)
pub fn set_copyright(&self, copyright: &str)
Sets the copyright information for @self.
This should be a short string of one or two lines, for example:
© 2022 Example.
The copyright information will be displayed on the Legal page, before the application license.
add_legal_section() can be used to add copyright
information for the application dependencies or other components.
copyright
the copyright information
Sourcepub fn set_debug_info(&self, debug_info: &str)
pub fn set_debug_info(&self, debug_info: &str)
Sets the debug information for @self.
Debug information will be shown on the Troubleshooting page. It’s intended to be attached to issue reports when reporting issues against the application.
AboutDialog provides a quick way to save debug information to a file.
When saving, debug-info-filename would be used as
the suggested filename.
Debug information cannot contain markup or links.
debug_info
the debug information
Sourcepub fn set_debug_info_filename(&self, filename: &str)
pub fn set_debug_info_filename(&self, filename: &str)
Sets the debug information filename for @self.
It will be used as the suggested filename when saving debug information to a file.
See debug-info.
filename
the debug info filename
Sourcepub fn set_designers(&self, designers: &[&str])
pub fn set_designers(&self, designers: &[&str])
Sets the list of designers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersartistsdocumenterstranslator-creditsadd_credit_section()add_acknowledgement_section()
designers
the list of designers
Sourcepub fn set_developer_name(&self, developer_name: &str)
pub fn set_developer_name(&self, developer_name: &str)
Sets the developer name for @self.
The developer name is displayed on the main page, under the application name.
If the application is developed by multiple people, the developer name can be
set to values like “AppName team”, “AppName developers” or
“The AppName project”, and the individual contributors can be listed on the
Credits page, with developers and related properties.
developer_name
the developer name
Sourcepub fn set_developers(&self, developers: &[&str])
pub fn set_developers(&self, developers: &[&str])
Sets the list of developers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developers
the list of developers
Sourcepub fn set_documenters(&self, documenters: &[&str])
pub fn set_documenters(&self, documenters: &[&str])
Sets the list of documenters of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
documenters
the list of documenters
Sourcepub fn set_issue_url(&self, issue_url: &str)
pub fn set_issue_url(&self, issue_url: &str)
Sets the issue tracker URL for @self.
The issue tracker link is displayed on the main page.
issue_url
the issue tracker URL
Sourcepub fn set_license(&self, license: &str)
pub fn set_license(&self, license: &str)
Sets the license for @self.
This can be used to set a custom text for the license if it can’t be set via
license-type.
When set, license-type will be set to
GTK_LICENSE_CUSTOM.
The license text will be displayed on the Legal page, below the copyright information.
License text can contain Pango markup and links.
add_legal_section() can be used to add license information
for the application dependencies or other components.
license
the license
Sourcepub fn set_license_type(&self, license_type: License)
pub fn set_license_type(&self, license_type: License)
Sets the license for @self from a list of known licenses.
If the application’s license is not in the list,
license can be used instead. The license type will be
automatically set to GTK_LICENSE_CUSTOM in that case.
If @license_type is GTK_LICENSE_UNKNOWN, no information will be displayed.
If @license_type is different from GTK_LICENSE_CUSTOM.
license will be cleared out.
The license description will be displayed on the Legal page, below the copyright information.
add_legal_section() can be used to add license information
for the application dependencies or other components.
license_type
the license type
Sourcepub fn set_release_notes(&self, release_notes: &str)
pub fn set_release_notes(&self, release_notes: &str)
Sets the release notes for @self.
Release notes are displayed on the the What’s New page.
Release notes are formatted the same way as AppStream descriptions.
The supported formatting options are:
- Paragraph (
<p>) - Ordered list (
<ol>), with list items (<li>) - Unordered list (
<ul>), with list items (<li>)
Within paragraphs and list items, emphasis (<em>) and inline code
(<code>) text styles are supported. The emphasis is rendered in italic,
while inline code is shown in a monospaced font.
Any text outside paragraphs or list items is ignored.
Nested lists are not supported.
AboutDialog displays the version above the release notes. If set, the
release-notes-version of the property will be used
as the version; otherwise, version is used.
release_notes
the release notes
Sourcepub fn set_release_notes_version(&self, version: &str)
pub fn set_release_notes_version(&self, version: &str)
Sets the version described by the application’s release notes.
The release notes version is displayed on the What’s New page, above the release notes.
If not set, version will be used instead.
For example, an application with the current version 2.0.2 might want to keep the release notes from 2.0.0, and set the release notes version accordingly.
See release-notes.
version
the release notes version
Sourcepub fn set_support_url(&self, support_url: &str)
pub fn set_support_url(&self, support_url: &str)
Sets the URL of the support page for @self.
The support page link is displayed on the main page.
support_url
the support page URL
Sourcepub fn set_translator_credits(&self, translator_credits: &str)
pub fn set_translator_credits(&self, translator_credits: &str)
Sets the translator credits string.
It will be displayed on the Credits page.
This string should be "translator-credits" or "translator_credits" and
should be marked as translatable.
The string may contain email addresses and URLs, see the introduction for more details. When there is more than one translator, they must be separated by a newline in the same string.
See also:
translator_credits
the translator credits
Sourcepub fn set_version(&self, version: &str)
pub fn set_version(&self, version: &str)
Sets the version for @self.
The version is displayed on the main page.
If release-notes-version is not set, the version will
also be displayed above the release notes on the What’s New page.
version
the version
Sourcepub fn set_website(&self, website: &str)
pub fn set_website(&self, website: &str)
Sets the application website URL for @self.
Website is displayed on the Details page, below comments, or on the main page if the Details page doesn’t have any other content.
Applications can add other links below, see add_link().
website
the website URL
Sourcepub fn connect_activate_link<F: Fn(&Self, &str) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_activate_link<F: Fn(&Self, &str) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_application_icon_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_application_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_artists_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_comments_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_copyright_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_debug_info_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_debug_info_filename_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_designers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_developer_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_developers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_documenters_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_issue_url_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_license_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_license_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_release_notes_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_release_notes_version_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_support_url_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_translator_credits_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_version_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_website_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId