pub struct AboutWindow { /* private fields */ }Since 1.6
v1_2 only.Expand description
Use AboutDialog.
A window showing information about the application.
An about window is typically opened when the user activates the About …
item in the application’s primary menu. All parts of the window are optional.
Main page
AboutWindow prominently displays the application’s icon, name, developer
name and version. They can be set with the application-icon,
application-name,
developer-name and version
respectively.
What’s New
AboutWindow provides a way for applications to display their release
notes, set with the release-notes property.
Release notes are formatted the same way as AppStream descriptions.
The supported formatting options are:
- Paragraph (
<p>) - Ordered list (
<ol>), with list items (<li>) - Unordered list (
<ul>), with list items (<li>)
Within paragraphs and list items, emphasis (<em>) and inline code
(<code>) text styles are supported. The emphasis is rendered in italic,
while inline code is shown in a monospaced font.
Any text outside paragraphs or list items is ignored.
Nested lists are not supported.
Only one version can be shown at a time. By default, the displayed version
number matches version. Use
release-notes-version to override it.
Details
The Details page displays the application comments and links.
The comments can be set with the comments property.
Unlike [comments][struct@crate::Gtk::AboutDialog#comments], this string can be long and
detailed. It can also contain links and Pango markup.
To set the application website, use website.
To add extra links below the website, use add_link().
If the Details page doesn’t have any other content besides website, the website will be displayed on the main page instead.
Troubleshooting
AboutWindow displays the following two links on the main page:
- Support Questions, set with the
support-urlproperty, - Report an Issue, set with the
issue-urlproperty.
Additionally, applications can provide debugging information. It will be
shown separately on the Troubleshooting page. Use the
debug-info property to specify it.
It’s intended to be attached to issue reports when reporting issues against the application. As such, it cannot contain markup or links.
AboutWindow provides a quick way to save debug information to a file.
When saving, debug-info-filename would be used as
the suggested filename.
Credits and Acknowledgements
The Credits page has the following default sections:
- Developers, set with the
developersproperty, - Designers, set with the
designersproperty, - Artists, set with the
artistsproperty, - Documenters, set with the
documentersproperty, - Translators, set with the
translator-creditsproperty.
When setting translator credits, use the strings "translator-credits" or
"translator_credits" and mark them as translatable.
The default sections that don’t contain any names won’t be displayed.
The Credits page can also contain an arbitrary number of extra sections below
the default ones. Use add_credit_section() to add them.
The Acknowledgements page can be used to acknowledge additional people and
organizations for their non-development contributions. Use
add_acknowledgement_section() to add sections to it. For
example, it can be used to list backers in a crowdfunded project or to give
special thanks.
Each of the people or organizations can have an email address or a website
specified. To add a email address, use a string like
Edgar Allan Poe <edgar@poe.com>. To specify a website with a title, use a
string like The GNOME Project https://www.gnome.org:
Legal
The Legal page displays the copyright and licensing information for the application and other modules.
The copyright string is set with the copyright
property and should be a short string of one or two lines, for example:
© 2022 Example.
Licensing information can be quickly set from a list of known licenses with
the license-type property. If the application’s
license is not in the list, license can be used
instead.
To add information about other modules, such as application dependencies or
data, use add_legal_section().
Constructing
To make constructing an AboutWindow as convenient as possible, you can
use the function show_about_window() which constructs and shows a
window.
⚠️ The following code is in c ⚠️
static void
show_about (GtkApplication *app)
{
const char *developers[] = {
"Angela Avery",
NULL
};
const char *designers[] = {
"GNOME Design Team",
NULL
};
adw_show_about_window (gtk_application_get_active_window (app),
"application-name", _("Example"),
"application-icon", "org.example.App",
"version", "1.2.3",
"copyright", "© 2022 Angela Avery",
"issue-url", "https://gitlab.gnome.org/example/example/-/issues/",
"license-type", GTK_LICENSE_GPL_3_0,
"developers", developers,
"designers", designers,
"translator-credits", _("translator-credits"),
NULL);
}CSS nodes
AboutWindow has a main CSS node with the name window and the
style class .about.
Properties
application-icon
The name of the application icon.
The icon is displayed at the top of the main page.
Readable | Writeable
application-name
The name of the application.
The name is displayed at the top of the main page.
Readable | Writeable
artists
The list of artists of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersdocumenterstranslator-creditsAboutWindow::add_credit_section()AboutWindow::add_acknowledgement_section()
Readable | Writeable
comments
The comments about the application.
Comments will be shown on the Details page, above links.
Unlike [comments][struct@crate::Gtk::AboutDialog#comments], this string can be long and
detailed. It can also contain links and Pango markup.
Readable | Writeable
copyright
The copyright information.
This should be a short string of one or two lines, for example:
© 2022 Example.
The copyright information will be displayed on the Legal page, above the application license.
AboutWindow::add_legal_section() can be used to add copyright
information for the application dependencies or other components.
Readable | Writeable
debug-info
The debug information.
Debug information will be shown on the Troubleshooting page. It’s intended to be attached to issue reports when reporting issues against the application.
AboutWindow provides a quick way to save debug information to a file.
When saving, debug-info-filename would be used as
the suggested filename.
Debug information cannot contain markup or links.
Readable | Writeable
debug-info-filename
The debug information filename.
It will be used as the suggested filename when saving debug information to a file.
See debug-info.
Readable | Writeable
designers
The list of designers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersartistsdocumenterstranslator-creditsAboutWindow::add_credit_section()AboutWindow::add_acknowledgement_section()
Readable | Writeable
developer-name
The developer name.
The developer name is displayed on the main page, under the application name.
If the application is developed by multiple people, the developer name can
be set to values like “AppName team”, “AppName developers” or
“The AppName project”, and the individual contributors can be listed on the
Credits page, with developers and related
properties.
Readable | Writeable
developers
The list of developers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
designersartistsdocumenterstranslator-creditsAboutWindow::add_credit_section()AboutWindow::add_acknowledgement_section()
Readable | Writeable
documenters
The list of documenters of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersartiststranslator-creditsAboutWindow::add_credit_section()AboutWindow::add_acknowledgement_section()
Readable | Writeable
issue-url
The URL for the application’s issue tracker.
The issue tracker link is displayed on the main page.
Readable | Writeable
license
The license text.
This can be used to set a custom text for the license if it can’t be set
via license-type.
When set, license-type will be set to
[enum@Gtk.License.custom].
The license text will be displayed on the Legal page, below the copyright information.
License text can contain Pango markup and links.
AboutWindow::add_legal_section() can be used to add license
information for the application dependencies or other components.
Readable | Writeable
license-type
The license type.
Allows to set the application’s license froma list of known licenses.
If the application’s license is not in the list,
license can be used instead. The license type will
be automatically set to [enum@Gtk.License.custom] in that case.
If set to [enum@Gtk.License.unknown], no information will be displayed.
If the license type is different from [enum@Gtk.License.custom].
license will be cleared out.
The license description will be displayed on the Legal page, below the copyright information.
AboutWindow::add_legal_section() can be used to add license
information for the application dependencies or other components.
Readable | Writeable
release-notes
The release notes of the application.
Release notes are displayed on the the What’s New page.
Release notes are formatted the same way as AppStream descriptions.
The supported formatting options are:
- Paragraph (
<p>) - Ordered list (
<ol>), with list items (<li>) - Unordered list (
<ul>), with list items (<li>)
Within paragraphs and list items, emphasis (<em>) and inline code
(<code>) text styles are supported. The emphasis is rendered in italic,
while inline code is shown in a monospaced font.
Any text outside paragraphs or list items is ignored.
Nested lists are not supported.
AboutWindow displays the version above the release notes. If set, the
release-notes-version of the property will be used
as the version; otherwise, version is used.
Readable | Writeable
release-notes-version
The version described by the application’s release notes.
The release notes version is displayed on the What’s New page, above the release notes.
If not set, version will be used instead.
For example, an application with the current version 2.0.2 might want to keep the release notes from 2.0.0, and set the release notes version accordingly.
See release-notes.
Readable | Writeable
support-url
The URL of the application’s support page.
The support page link is displayed on the main page.
Readable | Writeable
translator-credits
The translator credits string.
It will be displayed on the Credits page.
This string should be "translator-credits" or "translator_credits" and
should be marked as translatable.
The string may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersartistsdocumentersAboutWindow::add_credit_section()AboutWindow::add_acknowledgement_section()
Readable | Writeable
version
The version of the application.
The version is displayed on the main page.
If release-notes-version is not set, the version
will also be displayed above the release notes on the What’s New page.
Readable | Writeable
website
The URL of the application’s website.
Website is displayed on the Details page, below comments, or on the main page if the Details page doesn’t have any other content.
Applications can add other links below, see AboutWindow::add_link().
Readable | Writeable
Window
adaptive-preview
Whether adaptive preview is currently open.
Adaptive preview is a debugging tool used for testing the window contents at specific screen sizes, simulating mobile environment.
Adaptive preview can always be accessed from inspector. This function allows applications to open it manually.
Most applications should not use this property.
Readable | Writeable
content
The content widget.
This property should always be used instead of child.
Readable | Writeable
current-breakpoint
The current breakpoint.
Readable
dialogs
The open dialogs.
Readable
visible-dialog
The currently visible dialog
Readable
Window
application
The gtk::Application associated with the window.
The application will be kept alive for at least as long as it has any windows associated with it (see g_application_hold() for a way to keep it alive without windows).
Normally, the connection between the application and the window
will remain until the window is destroyed, but you can explicitly
remove it by setting the this property to NULL.
Readable | Writeable
child
The child widget.
Readable | Writeable
decorated
Whether the window should have a frame (also known as decorations).
Readable | Writeable
default-height
The default height of the window.
Readable | Writeable
default-widget
The default widget.
Readable | Writeable
default-width
The default width of the window.
Readable | Writeable
deletable
Whether the window frame should have a close button.
Readable | Writeable
destroy-with-parent
If this window should be destroyed when the parent is destroyed.
Readable | Writeable
display
The display that will display this window.
Readable | Writeable
focus-visible
Whether ‘focus rectangles’ are currently visible in this window.
This property is maintained by GTK based on user input and should not be set by applications.
Readable | Writeable
focus-widget
The focus widget.
Readable | Writeable
fullscreened
Whether the window is fullscreen.
Setting this property is the equivalent of calling
[GtkWindowExtManual::fullscreen()][crate::gtk::prelude::GtkWindowExtManual::fullscreen()] or [GtkWindowExtManual::unfullscreen()][crate::gtk::prelude::GtkWindowExtManual::unfullscreen()];
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writeable
gravity
The gravity to use when resizing the window programmatically.
Gravity describes which point of the window we want to keep
fixed (meaning that the window will grow in the opposite direction).
For example, a gravity of GTK_WINDOW_GRAVITY_TOP_RIGHT means that we
want the to fix top right corner of the window.
Readable | Writeable
handle-menubar-accel
Whether the window frame should handle F10 for activating menubars.
Readable | Writeable
hide-on-close
If this window should be hidden instead of destroyed when the user clicks the close button.
Readable | Writeable
icon-name
Specifies the name of the themed icon to use as the window icon.
See Gtk::IconTheme for more details.
Readable | Writeable
is-active
Whether the toplevel is the currently active window.
Readable
maximized
Whether the window is maximized.
Setting this property is the equivalent of calling
[GtkWindowExtManual::maximize()][crate::gtk::prelude::GtkWindowExtManual::maximize()] or [GtkWindowExtManual::unmaximize()][crate::gtk::prelude::GtkWindowExtManual::unmaximize()];
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writeable
mnemonics-visible
Whether mnemonics are currently visible in this window.
This property is maintained by GTK based on user input, and should not be set by applications.
Readable | Writeable
modal
If true, the window is modal.
Readable | Writeable
resizable
If true, users can resize the window.
Readable | Writeable
startup-id
A write-only property for setting window’s startup notification identifier.
Writeable
suspended
Whether the window is suspended.
See [GtkWindowExtManual::is_suspended()][crate::gtk::prelude::GtkWindowExtManual::is_suspended()] for details about what suspended means.
Readable
title
The title of the window.
Readable | Writeable
titlebar
The titlebar widget.
Readable | Writeable
transient-for
The transient parent of the window.
Readable | Writeable | Construct
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Signals
activate-link
Emitted when a URL is activated.
Applications may connect to it to override the default behavior, which is
to call show_uri().
Window
activate-default
Emitted when the user activates the default widget.
This is a keybinding signal.
The keybindings for this signal are all forms of the Enter key.
Action
activate-focus
Emitted when the user activates the currently focused widget of @window.
This is a keybinding signal.
The default binding for this signal is ␣.
Action
close-request
Emitted when the user clicks on the close button of the window.
enable-debugging
Emitted when the user enables or disables interactive debugging.
When @toggle is true, interactive debugging is toggled on or off, when it is false, the debugger will be pointed at the widget under the pointer.
This is a keybinding signal.
The default bindings for this signal are Ctrl+Shift+I and Ctrl+Shift+D.
Action
force-close
Emitted when the compositor has decided to eliminate a window.
@window has to be in a hidden state after this signal was handled.
keys-changed
Emitted when the set of accelerators or mnemonics that are associated with the window changes.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
AdwWindowExt, gtk::prelude::GtkWindowExt, gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, gtk::prelude::NativeExt, gtk::prelude::RootExt, gtk::prelude::ShortcutManagerExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl AboutWindow
impl AboutWindow
Sourcepub fn new() -> AboutWindow
👎Deprecated: Since 1.6
pub fn new() -> AboutWindow
Since 1.6
Creates a new AboutWindow.
Deprecated since 1.6
Use AboutDialog.
Returns
the newly created AboutWindow
Sourcepub fn from_appdata(
resource_path: &str,
release_notes_version: Option<&str>,
) -> AboutWindow
👎Deprecated: Since 1.6
Available on crate feature v1_4 and non-MSVC only.
pub fn from_appdata( resource_path: &str, release_notes_version: Option<&str>, ) -> AboutWindow
Since 1.6
v1_4 and non-MSVC only.Creates a new AboutWindow using AppStream metadata.
This automatically sets the following properties with the following AppStream values:
application-iconis set from the<id>application-nameis set from the<name>developer-nameis set from the<name>within<developer>versionis set from the version of the latest releasewebsiteis set from the<url type="homepage">support-urlis set from the<url type="help">issue-urlis set from the<url type="bugtracker">license-typeis set from the<project_license>. If the license type retrieved from AppStream is not listed ingtk::License, it will be set to [enum@Gtk.License.custom].
If @release_notes_version is not NULL,
release-notes-version is set to match it, while
release-notes is set from the AppStream release
description for that version.
Deprecated since 1.6
Use AboutDialog.
resource_path
The resource to use
release_notes_version
The version to retrieve release notes for
Returns
the newly created AboutWindow
Sourcepub fn builder() -> AboutWindowBuilder
👎Deprecated: Since 1.6
pub fn builder() -> AboutWindowBuilder
Since 1.6
Creates a new builder-pattern struct instance to construct AboutWindow objects.
This method returns an instance of AboutWindowBuilder which can be used to create AboutWindow objects.
Sourcepub fn add_acknowledgement_section(&self, name: Option<&str>, people: &[&str])
👎Deprecated: Since 1.6
pub fn add_acknowledgement_section(&self, name: Option<&str>, people: &[&str])
Since 1.6
Adds a section to the Acknowledgements page.
This can be used to acknowledge additional people and organizations for their non-development contributions - for example, backers in a crowdfunded project.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
Deprecated since 1.6
Use AboutDialog.
name
the section name
people
the list of names
Sourcepub fn add_credit_section(&self, name: Option<&str>, people: &[&str])
👎Deprecated: Since 1.6
pub fn add_credit_section(&self, name: Option<&str>, people: &[&str])
Since 1.6
Adds an extra section to the Credits page.
Extra sections are displayed below the standard categories.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
Deprecated since 1.6
Use AboutDialog.
name
the section name
people
the list of names
Sourcepub fn add_legal_section(
&self,
title: &str,
copyright: Option<&str>,
license_type: License,
license: Option<&str>,
)
👎Deprecated: Since 1.6
pub fn add_legal_section( &self, title: &str, copyright: Option<&str>, license_type: License, license: Option<&str>, )
Since 1.6
Adds an extra section to the Legal page.
Extra sections will be displayed below the application’s own information.
The parameters @copyright, @license_type and @license will be used to present
the it the same way as copyright,
license-type and license are
for the application’s own information.
See those properties for more details.
This can be useful to attribute the application dependencies or data.
Examples:
⚠️ The following code is in c ⚠️
adw_about_window_add_legal_section (ADW_ABOUT_WINDOW (about),
_("Copyright and a known license"),
"© 2022 Example",
GTK_LICENSE_LGPL_2_1,
NULL);
adw_about_window_add_legal_section (ADW_ABOUT_WINDOW (about),
_("Copyright and custom license"),
"© 2022 Example",
GTK_LICENSE_CUSTOM,
"Custom license text");
adw_about_window_add_legal_section (ADW_ABOUT_WINDOW (about),
_("Copyright only"),
"© 2022 Example",
GTK_LICENSE_UNKNOWN,
NULL);
adw_about_window_add_legal_section (ADW_ABOUT_WINDOW (about),
_("Custom license only"),
NULL,
GTK_LICENSE_CUSTOM,
"Something completely custom here.");Deprecated since 1.6
Use AboutDialog.
title
the name of the section
copyright
a copyright string
license_type
the type of license
license
custom license information
Sourcepub fn add_link(&self, title: &str, url: &str)
👎Deprecated: Since 1.6
pub fn add_link(&self, title: &str, url: &str)
Since 1.6
Adds an extra link to the Details page.
Extra links are displayed under the comment and website.
Underlines in @title will be interpreted as indicating a mnemonic.
See website.
Deprecated since 1.6
Use AboutDialog.
title
the link title
url
the link URL
Sourcepub fn application_icon(&self) -> GString
👎Deprecated: Since 1.6
pub fn application_icon(&self) -> GString
Since 1.6
Gets the name of the application icon for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the application icon name
Sourcepub fn application_name(&self) -> GString
👎Deprecated: Since 1.6
pub fn application_name(&self) -> GString
Since 1.6
Gets the application name for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the application name
Sourcepub fn artists(&self) -> Vec<GString>
👎Deprecated: Since 1.6
pub fn artists(&self) -> Vec<GString>
Since 1.6
Gets the list of artists of the application.
Deprecated since 1.6
Use AboutDialog.
Returns
The list of artists
Sourcepub fn comments(&self) -> GString
👎Deprecated: Since 1.6
pub fn comments(&self) -> GString
Since 1.6
Gets the comments about the application.
Deprecated since 1.6
Use AboutDialog.
Returns
the comments
Sourcepub fn copyright(&self) -> GString
👎Deprecated: Since 1.6
pub fn copyright(&self) -> GString
Since 1.6
Gets the copyright information for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the copyright information
Sourcepub fn debug_info(&self) -> GString
👎Deprecated: Since 1.6
pub fn debug_info(&self) -> GString
Since 1.6
Gets the debug information for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the debug information
Sourcepub fn debug_info_filename(&self) -> GString
👎Deprecated: Since 1.6
pub fn debug_info_filename(&self) -> GString
Since 1.6
Gets the debug information filename for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the debug information filename
Sourcepub fn designers(&self) -> Vec<GString>
👎Deprecated: Since 1.6
pub fn designers(&self) -> Vec<GString>
Since 1.6
Gets the list of designers of the application.
Deprecated since 1.6
Use AboutDialog.
Returns
The list of designers
Sourcepub fn developer_name(&self) -> GString
👎Deprecated: Since 1.6
pub fn developer_name(&self) -> GString
Since 1.6
Gets the developer name for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the developer_name
Sourcepub fn developers(&self) -> Vec<GString>
👎Deprecated: Since 1.6
pub fn developers(&self) -> Vec<GString>
Since 1.6
Gets the list of developers of the application.
Deprecated since 1.6
Use AboutDialog.
Returns
The list of developers
Sourcepub fn documenters(&self) -> Vec<GString>
👎Deprecated: Since 1.6
pub fn documenters(&self) -> Vec<GString>
Since 1.6
Gets the list of documenters of the application.
Deprecated since 1.6
Use AboutDialog.
Returns
The list of documenters
Sourcepub fn issue_url(&self) -> GString
👎Deprecated: Since 1.6
pub fn issue_url(&self) -> GString
Since 1.6
Gets the issue tracker URL for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the issue tracker URL
Sourcepub fn license_type(&self) -> License
👎Deprecated: Since 1.6
pub fn license_type(&self) -> License
Since 1.6
Sourcepub fn release_notes(&self) -> GString
👎Deprecated: Since 1.6
pub fn release_notes(&self) -> GString
Since 1.6
Sourcepub fn release_notes_version(&self) -> GString
👎Deprecated: Since 1.6
pub fn release_notes_version(&self) -> GString
Since 1.6
Gets the version described by the application’s release notes.
Deprecated since 1.6
Use AboutDialog.
Returns
the release notes version
Sourcepub fn support_url(&self) -> GString
👎Deprecated: Since 1.6
pub fn support_url(&self) -> GString
Since 1.6
Gets the URL of the support page for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the support page URL
Sourcepub fn translator_credits(&self) -> GString
👎Deprecated: Since 1.6
pub fn translator_credits(&self) -> GString
Since 1.6
Gets the translator credits string.
Deprecated since 1.6
Use AboutDialog.
Returns
The translator credits string
Sourcepub fn website(&self) -> GString
👎Deprecated: Since 1.6
pub fn website(&self) -> GString
Since 1.6
Gets the application website URL for @self.
Deprecated since 1.6
Use AboutDialog.
Returns
the website URL
Sourcepub fn set_application_icon(&self, application_icon: &str)
👎Deprecated: Since 1.6
pub fn set_application_icon(&self, application_icon: &str)
Since 1.6
Sets the name of the application icon for @self.
The icon is displayed at the top of the main page.
Deprecated since 1.6
Use AboutDialog.
application_icon
the application icon name
Sourcepub fn set_application_name(&self, application_name: &str)
👎Deprecated: Since 1.6
pub fn set_application_name(&self, application_name: &str)
Since 1.6
Sets the application name for @self.
The name is displayed at the top of the main page.
Deprecated since 1.6
Use AboutDialog.
application_name
the application name
Sourcepub fn set_artists(&self, artists: &[&str])
👎Deprecated: Since 1.6
pub fn set_artists(&self, artists: &[&str])
Since 1.6
Sets the list of artists of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersdesignersdocumenterstranslator-creditsadd_credit_section()add_acknowledgement_section()
Deprecated since 1.6
Use AboutDialog.
artists
the list of artists
Sourcepub fn set_comments(&self, comments: &str)
👎Deprecated: Since 1.6
pub fn set_comments(&self, comments: &str)
Since 1.6
Sets the comments about the application.
Comments will be shown on the Details page, above links.
Unlike [comments][struct@crate::Gtk::AboutDialog#comments], this string can be long and
detailed. It can also contain links and Pango markup.
Deprecated since 1.6
Use AboutDialog.
comments
the comments
Sourcepub fn set_copyright(&self, copyright: &str)
👎Deprecated: Since 1.6
pub fn set_copyright(&self, copyright: &str)
Since 1.6
Sets the copyright information for @self.
This should be a short string of one or two lines, for example:
© 2022 Example.
The copyright information will be displayed on the Legal page, before the application license.
add_legal_section() can be used to add copyright
information for the application dependencies or other components.
Deprecated since 1.6
Use AboutDialog.
copyright
the copyright information
Sourcepub fn set_debug_info(&self, debug_info: &str)
👎Deprecated: Since 1.6
pub fn set_debug_info(&self, debug_info: &str)
Since 1.6
Sets the debug information for @self.
Debug information will be shown on the Troubleshooting page. It’s intended to be attached to issue reports when reporting issues against the application.
AboutWindow provides a quick way to save debug information to a file.
When saving, debug-info-filename would be used as
the suggested filename.
Debug information cannot contain markup or links.
Deprecated since 1.6
Use AboutDialog.
debug_info
the debug information
Sourcepub fn set_debug_info_filename(&self, filename: &str)
👎Deprecated: Since 1.6
pub fn set_debug_info_filename(&self, filename: &str)
Since 1.6
Sets the debug information filename for @self.
It will be used as the suggested filename when saving debug information to a file.
See debug-info.
Deprecated since 1.6
Use AboutDialog.
filename
the debug info filename
Sourcepub fn set_designers(&self, designers: &[&str])
👎Deprecated: Since 1.6
pub fn set_designers(&self, designers: &[&str])
Since 1.6
Sets the list of designers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
developersartistsdocumenterstranslator-creditsadd_credit_section()add_acknowledgement_section()
Deprecated since 1.6
Use AboutDialog.
designers
the list of designers
Sourcepub fn set_developer_name(&self, developer_name: &str)
👎Deprecated: Since 1.6
pub fn set_developer_name(&self, developer_name: &str)
Since 1.6
Sets the developer name for @self.
The developer name is displayed on the main page, under the application name.
If the application is developed by multiple people, the developer name can be
set to values like “AppName team”, “AppName developers” or
“The AppName project”, and the individual contributors can be listed on the
Credits page, with developers and related properties.
Deprecated since 1.6
Use AboutDialog.
developer_name
the developer name
Sourcepub fn set_developers(&self, developers: &[&str])
👎Deprecated: Since 1.6
pub fn set_developers(&self, developers: &[&str])
Since 1.6
Sets the list of developers of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
Deprecated since 1.6
Use AboutDialog.
developers
the list of developers
Sourcepub fn set_documenters(&self, documenters: &[&str])
👎Deprecated: Since 1.6
pub fn set_documenters(&self, documenters: &[&str])
Since 1.6
Sets the list of documenters of the application.
It will be displayed on the Credits page.
Each name may contain email addresses and URLs, see the introduction for more details.
See also:
Deprecated since 1.6
Use AboutDialog.
documenters
the list of documenters
Sourcepub fn set_issue_url(&self, issue_url: &str)
👎Deprecated: Since 1.6
pub fn set_issue_url(&self, issue_url: &str)
Since 1.6
Sets the issue tracker URL for @self.
The issue tracker link is displayed on the main page.
Deprecated since 1.6
Use AboutDialog.
issue_url
the issue tracker URL
Sourcepub fn set_license(&self, license: &str)
👎Deprecated: Since 1.6
pub fn set_license(&self, license: &str)
Since 1.6
Sets the license for @self.
This can be used to set a custom text for the license if it can’t be set via
license-type.
When set, license-type will be set to
[enum@Gtk.License.custom].
The license text will be displayed on the Legal page, below the copyright information.
License text can contain Pango markup and links.
add_legal_section() can be used to add license information
for the application dependencies or other components.
Deprecated since 1.6
Use AboutDialog.
license
the license
Sourcepub fn set_license_type(&self, license_type: License)
👎Deprecated: Since 1.6
pub fn set_license_type(&self, license_type: License)
Since 1.6
Sets the license for @self from a list of known licenses.
If the application’s license is not in the list,
license can be used instead. The license type will be
automatically set to [enum@Gtk.License.custom] in that case.
If @license_type is [enum@Gtk.License.unknown], no information will be displayed.
If @license_type is different from [enum@Gtk.License.custom].
license will be cleared out.
The license description will be displayed on the Legal page, below the copyright information.
add_legal_section() can be used to add license information
for the application dependencies or other components.
Deprecated since 1.6
Use AboutDialog.
license_type
the license type
Sourcepub fn set_release_notes(&self, release_notes: &str)
👎Deprecated: Since 1.6
pub fn set_release_notes(&self, release_notes: &str)
Since 1.6
Sets the release notes for @self.
Release notes are displayed on the the What’s New page.
Release notes are formatted the same way as AppStream descriptions.
The supported formatting options are:
- Paragraph (
<p>) - Ordered list (
<ol>), with list items (<li>) - Unordered list (
<ul>), with list items (<li>)
Within paragraphs and list items, emphasis (<em>) and inline code
(<code>) text styles are supported. The emphasis is rendered in italic,
while inline code is shown in a monospaced font.
Any text outside paragraphs or list items is ignored.
Nested lists are not supported.
AboutWindow displays the version above the release notes. If set, the
release-notes-version of the property will be used
as the version; otherwise, version is used.
Deprecated since 1.6
Use AboutDialog.
release_notes
the release notes
Sourcepub fn set_release_notes_version(&self, version: &str)
👎Deprecated: Since 1.6
pub fn set_release_notes_version(&self, version: &str)
Since 1.6
Sets the version described by the application’s release notes.
The release notes version is displayed on the What’s New page, above the release notes.
If not set, version will be used instead.
For example, an application with the current version 2.0.2 might want to keep the release notes from 2.0.0, and set the release notes version accordingly.
See release-notes.
Deprecated since 1.6
Use AboutDialog.
version
the release notes version
Sourcepub fn set_support_url(&self, support_url: &str)
👎Deprecated: Since 1.6
pub fn set_support_url(&self, support_url: &str)
Since 1.6
Sets the URL of the support page for @self.
The support page link is displayed on the main page.
Deprecated since 1.6
Use AboutDialog.
support_url
the support page URL
Sourcepub fn set_translator_credits(&self, translator_credits: &str)
👎Deprecated: Since 1.6
pub fn set_translator_credits(&self, translator_credits: &str)
Since 1.6
Sets the translator credits string.
It will be displayed on the Credits page.
This string should be "translator-credits" or "translator_credits" and
should be marked as translatable.
The string may contain email addresses and URLs, see the introduction for more details. When there is more than one translator, they must be separated by a newline in the same string.
See also:
Deprecated since 1.6
Use AboutDialog.
translator_credits
the translator credits
Sourcepub fn set_version(&self, version: &str)
👎Deprecated: Since 1.6
pub fn set_version(&self, version: &str)
Since 1.6
Sets the version for @self.
The version is displayed on the main page.
If release-notes-version is not set, the version will
also be displayed above the release notes on the What’s New page.
Deprecated since 1.6
Use AboutDialog.
version
the version
Sourcepub fn set_website(&self, website: &str)
👎Deprecated: Since 1.6
pub fn set_website(&self, website: &str)
Since 1.6
Sets the application website URL for @self.
Website is displayed on the Details page, below comments, or on the main page if the Details page doesn’t have any other content.
Applications can add other links below, see add_link().
Deprecated since 1.6
Use AboutDialog.
website
the website URL
Sourcepub fn connect_activate_link<F: Fn(&Self, &str) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
👎Deprecated: Since 1.6
pub fn connect_activate_link<F: Fn(&Self, &str) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
Emitted when a URL is activated.
Applications may connect to it to override the default behavior, which is
to call show_uri().
Deprecated since 1.6
Use AboutDialog.
uri
the URI to activate
Returns
TRUE if the link has been activated
pub fn connect_application_icon_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_application_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_artists_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_comments_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_copyright_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_debug_info_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_debug_info_filename_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_designers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_developer_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_developers_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_documenters_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_issue_url_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_license_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_license_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_release_notes_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_release_notes_version_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_support_url_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_translator_credits_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_version_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6
pub fn connect_website_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.6