pub struct Avatar { /* private fields */ }Expand description
A widget displaying an image, with a generated fallback.
Avatar is a widget that shows a round avatar.
Avatar generates an avatar with the initials of the
text on top of a colored background.
The color is picked based on the hash of the text.
If show-initials is set to FALSE,
icon-name or avatar-default-symbolic is shown instead of
the initials.
Use custom-image to set a custom image.
CSS nodes
Avatar has a single CSS node with name avatar.
Accessibility
Avatar uses the [enum@Gtk.AccessibleRole.img] role.
Properties
custom-image
A custom image paintable.
Custom image is displayed instead of initials or icon.
Readable | Writeable
icon-name
The name of an icon to use as a fallback.
If no name is set, avatar-default-symbolic will be used.
Readable | Writeable
show-initials
Whether initials are used instead of an icon on the fallback avatar.
See icon-name for how to change the fallback icon.
Readable | Writeable
size
The size of the avatar.
Readable | Writeable
text
Sets the text used to generate the fallback initials and color.
It’s only used to generate the color if show-initials is
FALSE.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Avatar
impl Avatar
Sourcepub fn builder() -> AvatarBuilder
pub fn builder() -> AvatarBuilder
Creates a new builder-pattern struct instance to construct Avatar objects.
This method returns an instance of AvatarBuilder which can be used to create Avatar objects.
Sourcepub fn draw_to_texture(&self, scale_factor: i32) -> Texture
pub fn draw_to_texture(&self, scale_factor: i32) -> Texture
Renders @self into a gdk::Texture at @scale_factor.
This can be used to export the fallback avatar.
scale_factor
The scale factor
Returns
the texture
Sourcepub fn custom_image(&self) -> Option<Paintable>
pub fn custom_image(&self) -> Option<Paintable>
Sourcepub fn shows_initials(&self) -> bool
pub fn shows_initials(&self) -> bool
Gets whether initials are used instead of an icon on the fallback avatar.
Returns
whether initials are used instead of an icon as fallback
Sourcepub fn text(&self) -> Option<GString>
pub fn text(&self) -> Option<GString>
Gets the text used to generate the fallback initials and color.
Returns
the text used to generate the fallback initials and color
Sourcepub fn set_custom_image(&self, custom_image: Option<&impl IsA<Paintable>>)
pub fn set_custom_image(&self, custom_image: Option<&impl IsA<Paintable>>)
Sets the custom image paintable.
Custom image is displayed instead of initials or icon.
custom_image
a custom image
Sourcepub fn set_icon_name(&self, icon_name: Option<&str>)
pub fn set_icon_name(&self, icon_name: Option<&str>)
Sets the name of an icon to use as a fallback.
If no name is set, avatar-default-symbolic will be used.
icon_name
the icon name
Sourcepub fn set_show_initials(&self, show_initials: bool)
pub fn set_show_initials(&self, show_initials: bool)
Sourcepub fn set_text(&self, text: Option<&str>)
pub fn set_text(&self, text: Option<&str>)
Sets the text used to generate the fallback initials and color.
It’s only used to generate the color if show-initials is
FALSE.
text
the text used to get the initials and color
pub fn connect_custom_image_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_show_initials_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId