pub struct BottomSheet { /* private fields */ }v1_6 only.Expand description
A bottom sheet with an optional bottom bar.
BottomSheet has three child widgets. content is
shown persistently. sheet is displayed above it when
it’s open, and bottom-bar is displayed when it’s not.
Bottom sheet and bottom bar are attached to the bottom edge of the widget.
They take the full width by default, but can only take a portion of it if
full-width is set to FALSE. In this case,
align determines where along the bottom edge they are
placed.
Bottom bar can be hidden using the reveal-bottom-bar
property.
BottomSheet can be useful for applications such as music players, that
want to have a persistent bottom bar that expands into a bottom sheet when
clicked. It’s meant for cases where a bottom sheet is tightly integrated into
the UI. For more transient bottom sheets, see Dialog.
To open or close the bottom sheet, use the open
property.
By default, the bottom sheet has an overlaid drag handle. It can be disabled
by setting show-drag-handle to FALSE. Note that the
handle also controls whether the sheet can be dragged using a pointer.
Bottom sheets are modal by default, meaning that the content is dimmed and
cannot be accessed while the sheet is open. Set modal
to FALSE if this behavior is unwanted.
To disable user interactions for opening or closing the bottom sheet (such as
swipes or clicking the bottom bar or close button), set
can-open or can-close to
FALSE.
In some cases, particularly when using a full-width bottom bar, it may be
necessary to shift content upwards. Use the
bottom-bar-height and
sheet-height for that.
BottomSheet is not adaptive, and for larger window sizes applications
may want to replace it with another UI, such as a sidebar. This can be done
using MultiLayoutView.
Sizing
Unlike Dialog presented as a bottom sheet, BottomSheet just
follows the content’s natural size, and it’s up to the applications to make
sure their content provides one. For example, when using
gtk::ScrolledWindow, make sure to set
propagate-natural-height to TRUE.
Header Bar Integration
When placed inside an BottomSheet, HeaderBar will not show the
title when show-drag-handle is TRUE, regardless of
show-title. This only applies to the default title,
titles set with title-widget will still be shown.
BottomSheet as gtk::Buildable:
The BottomSheet implementation of the gtk::Buildable interface
supports setting the sheet widget by specifying “sheet” as the “type”
attribute of a <child> element, and the bottom bar by specifying
“bottom-bar”. Specifying “content” or omitting the child type results in
setting the content child.
Properties
align
Horizontal alignment of the bottom sheet.
0 means the bottom sheet is flush with the start edge, 1 means it’s flush with the end edge. 0.5 means it’s centered.
Only used when full-width is set to FALSE.
Readable | Writeable
bottom-bar
The bottom bar widget.
Shown when open is FALSE. When open, morphs into
the sheet.
Bottom bar can be temporarily hidden using the
reveal-bottom-bar property.
Readable | Writeable
bottom-bar-height
The current bottom bar height.
It can be used to shift the content upwards permanently to accommodate for the bottom bar.
Readable
can-close
Whether the bottom sheet can be closed by user.
It can be closed via the close button, swiping down, pressing Escape or clicking the content dimming (when modal).
Bottom sheet can still be closed using open.
Readable | Writeable
can-open
Whether the bottom sheet can be opened by user.
It can be opened via clicking or swiping up from the bottom bar.
Does nothing if bottom-bar is not set.
Bottom sheet can still be opened using open.
Readable | Writeable
content
The content widget.
It’s always shown, and the bottom sheet is overlaid over it.
Readable | Writeable
full-width
Whether the bottom sheet takes the full width.
When full width, align is ignored.
Readable | Writeable
modal
Whether the bottom sheet is modal.
When modal, content will be dimmed when the bottom
sheet is open, and clicking it will close the bottom sheet. It also cannot
be focused with keyboard.
Otherwise, the content is accessible even when the bottom sheet is open.
Readable | Writeable
open
Whether the bottom sheet is open.
Readable | Writeable
reveal-bottom-bar
Whether to reveal the bottom bar.
The transition will be animated.
See bottom-bar and
bottom-bar-height.
Readable | Writeable
sheet
The bottom sheet widget.
Only shown when open is TRUE.
Readable | Writeable
sheet-height
The current bottom sheet height.
It can be used to shift the content upwards when the bottom sheet is open.
Readable
show-drag-handle
Whether to overlay a drag handle in the bottom sheet.
The handle will be overlaid over sheet.
When the handle is shown, HeaderBar will hide its default title,
and ToolbarView will reserve space if there are no top bars.
Showing drag handle also allows to swipe the bottom sheet down (and to swipe the bottom bar up) with a pointer, instead of just touchscreen.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Signals
close-attempt
Emitted when the close button or shortcut is used while
can-close is set to FALSE.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, SwipeableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl BottomSheet
impl BottomSheet
Sourcepub fn new() -> BottomSheet
pub fn new() -> BottomSheet
Sourcepub fn builder() -> BottomSheetBuilder
pub fn builder() -> BottomSheetBuilder
Creates a new builder-pattern struct instance to construct BottomSheet objects.
This method returns an instance of BottomSheetBuilder which can be used to create BottomSheet objects.
Sourcepub fn bottom_bar(&self) -> Option<Widget>
pub fn bottom_bar(&self) -> Option<Widget>
Sourcepub fn bottom_bar_height(&self) -> i32
pub fn bottom_bar_height(&self) -> i32
Gets the current bottom bar height.
It can be used to shift the content upwards permanently to accommodate for the bottom bar.
Returns
the bottom bar height
Sourcepub fn can_close(&self) -> bool
pub fn can_close(&self) -> bool
Gets whether the bottom sheet can be closed by user.
Returns
whether the sheet can be closed by user
Sourcepub fn can_open(&self) -> bool
pub fn can_open(&self) -> bool
Gets whether the bottom sheet can be opened by user.
Returns
whether the sheet can be opened by user.
Sourcepub fn is_full_width(&self) -> bool
pub fn is_full_width(&self) -> bool
Gets whether the bottom sheet takes the full width.
Returns
whether the sheet takes up the full width
Sourcepub fn reveals_bottom_bar(&self) -> bool
Available on crate feature v1_7 only.
pub fn reveals_bottom_bar(&self) -> bool
v1_7 only.Sourcepub fn sheet_height(&self) -> i32
pub fn sheet_height(&self) -> i32
Gets the current bottom sheet height.
It can be used to shift the content upwards when the bottom sheet is open.
Returns
the sheet height
Sourcepub fn shows_drag_handle(&self) -> bool
pub fn shows_drag_handle(&self) -> bool
Sourcepub fn set_align(&self, align: f32)
pub fn set_align(&self, align: f32)
Sets horizontal alignment of the bottom sheet.
0 means the bottom sheet is flush with the start edge, 1 means it’s flush with the end edge. 0.5 means it’s centered.
Only used when full-width is set to FALSE.
align
the new alignment
Sourcepub fn set_bottom_bar(&self, bottom_bar: Option<&impl IsA<Widget>>)
pub fn set_bottom_bar(&self, bottom_bar: Option<&impl IsA<Widget>>)
Sets the bottom bar widget for @self.
Shown when open is FALSE. When open, morphs into
the sheet.
Bottom bar can be temporarily hidden using the
reveal-bottom-bar property.
bottom_bar
the bottom bar widget
Sourcepub fn set_can_close(&self, can_close: bool)
pub fn set_can_close(&self, can_close: bool)
Sourcepub fn set_can_open(&self, can_open: bool)
pub fn set_can_open(&self, can_open: bool)
Sets whether the bottom sheet can be opened by user.
It can be opened via clicking or swiping up from the bottom bar.
Does nothing if bottom-bar is not set.
Bottom sheet can still be opened using open.
can_open
whether the sheet can be opened by user.
Sourcepub fn set_content(&self, content: Option<&impl IsA<Widget>>)
pub fn set_content(&self, content: Option<&impl IsA<Widget>>)
Sets the content widget for @self.
It’s always shown, and the bottom sheet is overlaid over it.
content
the content widget
Sourcepub fn set_full_width(&self, full_width: bool)
pub fn set_full_width(&self, full_width: bool)
Sourcepub fn set_reveal_bottom_bar(&self, reveal: bool)
Available on crate feature v1_7 only.
pub fn set_reveal_bottom_bar(&self, reveal: bool)
v1_7 only.Sets whether to reveal the bottom bar.
The transition will be animated.
See bottom-bar and
bottom-bar-height.
reveal
whether to reveal the bottom bar
Sourcepub fn set_show_drag_handle(&self, show_drag_handle: bool)
pub fn set_show_drag_handle(&self, show_drag_handle: bool)
Sets whether to show a drag handle in the bottom sheet.
The handle will be overlaid over sheet.
When the handle is shown, HeaderBar will hide its default title, and
ToolbarView will reserve space if there are no top bars.
Showing drag handle also allows to swipe the bottom sheet down (and to swipe the bottom bar up) with a pointer, instead of just touchscreen.
show_drag_handle
whether to show the drag handle
Sourcepub fn connect_close_attempt<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_close_attempt<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the close button or shortcut is used while
can-close is set to FALSE.
pub fn connect_align_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_bottom_bar_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_bottom_bar_height_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_can_close_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_can_open_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_content_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_full_width_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_modal_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_open_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_reveal_bottom_bar_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.pub fn connect_sheet_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_sheet_height_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_show_drag_handle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId