pub struct Breakpoint { /* private fields */ }v1_4 only.Expand description
## Properties
#### `condition`
The breakpoint's condition.
Readable | Writable
## Signals
#### `apply`
Emitted when the breakpoint is applied.
This signal is emitted after the setters have been applied.
#### `unapply`
Emitted when the breakpoint is unapplied.
This signal is emitted before resetting the setter values.
# Implements
[`trait@glib::ObjectExt`], [`trait@gtk::prelude::BuildableExt`]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl Breakpoint
impl Breakpoint
Sourcepub fn new(condition: BreakpointCondition) -> Breakpoint
pub fn new(condition: BreakpointCondition) -> Breakpoint
Creates a new Breakpoint with @condition.
condition
the condition
Returns
the newly created Breakpoint
Sourcepub fn add_setter(
&self,
object: &impl IsA<Object>,
property: &str,
value: Option<&Value>,
)
pub fn add_setter( &self, object: &impl IsA<Object>, property: &str, value: Option<&Value>, )
button, _(“_Back”)); }
// …
g_signal_connect_swapped (breakpoint, “apply”, G_CALLBACK (breakpoint_apply_cb), self); g_signal_connect_swapped (breakpoint, “unapply”, G_CALLBACK (breakpoint_unapply_cb), self);
## `object`
the target object
## `property`
the target property
## `value`
the value to setSourcepub fn condition(&self) -> Option<BreakpointCondition>
pub fn condition(&self) -> Option<BreakpointCondition>
Sourcepub fn set_condition(&self, condition: Option<&BreakpointCondition>)
pub fn set_condition(&self, condition: Option<&BreakpointCondition>)
Sourcepub fn connect_apply<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_apply<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the breakpoint is applied.
This signal is emitted after the setters have been applied.
Sourcepub fn connect_unapply<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_unapply<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the breakpoint is unapplied.
This signal is emitted before resetting the setter values.
pub fn connect_condition_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl Breakpoint
impl Breakpoint
Sourcepub fn add_setters(&self, additions: &[(&impl IsA<Object>, &str, impl ToValue)])
pub fn add_setters(&self, additions: &[(&impl IsA<Object>, &str, impl ToValue)])
Adds @n_setters setters to @self.
This is a convenience function for adding multiple setters at once.
See add_setter().
This function is meant to be used by language bindings.
objects
setter target object
names
setter target properties
values
setter values