pub struct BreakpointCondition { /* private fields */ }Available on crate feature
v1_4 only.Expand description
Describes condition for an Breakpoint.
GLib type: Boxed type with copy-on-clone semantics.
Implementations
Sourceimpl BreakpointCondition
impl BreakpointCondition
Sourcepub fn as_ptr(&self) -> *mut AdwBreakpointCondition
pub fn as_ptr(&self) -> *mut AdwBreakpointCondition
Return the inner pointer to the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow(ptr: &*mut AdwBreakpointCondition) -> &Self
pub unsafe fn from_glib_ptr_borrow(ptr: &*mut AdwBreakpointCondition) -> &Self
Borrows the underlying C value.
Sourcepub unsafe fn from_glib_ptr_borrow_mut(
ptr: &mut *mut AdwBreakpointCondition,
) -> &mut Self
pub unsafe fn from_glib_ptr_borrow_mut( ptr: &mut *mut AdwBreakpointCondition, ) -> &mut Self
Borrows the underlying C value mutably.
Sourceimpl BreakpointCondition
impl BreakpointCondition
Sourcepub fn new_and(
condition_1: BreakpointCondition,
condition_2: BreakpointCondition,
) -> BreakpointCondition
pub fn new_and( condition_1: BreakpointCondition, condition_2: BreakpointCondition, ) -> BreakpointCondition
Sourcepub fn new_length(
type_: BreakpointConditionLengthType,
value: f64,
unit: LengthUnit,
) -> BreakpointCondition
pub fn new_length( type_: BreakpointConditionLengthType, value: f64, unit: LengthUnit, ) -> BreakpointCondition
Sourcepub fn new_or(
condition_1: BreakpointCondition,
condition_2: BreakpointCondition,
) -> BreakpointCondition
pub fn new_or( condition_1: BreakpointCondition, condition_2: BreakpointCondition, ) -> BreakpointCondition
Sourcepub fn new_ratio(
type_: BreakpointConditionRatioType,
width: i32,
height: i32,
) -> BreakpointCondition
pub fn new_ratio( type_: BreakpointConditionRatioType, width: i32, height: i32, ) -> BreakpointCondition
Sourcepub fn to_str(&self) -> GString
pub fn to_str(&self) -> GString
Returns a textual representation of @self.
The returned string can be parsed by parse().
Returns
A newly allocated text string
Sourcepub fn parse(str: &str) -> Result<BreakpointCondition, BoolError>
pub fn parse(str: &str) -> Result<BreakpointCondition, BoolError>
s is true, same as when using BreakpointCondition::new_or()`
Examples:
min-width: 400px and max-aspect-ratio: 4/3max-width: 360sp or max-width: 360px
Conditions can be further nested using parentheses, for example:
min-width: 400px and (max-aspect-ratio: 4/3 or max-height: 400px)
If parentheses are omitted, the first operator takes priority.
str
the string specifying the condition
Returns
the parsed condition