pub struct Dialog { /* private fields */ }v1_5 only.Expand description
An adaptive dialog container.
Dialog is similar to a window, but is shown within another window. It
can be used with Window and ApplicationWindow, use
AdwDialogExt::present() to show it.
Dialog is not resizable. Use the content-width and
content-height properties to set its size, or set
follows-content-size to TRUE to make the dialog track the
content’s size as it changes. Dialog can never be larger than its parent
window.
Dialog can be presented as a centered floating window or a bottom sheet.
By default it’s automatic depending on the available size.
presentation-mode can be used to change that.
Dialog can be closed via AdwDialogExt::close().
When presented as a bottom sheet, Dialog can also be closed via swiping
it down.
The can-close can be used to prevent closing. In that case,
close-attempt gets emitted instead.
Use AdwDialogExt::force_close() to close the dialog even when can-close is set to
FALSE.
Dialog is transient and doesn’t integrate with the window below it, for
example it’s not possible to collapse it into a bottom bar. See
BottomSheet for persistent and more tightly integrated bottom sheets.
Header Bar Integration
When placed inside an Dialog, HeaderBar will display the dialog
title instead of window title. It will also adjust the decoration layout to
ensure it always has a close button and nothing else. Set
show-start-title-buttons and
show-end-title-buttons to FALSE to remove it if it’s
unwanted.
Breakpoints
Dialog can be used with Breakpoint the same way as
BreakpointBin. Refer to that widget’s documentation for details.
Like BreakpointBin, if breakpoints are used, Dialog doesn’t have a
minimum size, and width-request and
height-request properties must be set manually.
Properties
can-close
Whether the dialog can be closed.
If set to FALSE, the close button, shortcuts and
AdwDialogExt::close() will result in close-attempt being
emitted instead, and bottom sheet close swipe will be disabled.
AdwDialogExt::force_close() still works.
Readable | Writeable
child
The child widget of the Dialog.
Readable | Writeable
content-height
The height of the dialog’s contents.
Set it to -1 to reset it to the content’s natural height.
See also: default-height
Readable | Writeable
content-width
The width of the dialog’s contents.
Set it to -1 to reset it to the content’s natural width.
See also: default-width
Readable | Writeable
current-breakpoint
The current breakpoint.
Readable
default-widget
The default widget.
It’s activated when the user presses Enter.
Readable | Writeable
focus-widget
The focus widget.
Readable | Writeable
follows-content-size
Whether to size content automatically.
If set to TRUE, always use the content’s natural size instead of
content-width and content-height. If
the content resizes, the dialog will immediately resize as well.
See also: resizable
Readable | Writeable
presentation-mode
The dialog’s presentation mode.
When set to [enum@Adw.DialogPresentationMode.auto], the dialog appears as a
bottom sheet when the following condition is met:
max-width: 450px or max-height: 360px, and as a floating window otherwise.
Set it to [enum@Adw.DialogPresentationMode.floating] or [enum@Adw.DialogPresentationMode.bottom-sheet] to always present it a floating window or a bottom sheet respectively, regardless of available size.
Presentation mode does nothing for dialogs presented as a window.
Readable | Writeable
title
The title of the dialog.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Signals
close-attempt
Emitted when the close button or shortcut is used, or
AdwDialogExt::close() is called while can-close is set to
FALSE.
closed
Emitted when the dialog is successfully closed.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
AdwDialogExt, gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, gtk::prelude::ShortcutManagerExt
GLib type: GObject with reference counted clone semantics.
Implementations