pub struct Leaflet { /* private fields */ }Expand description
See the migration guide An adaptive container acting like a box or a stack.
The Leaflet widget can display its children like a Gtk::Box does
or like a gtk::Stack does, adapting to size changes by switching
between the two modes.
When there is enough space the children are displayed side by side, otherwise only one is displayed and the leaflet is said to be “folded”. The threshold is dictated by the preferred minimum sizes of the children. When a leaflet is folded, the children can be navigated using swipe gestures.
The “over” and “under” transition types stack the children one on top of the other, while the “slide” transition puts the children side by side. While navigating to a child on the side or below can be performed by swiping the current child away, navigating to an upper child requires dragging it from the edge where it resides. This doesn’t affect non-dragging swipes.
CSS nodes
Leaflet has a single CSS node with name leaflet. The node will get the
style classes .folded when it is folded, .unfolded when it’s not, or none
if it hasn’t computed its fold yet.
Properties
can-navigate-back
Whether gestures and shortcuts for navigating backward are enabled.
The supported gestures are:
- One-finger swipe on touchscreens
- Horizontal scrolling on touchpads (usually two-finger swipe)
- Back/forward mouse buttons
The keyboard back/forward keys are also supported, as well as the Alt+← shortcut for horizontal orientation, or Alt+↑ for vertical orientation.
If the orientation is horizontal, for right-to-left locales, gestures and shortcuts are reversed.
Only children that have navigatable set to TRUE
can be navigated to.
Readable | Writeable
can-navigate-forward
Whether gestures and shortcuts for navigating forward are enabled.
The supported gestures are:
- One-finger swipe on touchscreens
- Horizontal scrolling on touchpads (usually two-finger swipe)
- Back/forward mouse buttons
The keyboard back/forward keys are also supported, as well as the Alt+→ shortcut for horizontal orientation, or Alt+↓ for vertical orientation.
If the orientation is horizontal, for right-to-left locales, gestures and shortcuts are reversed.
Only children that have navigatable set to TRUE
can be navigated to.
Readable | Writeable
can-unfold
Whether or not the leaflet can unfold.
Readable | Writeable
child-transition-params
The child transition spring parameters.
The default value is equivalent to:
⚠️ The following code is in c ⚠️
adw_spring_params_new (1, 0.5, 500)Readable | Writeable
child-transition-running
Whether a child transition is currently running.
Readable
fold-threshold-policy
Determines when the leaflet will fold.
If set to ADW_FOLD_THRESHOLD_POLICY_MINIMUM, it will only fold when the
children cannot fit anymore. With ADW_FOLD_THRESHOLD_POLICY_NATURAL, it
will fold as soon as children don’t get their natural size.
This can be useful if you have a long ellipsizing label and want to let it ellipsize instead of immediately folding.
Readable | Writeable
folded
Whether the leaflet is folded.
The leaflet will be folded if the size allocated to it is smaller than the
sum of the minimum or natural sizes of the children (see
fold-threshold-policy), it will be unfolded otherwise.
Readable
homogeneous
Whether the leaflet allocates the same size for all children when folded.
If set to FALSE, different children can have different size along the
opposite orientation.
Readable | Writeable
mode-transition-duration
The mode transition animation duration, in milliseconds.
Readable | Writeable
pages
A selection model with the leaflet’s pages.
This can be used to keep an up-to-date view. The model also implements
gtk::SelectionModel and can be used to track and change the visible
page.
Readable
transition-type
The type of animation used for transitions between modes and children.
The transition type can be changed without problems at runtime, so it is possible to change the animation based on the mode or child that is about to become current.
Readable | Writeable
visible-child
The widget currently visible when the leaflet is folded.
The transition is determined by transition-type and
child-transition-params. The transition can be cancelled
by the user, in which case visible child will change back to the previously
visible child.
Readable | Writeable
visible-child-name
The name of the widget currently visible when the leaflet is folded.
See visible-child.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, SwipeableExt, gtk::prelude::OrientableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Leaflet
impl Leaflet
Sourcepub fn new() -> Leaflet
👎Deprecated: Since 1.4
pub fn new() -> Leaflet
Sourcepub fn builder() -> LeafletBuilder
👎Deprecated: Since 1.4
pub fn builder() -> LeafletBuilder
Creates a new builder-pattern struct instance to construct Leaflet objects.
This method returns an instance of LeafletBuilder which can be used to create Leaflet objects.
Sourcepub fn append(&self, child: &impl IsA<Widget>) -> LeafletPage
👎Deprecated: Since 1.4
pub fn append(&self, child: &impl IsA<Widget>) -> LeafletPage
Adds a child to @self.
Deprecated since 1.4
child
the widget to add
Returns
the LeafletPage for @child
Sourcepub fn adjacent_child(&self, direction: NavigationDirection) -> Option<Widget>
👎Deprecated: Since 1.4
pub fn adjacent_child(&self, direction: NavigationDirection) -> Option<Widget>
Finds the previous or next navigatable child.
This will be the same child navigate() or swipe gestures will
navigate to.
If there’s no child to navigate to, NULL will be returned instead.
See navigatable.
Deprecated since 1.4
direction
the direction
Returns
the previous or next child
👎Deprecated: Since 1.4
👎Deprecated: Since 1.4
Sourcepub fn can_unfold(&self) -> bool
👎Deprecated: Since 1.4
pub fn can_unfold(&self) -> bool
Sourcepub fn child_by_name(&self, name: &str) -> Option<Widget>
👎Deprecated: Since 1.4
pub fn child_by_name(&self, name: &str) -> Option<Widget>
Sourcepub fn child_transition_params(&self) -> SpringParams
👎Deprecated: Since 1.4
pub fn child_transition_params(&self) -> SpringParams
Sourcepub fn is_child_transition_running(&self) -> bool
👎Deprecated: Since 1.4
pub fn is_child_transition_running(&self) -> bool
Sourcepub fn fold_threshold_policy(&self) -> FoldThresholdPolicy
👎Deprecated: Since 1.4
pub fn fold_threshold_policy(&self) -> FoldThresholdPolicy
Sourcepub fn is_folded(&self) -> bool
👎Deprecated: Since 1.4
pub fn is_folded(&self) -> bool
Gets whether @self is folded.
The leaflet will be folded if the size allocated to it is smaller than the
sum of the minimum or natural sizes of the children (see
fold-threshold-policy), it will be unfolded otherwise.
Deprecated since 1.4
Returns
whether @self is folded.
Sourcepub fn is_homogeneous(&self) -> bool
👎Deprecated: Since 1.4
pub fn is_homogeneous(&self) -> bool
Sourcepub fn mode_transition_duration(&self) -> u32
👎Deprecated: Since 1.4
pub fn mode_transition_duration(&self) -> u32
Sourcepub fn page(&self, child: &impl IsA<Widget>) -> LeafletPage
👎Deprecated: Since 1.4
pub fn page(&self, child: &impl IsA<Widget>) -> LeafletPage
Returns the LeafletPage object for @child.
Deprecated since 1.4
child
a child of @self
Returns
the page object for @child
Sourcepub fn pages(&self) -> SelectionModel
👎Deprecated: Since 1.4
pub fn pages(&self) -> SelectionModel
Returns a gio::ListModel that contains the pages of the leaflet.
This can be used to keep an up-to-date view. The model also implements
gtk::SelectionModel and can be used to track and change the visible
page.
Deprecated since 1.4
Returns
a gtk::SelectionModel for the leaflet’s children
Sourcepub fn transition_type(&self) -> LeafletTransitionType
👎Deprecated: Since 1.4
pub fn transition_type(&self) -> LeafletTransitionType
Sourcepub fn visible_child(&self) -> Option<Widget>
👎Deprecated: Since 1.4
pub fn visible_child(&self) -> Option<Widget>
Sourcepub fn visible_child_name(&self) -> Option<GString>
👎Deprecated: Since 1.4
pub fn visible_child_name(&self) -> Option<GString>
Sourcepub fn insert_child_after(
&self,
child: &impl IsA<Widget>,
sibling: Option<&impl IsA<Widget>>,
) -> LeafletPage
👎Deprecated: Since 1.4
pub fn insert_child_after( &self, child: &impl IsA<Widget>, sibling: Option<&impl IsA<Widget>>, ) -> LeafletPage
Inserts @child in the position after @sibling in the list of children.
If @sibling is NULL, inserts @child at the first position.
Deprecated since 1.4
child
the widget to insert
sibling
the sibling after which to insert @child
Returns
the LeafletPage for @child
👎Deprecated: Since 1.4
Navigates to the previous or next child.
The child must have the navigatable property set to
TRUE, otherwise it will be skipped.
This will be the same child as returned by
adjacent_child() or navigated to via swipe gestures.
Deprecated since 1.4
direction
the direction
Returns
whether the visible child was changed
Sourcepub fn prepend(&self, child: &impl IsA<Widget>) -> LeafletPage
👎Deprecated: Since 1.4
pub fn prepend(&self, child: &impl IsA<Widget>) -> LeafletPage
Inserts @child at the first position in @self.
Deprecated since 1.4
child
the widget to prepend
Returns
the LeafletPage for @child
Sourcepub fn remove(&self, child: &impl IsA<Widget>)
👎Deprecated: Since 1.4
pub fn remove(&self, child: &impl IsA<Widget>)
Sourcepub fn reorder_child_after(
&self,
child: &impl IsA<Widget>,
sibling: Option<&impl IsA<Widget>>,
)
👎Deprecated: Since 1.4
pub fn reorder_child_after( &self, child: &impl IsA<Widget>, sibling: Option<&impl IsA<Widget>>, )
👎Deprecated: Since 1.4
Sets whether gestures and shortcuts for navigating backward are enabled.
The supported gestures are:
- One-finger swipe on touchscreens
- Horizontal scrolling on touchpads (usually two-finger swipe)
- Back/forward mouse buttons
The keyboard back/forward keys are also supported, as well as the Alt+← shortcut for horizontal orientation, or Alt+↑ for vertical orientation.
If the orientation is horizontal, for right-to-left locales, gestures and shortcuts are reversed.
Only children that have navigatable set to TRUE can
be navigated to.
Deprecated since 1.4
can_navigate_back
the new value
👎Deprecated: Since 1.4
Sets whether gestures and shortcuts for navigating forward are enabled.
The supported gestures are:
- One-finger swipe on touchscreens
- Horizontal scrolling on touchpads (usually two-finger swipe)
- Back/forward mouse buttons
The keyboard back/forward keys are also supported, as well as the Alt+→ shortcut for horizontal orientation, or Alt+↓ for vertical orientation.
If the orientation is horizontal, for right-to-left locales, gestures and shortcuts are reversed.
Only children that have navigatable set to TRUE can
be navigated to.
Deprecated since 1.4
can_navigate_forward
the new value
Sourcepub fn set_can_unfold(&self, can_unfold: bool)
👎Deprecated: Since 1.4
pub fn set_can_unfold(&self, can_unfold: bool)
Sourcepub fn set_child_transition_params(&self, params: &SpringParams)
👎Deprecated: Since 1.4
pub fn set_child_transition_params(&self, params: &SpringParams)
Sourcepub fn set_fold_threshold_policy(&self, policy: FoldThresholdPolicy)
👎Deprecated: Since 1.4
pub fn set_fold_threshold_policy(&self, policy: FoldThresholdPolicy)
Sets the fold threshold policy for @self.
If set to ADW_FOLD_THRESHOLD_POLICY_MINIMUM, it will only fold when the
children cannot fit anymore. With ADW_FOLD_THRESHOLD_POLICY_NATURAL, it
will fold as soon as children don’t get their natural size.
This can be useful if you have a long ellipsizing label and want to let it ellipsize instead of immediately folding.
Deprecated since 1.4
policy
the policy to use
Sourcepub fn set_homogeneous(&self, homogeneous: bool)
👎Deprecated: Since 1.4
pub fn set_homogeneous(&self, homogeneous: bool)
Sourcepub fn set_mode_transition_duration(&self, duration: u32)
👎Deprecated: Since 1.4
pub fn set_mode_transition_duration(&self, duration: u32)
Sourcepub fn set_transition_type(&self, transition: LeafletTransitionType)
👎Deprecated: Since 1.4
pub fn set_transition_type(&self, transition: LeafletTransitionType)
Sourcepub fn set_visible_child(&self, visible_child: &impl IsA<Widget>)
👎Deprecated: Since 1.4
pub fn set_visible_child(&self, visible_child: &impl IsA<Widget>)
Sets the widget currently visible when the leaflet is folded.
The transition is determined by transition-type and
child-transition-params. The transition can be cancelled
by the user, in which case visible child will change back to the previously
visible child.
Deprecated since 1.4
visible_child
the new child
Sourcepub fn set_visible_child_name(&self, name: &str)
👎Deprecated: Since 1.4
pub fn set_visible_child_name(&self, name: &str)
Makes the child with the name @name visible.
See visible-child.
Deprecated since 1.4
name
the name of a child
pub fn connect_can_unfold_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_child_transition_params_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_child_transition_running_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_fold_threshold_policy_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_folded_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_homogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_mode_transition_duration_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_pages_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_transition_type_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_visible_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_visible_child_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId