MultiLayoutView

Struct MultiLayoutView 

pub struct MultiLayoutView { /* private fields */ }
Available on crate feature v1_6 only.
## CSS nodes

[`MultiLayoutView`][crate::MultiLayoutView] has a single CSS node with name `multi-layout-view`.

## Properties


#### `layout`
 The currently used layout.

Readable | Writable


#### `layout-name`
 The name of the currently used layout.

See [`name`][struct@crate::Layout#name].

Readable | Writable
<details><summary><h4>Widget</h4></summary>


#### `can-focus`
 Whether the widget or any of its descendents can accept
the input focus.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `can-target`
 Whether the widget can receive pointer events.

Readable | Writable


#### `css-classes`
 A list of css classes applied to this widget.

Readable | Writable


#### `css-name`
 The name of this widget in the CSS tree.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable | Construct Only


#### `cursor`
 The cursor used by @widget.

Readable | Writable


#### `focus-on-click`
 Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Readable | Writable


#### `focusable`
 Whether this widget itself will accept the input focus.

Readable | Writable


#### `halign`
 How to distribute horizontal space if widget gets extra space.

Readable | Writable


#### `has-default`
 Whether the widget is the default widget.

Readable


#### `has-focus`
 Whether the widget has the input focus.

Readable


#### `has-tooltip`
 Enables or disables the emission of the [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip]
signal on @widget.

A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.

Readable | Writable


#### `height-request`
 Overrides for height request of the widget.

If this is -1, the natural request will be used.

Readable | Writable


#### `hexpand`
 Whether to expand horizontally.

Readable | Writable


#### `hexpand-set`
 Whether to use the `hexpand` property.

Readable | Writable


#### `layout-manager`
 The [`gtk::LayoutManager`][crate::gtk::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `limit-events`
 Makes this widget act like a modal dialog, with respect to
event delivery.

Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See `Gtk::EventController::set_propagation_limit()`.

Readable | Writable


#### `margin-bottom`
 Margin on bottom side of widget.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writable


#### `margin-end`
 Margin on end of widget, horizontally.

This property supports left-to-right and right-to-left text
directions.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writable


#### `margin-start`
 Margin on start of widget, horizontally.

This property supports left-to-right and right-to-left text
directions.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writable


#### `margin-top`
 Margin on top side of widget.

This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writable


#### `name`
 The name of the widget.

Readable | Writable


#### `opacity`
 The requested opacity of the widget.

Readable | Writable


#### `overflow`
 How content outside the widget's content area is treated.

This property is meant to be set by widget implementations,
typically in their instance init function.

Readable | Writable


#### `parent`
 The parent widget of this widget.

Readable


#### `receives-default`
 Whether the widget will receive the default action when it is focused.

Readable | Writable


#### `root`
 The [`gtk::Root`][crate::gtk::Root] widget of the widget tree containing this widget.

This will be `NULL` if the widget is not contained in a root widget.

Readable


#### `scale-factor`
 The scale factor of the widget.

Readable


#### `sensitive`
 Whether the widget responds to input.

Readable | Writable


#### `tooltip-markup`
 Sets the text of tooltip to be the given string, which is marked up
with Pango markup.

Also see `Gtk::Tooltip::set_markup()`.

This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.

Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.

Readable | Writable


#### `tooltip-text`
 Sets the text of tooltip to be the given string.

Also see `Gtk::Tooltip::set_text()`.

This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.

Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.

Readable | Writable


#### `valign`
 How to distribute vertical space if widget gets extra space.

Readable | Writable


#### `vexpand`
 Whether to expand vertically.

Readable | Writable


#### `vexpand-set`
 Whether to use the `vexpand` property.

Readable | Writable


#### `visible`
 Whether the widget is visible.

Readable | Writable


#### `width-request`
 Overrides for width request of the widget.

If this is -1, the natural request will be used.

Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>


#### `accessible-role`
 The accessible role of the given [`gtk::Accessible`][crate::gtk::Accessible] implementation.

The accessible role cannot be changed once set.

Readable | Writable
</details>

# Implements

[`trait@gtk::prelude::WidgetExt`], [`trait@glib::ObjectExt`], [`trait@gtk::prelude::AccessibleExt`], [`trait@gtk::prelude::BuildableExt`], [`trait@gtk::prelude::ConstraintTargetExt`]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl MultiLayoutView

pub fn new() -> MultiLayoutView

Creates a new MultiLayoutView.

Returns

the newly created MultiLayoutView

pub fn builder() -> MultiLayoutViewBuilder

Creates a new builder-pattern struct instance to construct MultiLayoutView objects.

This method returns an instance of MultiLayoutViewBuilder which can be used to create MultiLayoutView objects.

pub fn add_layout(&self, layout: Layout)

Adds @layout to @self.

layout

the layout to add

pub fn child(&self, id: &str) -> Option<Widget>

Gets the child for @id to @self.

id

the id of the child

Returns

the child for @id

pub fn layout(&self) -> Option<Layout>

Gets the currently used layout of @self.

Returns

the current layout

pub fn layout_by_name(&self, name: &str) -> Option<Layout>

Gets layout with the name @name from @self, or NULL if it doesn’t exist.

See name.

name

the name of the layout

Returns

the layout with @name

pub fn layout_name(&self) -> Option<GString>

Returns the name of the currently used layout of @self.

Returns

the name of the current layout

pub fn remove_layout(&self, layout: &Layout)

Removes @layout from @self.

layout

the layout to add

pub fn set_child(&self, id: &str, child: &impl IsA<Widget>)

Sets @child as the child for @id in @self.

When changing layouts, it will be inserted into the slot with @id.

id

the id of the child

child

the child to set

pub fn set_layout(&self, layout: &Layout)

Makes @layout the current layout of @self.

layout

a layout in @self

pub fn set_layout_name(&self, name: &str)

Makes the layout with @name the current layout of @self.

See name.

name

the name of the layout

pub fn connect_layout_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_layout_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId