pub struct NavigationView { /* private fields */ }v1_4 only.Expand description
CSS nodes
NavigationView has a single CSS node with the name navigation-view.
Accessibility
NavigationView uses the [enum@Gtk.AccessibleRole.group] role.
Properties
animate-transitions
Whether to animate page transitions.
Gesture-based transitions are always animated.
Readable | Writable
hhomogeneous
Whether the view is horizontally homogeneous.
If the view is horizontally homogeneous, it allocates the same width for all pages.
If it’s not, the page may change width when a different page becomes visible.
Readable | Writable
navigation-stack
A list model that contains the pages in navigation stack.
The pages are sorted from root page to visible page.
This can be used to keep an up-to-date view.
Readable
pop-on-escape
Whether pressing Escape pops the current page.
Applications using NavigationView to implement a browser may want to
disable it.
Readable | Writable
vhomogeneous
Whether the view is vertically homogeneous.
If the view is vertically homogeneous, it allocates the same height for all pages.
If it’s not, the view may change height when a different page becomes visible.
Readable | Writable
visible-page
The currently visible page.
Readable
visible-page-tag
The tag of the currently visible page.
Readable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
can-target
Whether the widget can receive pointer events.
Readable | Writable
css-classes
A list of css classes applied to this widget.
Readable | Writable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable | Construct Only
cursor
The cursor used by @widget.
Readable | Writable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
focusable
Whether this widget itself will accept the input focus.
Readable | Writable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
hexpand
Whether to expand horizontally.
Readable | Writable
hexpand-set
Whether to use the hexpand property.
Readable | Writable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
name
The name of the widget.
Readable | Writable
opacity
The requested opacity of the widget.
Readable | Writable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writable
vexpand
Whether to expand vertically.
Readable | Writable
vexpand-set
Whether to use the vexpand property.
Readable | Writable
visible
Whether the widget is visible.
Readable | Writable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writable
Signals
get-next-page
Emitted when a push shortcut or a gesture is triggered.
To support the push shortcuts and gestures, the application is expected to return the page to push in the handler.
This signal can be emitted multiple times for the gestures, for example when the gesture is cancelled by the user. As such, the application must not make any irreversible changes in the handler, such as removing the page from a forward stack.
Instead, it should be done in the pushed handler.
popped
Emitted after @page has been popped from the navigation stack.
When using NavigationView::pop_to_page() or
NavigationView::pop_to_tag(), this signal is emitted for each of the
popped pages.
pushed
Emitted after a page has been pushed to the navigation stack.
replaced
Emitted after the navigation stack has been replaced.
See NavigationView::replace().
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
to move backward.
Action
query-tooltip
s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, SwipeableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourcepub fn new() -> NavigationView
pub fn new() -> NavigationView
Sourcepub fn builder() -> NavigationViewBuilder
pub fn builder() -> NavigationViewBuilder
Creates a new builder-pattern struct instance to construct NavigationView objects.
This method returns an instance of NavigationViewBuilder which can be used to create NavigationView objects.
Sourcepub fn add(&self, page: &impl IsA<NavigationPage>)
pub fn add(&self, page: &impl IsA<NavigationPage>)
Sourcepub fn find_page(&self, tag: &str) -> Option<NavigationPage>
pub fn find_page(&self, tag: &str) -> Option<NavigationPage>
Sourcepub fn is_animate_transitions(&self) -> bool
pub fn is_animate_transitions(&self) -> bool
Sourcepub fn is_hhomogeneous(&self) -> bool
Available on crate feature v1_7 only.
pub fn is_hhomogeneous(&self) -> bool
v1_7 only.Returns a gio::ListModel that contains the pages in navigation stack.
The pages are sorted from root page to visible page.
This can be used to keep an up-to-date view.
Returns
a list model for the navigation stack
Sourcepub fn is_pop_on_escape(&self) -> bool
pub fn is_pop_on_escape(&self) -> bool
Gets whether pressing Escape pops the current page on @self.
Returns
whether to pop the current page
Sourcepub fn previous_page(
&self,
page: &impl IsA<NavigationPage>,
) -> Option<NavigationPage>
pub fn previous_page( &self, page: &impl IsA<NavigationPage>, ) -> Option<NavigationPage>
Sourcepub fn is_vhomogeneous(&self) -> bool
Available on crate feature v1_7 only.
pub fn is_vhomogeneous(&self) -> bool
v1_7 only.Sourcepub fn visible_page(&self) -> Option<NavigationPage>
pub fn visible_page(&self) -> Option<NavigationPage>
Sourcepub fn visible_page_tag(&self) -> Option<GString>
Available on crate feature v1_7 only.
pub fn visible_page_tag(&self) -> Option<GString>
v1_7 only.Sourcepub fn pop(&self) -> bool
pub fn pop(&self) -> bool
Pops the visible page from the navigation stack.
Does nothing if the navigation stack contains less than two pages.
If add() hasn’t been called, the page is automatically
removed.
popped will be emitted for the current visible page.
See pop_to_page() and
pop_to_tag().
Returns
TRUE if a page has been popped
Sourcepub fn pop_to_page(&self, page: &impl IsA<NavigationPage>) -> bool
pub fn pop_to_page(&self, page: &impl IsA<NavigationPage>) -> bool
Pops pages from the navigation stack until @page is visible.
@page must be in the navigation stack.
If add() hasn’t been called for any of the popped pages,
they are automatically removed.
popped will be be emitted for each of the popped
pages.
See pop() and pop_to_tag().
page
the page to pop to
Returns
TRUE if any pages have been popped
Sourcepub fn pop_to_tag(&self, tag: &str) -> bool
pub fn pop_to_tag(&self, tag: &str) -> bool
Pops pages from the navigation stack until page with the tag @tag is visible.
The page must be in the navigation stack.
If add() hasn’t been called for any of the popped pages,
they are automatically removed.
popped will be emitted for each of the popped pages.
See pop_to_page() and tag.
tag
a page tag
Returns
TRUE if any pages have been popped
Sourcepub fn push(&self, page: &impl IsA<NavigationPage>)
pub fn push(&self, page: &impl IsA<NavigationPage>)
Pushes @page onto the navigation stack.
If add() hasn’t been called, the page is automatically
removed once it’s popped.
pushed will be emitted for @page.
See push_by_tag().
page
the page to push
Sourcepub fn push_by_tag(&self, tag: &str)
pub fn push_by_tag(&self, tag: &str)
Sourcepub fn remove(&self, page: &impl IsA<NavigationPage>)
pub fn remove(&self, page: &impl IsA<NavigationPage>)
Sourcepub fn replace(&self, pages: &[NavigationPage])
pub fn replace(&self, pages: &[NavigationPage])
Replaces the current navigation stack with @pages.
The last page becomes the visible page.
Replacing the navigation stack has no animation.
If add() hasn’t been called for any pages that are no
longer in the navigation stack, they are automatically removed.
@n_pages can be 0, in that case no page will be visible after calling this method. This can be useful for removing all pages from @self.
The replaced signal will be emitted.
See replace_with_tags().
pages
the new navigation stack
Replaces the current navigation stack with pages with the tags @tags.
The last page becomes the visible page.
Replacing the navigation stack has no animation.
If add() hasn’t been called for any pages that are no
longer in the navigation stack, they are automatically removed.
@n_tags can be 0, in that case no page will be visible after calling this method. This can be useful for removing all pages from @self.
The replaced signal will be emitted.
tags
tags of the pages in the navigation stack
Sourcepub fn set_animate_transitions(&self, animate_transitions: bool)
pub fn set_animate_transitions(&self, animate_transitions: bool)
Sets whether @self should animate page transitions.
Gesture-based transitions are always animated.
animate_transitions
whether to animate page transitions
Sourcepub fn set_hhomogeneous(&self, hhomogeneous: bool)
Available on crate feature v1_7 only.
pub fn set_hhomogeneous(&self, hhomogeneous: bool)
v1_7 only.Sets @self to be horizontally homogeneous or not.
If the view is horizontally homogeneous, it allocates the same width for all pages.
If it’s not, the view may change width when a different page becomes visible.
hhomogeneous
whether to make @self horizontally homogeneous
Sourcepub fn set_pop_on_escape(&self, pop_on_escape: bool)
pub fn set_pop_on_escape(&self, pop_on_escape: bool)
Sets whether pressing Escape pops the current page on @self.
Applications using NavigationView to implement a browser may want to
disable it.
pop_on_escape
whether to pop the current page when pressing Escape
Sourcepub fn set_vhomogeneous(&self, vhomogeneous: bool)
Available on crate feature v1_7 only.
pub fn set_vhomogeneous(&self, vhomogeneous: bool)
v1_7 only.Sets @self to be vertically homogeneous or not.
If the view is vertically homogeneous, it allocates the same height for all pages.
If it’s not, the view may change height when a different page becomes visible.
vhomogeneous
whether to make @self vertically homogeneous
Sourcepub fn connect_get_next_page<F: Fn(&Self) -> Option<NavigationPage> + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_get_next_page<F: Fn(&Self) -> Option<NavigationPage> + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when a push shortcut or a gesture is triggered.
To support the push shortcuts and gestures, the application is expected to return the page to push in the handler.
This signal can be emitted multiple times for the gestures, for example when the gesture is cancelled by the user. As such, the application must not make any irreversible changes in the handler, such as removing the page from a forward stack.
Instead, it should be done in the pushed handler.
Returns
the page to push
Sourcepub fn connect_popped<F: Fn(&Self, &NavigationPage) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_popped<F: Fn(&Self, &NavigationPage) + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted after @page has been popped from the navigation stack.
See pop().
When using pop_to_page() or
pop_to_tag(), this signal is emitted for each of the
popped pages.
page
the popped page
Sourcepub fn connect_pushed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_pushed<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted after a page has been pushed to the navigation stack.
See push().
Sourcepub fn connect_replaced<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_replaced<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted after the navigation stack has been replaced.
See replace().
pub fn connect_animate_transitions_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_hhomogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.pub fn connect_pop_on_escape_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_vhomogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.pub fn connect_visible_page_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_visible_page_tag_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.Trait Implementations
type ParamSpec = ParamSpecObject
Sourcetype SetValue = NavigationView
type SetValue = NavigationView
type BuilderFn = fn(&str) -> ParamSpecObjectBuilder<'_, NavigationView>
fn param_spec_builder() -> Self::BuilderFn
Sourcefn cmp(&self, other: &Self) -> Ordering
fn cmp(&self, other: &Self) -> Ordering
Comparison for two GObjects.
Compares the memory addresses of the provided objects.
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourcefn partial_cmp(&self, other: &OT) -> Option<Ordering>
fn partial_cmp(&self, other: &OT) -> Option<Ordering>
Partial comparison for two GObjects.
Compares the memory addresses of the provided objects.
Sourcefn static_type() -> Type
fn static_type() -> Type
Self.Auto Trait Implementations