pub struct OverlaySplitView { /* private fields */ }v1_4 only.Expand description
A widget presenting sidebar and content side by side or as an overlay.
OverlaySplitView has two children: sidebar and content, and displays
them side by side.
When collapsed is set to TRUE, the sidebar is
instead shown as an overlay above the content widget.
The sidebar can be hidden or shown using the
show-sidebar property.
Sidebar can be displayed before or after the content, this can be controlled
with the sidebar-position property.
Collapsing the split view automatically hides the sidebar widget, and
uncollapsing it shows the sidebar. If this behavior is not desired, the
pin-sidebar property can be used to override it.
OverlaySplitView supports an edge swipe gesture for showing the sidebar,
and a swipe from the sidebar for hiding it. Gestures are only supported on
touchscreen, but not touchpad. Gestures can be controlled with the
enable-show-gesture and
enable-hide-gesture properties.
See also NavigationSplitView.
OverlaySplitView is typically used together with an Breakpoint
setting the collapsed property to TRUE on small widths, as follows:
<object class="AdwWindow">
<property name="default-width">800</property>
<property name="default-height">800</property>
<child>
<object class="AdwBreakpoint">
<condition>max-width: 400sp</condition>
<setter object="split_view" property="collapsed">True</setter>
</object>
</child>
<property name="content">
<object class="AdwOverlaySplitView" id="split_view">
<property name="sidebar">
<!-- ... -->
</property>
<property name="content">
<!-- ... -->
</property>
</object>
</property>
</object>OverlaySplitView is often used for implementing the
utility pane
pattern.
Sizing
When not collapsed, OverlaySplitView changes the sidebar width
depending on its own width.
If possible, it tries to allocate a fraction of the total width, controlled
with the sidebar-width-fraction property.
The sidebar also has minimum and maximum sizes, controlled with the
min-sidebar-width and
max-sidebar-width properties.
The minimum and maximum sizes are using the length unit specified with the
sidebar-width-unit.
By default, sidebar is using 25% of the total width, with 180sp as the minimum size and 280sp as the maximum size.
When collapsed, the preferred width fraction is ignored and the sidebar uses
max-sidebar-width when possible.
Header Bar Integration
When used inside OverlaySplitView, HeaderBar will automatically
hide the window buttons in the middle.
OverlaySplitView as gtk::Buildable
The OverlaySplitView implementation of the gtk::Buildable
interface supports setting the sidebar widget by specifying “sidebar” as the
“type” attribute of a <child> element, Specifying “content” child type or
omitting it results in setting the content widget.
CSS nodes
OverlaySplitView has a single CSS node with the name
overlay-split-view.
It contains two nodes with the name widget, containing the sidebar and
content children.
When not collapsed, they have the .sidebar-view and .content-view style
classes respectively.
overlay-split-view
├── widget.sidebar-pane
│ ╰── [sidebar child]
╰── widget.content-pane
╰── [content child]When collapsed, the one containing the sidebar child has the .background
style class and the other one has no style classes.
overlay-split-view
├── widget.background
│ ╰── [sidebar child]
╰── widget
╰── [content child]Accessibility
OverlaySplitView uses the GTK_ACCESSIBLE_ROLE_GROUP role.
Properties
collapsed
Whether the split view is collapsed.
When collapsed, the sidebar widget is presented as an overlay above the content widget, otherwise they are displayed side by side.
Readable | Writeable
content
The content widget.
Readable | Writeable
enable-hide-gesture
Whether the sidebar can be closed with a swipe gesture.
Only touchscreen swipes are supported.
Readable | Writeable
enable-show-gesture
Whether the sidebar can be opened with an edge swipe gesture.
Only touchscreen swipes are supported.
Readable | Writeable
max-sidebar-width
The maximum sidebar width.
Maximum width is affected by
sidebar-width-unit.
The sidebar widget can still be allocated with larger width if its own minimum width exceeds it.
Readable | Writeable
min-sidebar-width
The minimum sidebar width.
Minimum width is affected by
sidebar-width-unit.
The sidebar widget can still be allocated with larger width if its own minimum width exceeds it.
Readable | Writeable
pin-sidebar
Whether the sidebar widget is pinned.
By default, collapsing @self_ automatically hides the sidebar widget, and
uncollapsing it shows the sidebar. If set to TRUE, sidebar visibility
never changes on its own.
Readable | Writeable
show-sidebar
Whether the sidebar widget is shown.
Readable | Writeable
sidebar
The sidebar widget.
Readable | Writeable
sidebar-position
The sidebar position.
If it’s set to GTK_PACK_START, the sidebar is displayed before the content,
if GTK_PACK_END, it’s displayed after the content.
Readable | Writeable
sidebar-width-fraction
The preferred sidebar width as a fraction of the total width.
The preferred width is additionally limited by
min-sidebar-width and
max-sidebar-width.
The sidebar widget can be allocated with larger width if its own minimum width exceeds the preferred width.
Readable | Writeable
sidebar-width-unit
The length unit for minimum and maximum sidebar widths.
See min-sidebar-width and
max-sidebar-width.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, SwipeableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl OverlaySplitView
impl OverlaySplitView
Sourcepub fn new() -> OverlaySplitView
pub fn new() -> OverlaySplitView
Sourcepub fn builder() -> OverlaySplitViewBuilder
pub fn builder() -> OverlaySplitViewBuilder
Creates a new builder-pattern struct instance to construct OverlaySplitView objects.
This method returns an instance of OverlaySplitViewBuilder which can be used to create OverlaySplitView objects.
Sourcepub fn is_collapsed(&self) -> bool
pub fn is_collapsed(&self) -> bool
Sourcepub fn enables_hide_gesture(&self) -> bool
pub fn enables_hide_gesture(&self) -> bool
Gets whether @self can be closed with a swipe gesture.
Returns
TRUE if @self can be closed with a swipe gesture
Sourcepub fn enables_show_gesture(&self) -> bool
pub fn enables_show_gesture(&self) -> bool
Gets whether @self can be opened with an edge swipe gesture.
Returns
TRUE if @self can be opened with a swipe gesture
Gets whether the sidebar widget is pinned for @self.
Returns
whether if the sidebar widget is pinned
Sourcepub fn set_collapsed(&self, collapsed: bool)
pub fn set_collapsed(&self, collapsed: bool)
Sets whether @self view is collapsed.
When collapsed, the sidebar widget is presented as an overlay above the content widget, otherwise they are displayed side by side.
collapsed
whether @self is collapsed
Sourcepub fn set_content(&self, content: Option<&impl IsA<Widget>>)
pub fn set_content(&self, content: Option<&impl IsA<Widget>>)
Sourcepub fn set_enable_hide_gesture(&self, enable_hide_gesture: bool)
pub fn set_enable_hide_gesture(&self, enable_hide_gesture: bool)
Sets whether @self can be closed with a swipe gesture.
Only touchscreen swipes are supported.
enable_hide_gesture
whether @self can be closed with a swipe gesture
Sourcepub fn set_enable_show_gesture(&self, enable_show_gesture: bool)
pub fn set_enable_show_gesture(&self, enable_show_gesture: bool)
Sets whether @self can be opened with an edge swipe gesture.
Only touchscreen swipes are supported.
enable_show_gesture
whether @self can be opened with a swipe gesture
Sets the maximum sidebar width for @self.
Maximum width is affected by sidebar-width-unit.
The sidebar widget can still be allocated with larger width if its own minimum width exceeds it.
width
the maximum width
Sets the minimum sidebar width for @self.
Minimum width is affected by sidebar-width-unit.
The sidebar widget can still be allocated with larger width if its own minimum width exceeds it.
width
the minimum width
Sets whether the sidebar widget is pinned for @self.
By default, collapsing @self automatically hides the sidebar widget, and
uncollapsing it shows the sidebar. If set to TRUE, sidebar visibility never
changes on its own.
pin_sidebar
whether to pin the sidebar widget
Sets whether the sidebar widget is shown for @self.
show_sidebar
whether to show the sidebar widget
Sets the sidebar position for @self.
If it’s set to GTK_PACK_START, the sidebar is displayed before the content,
if GTK_PACK_END, it’s displayed after the content.
position
the new position
Sets the preferred sidebar width as a fraction of the total width of @self.
The preferred width is additionally limited by
min-sidebar-width and
max-sidebar-width.
The sidebar widget can be allocated with larger width if its own minimum width exceeds the preferred width.
fraction
the preferred width fraction
Sets the length unit for minimum and maximum sidebar widths.
See min-sidebar-width and
max-sidebar-width.
unit
the length unit
pub fn connect_collapsed_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_content_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enable_hide_gesture_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enable_show_gesture_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId