pub struct SidebarItem { /* private fields */ }v1_9 only.Expand description
An item within SidebarSection.
Sidebar items must have a title, set via title.
Sidebar items should, but are not required to, have an icon. Icons can be set
from an icon name, via icon-name, or a
gdk::Paintable, via icon-paintable.
Items can also have subtitles, set with the subtitle
property. Subtitles should be used sparingly.
To add a tooltip, use tooltip. Tooltips always use
Pango markup.
Items can have an arbitrary suffix widget, set with the
suffix properties. It will be displayed at the end of
its row, or before the arrow in the [enum@Adw.SidebarMode.PAGE] mode.
To hide or disable the item, use the visible and
enabled properties respectively.
To access the items’s section, use section.
It’s also possible to access the index of the item in both the section and
the sidebar, using SidebarItemExt::section_index() and
SidebarItemExt::index() respectively.
Dragging content over sidebar items activates them by default. To disable
this behavior, set drag-motion-activate to FALSE.
SidebarItem is derivable, and applications that need to associate each
page with data can store it in the items themselves this way.
Properties
drag-motion-activate
Whether to activate the item on pointer motion during Drag-and-Drop.
This is needed to be able to drag content into the page the item represents, when the sidebar is used as a page switcher. However, it may be unwanted when dropping content onto the item itself, so it can be disabled.
Readable | Writeable
enabled
Whether the item is enabled.
See sensitive.
Readable | Writeable
icon-name
The icon name for this item.
Mutually exclusive with icon-paintable.
Readable | Writeable
icon-paintable
The paintable to use as the icon for this item.
Mutually exclusive with icon-name.
Readable | Writeable
section
The section the item is in.
Readable
subtitle
Subtitle of the item.
Readable | Writeable
suffix
The suffix widget for this item.
Suffix will be shown at the end of the item’s row, or before the arrow in the [enum@Adw.SidebarMode.PAGE] mode.
Readable | Writeable
title
Title of the item.
Readable | Writeable
tooltip
The tooltip of the item.
The tooltip can be marked up with the Pango text markup language.
Readable | Writeable
use-underline
Whether an underline in the title indicates a mnemonic.
The mnemonic can be used to activate the item.
Readable | Writeable
visible
Whether the item is visible.
Readable | Writeable
Implements
SidebarItemExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl SidebarItem
impl SidebarItem
pub const NONE: Option<&'static SidebarItem> = None
Sourcepub fn new(title: &str) -> SidebarItem
pub fn new(title: &str) -> SidebarItem
Creates a new SidebarItem with @title as its title.
title
the item title
Returns
the newly created SidebarItem
Sourcepub fn builder() -> SidebarItemBuilder
pub fn builder() -> SidebarItemBuilder
Creates a new builder-pattern struct instance to construct SidebarItem objects.
This method returns an instance of SidebarItemBuilder which can be used to create SidebarItem objects.