SidebarSection

Struct SidebarSection 

pub struct SidebarSection { /* private fields */ }
Available on crate feature v1_9 only.
/picture

Properties

items

A list model with the section’s items.

This can be used to keep an up-to-date view.

Readable

Context menu model for the section items.

When a context menu is shown for an item, it will be constructed from the provided menu model. Use the setup-menu signal to set up the menu actions for the particular item.

If not set, menu-model will be used instead.

Readable | Writable

The sidebar the section is in.

Readable

title

Title of the section.

If set, it will be displayed instead of the separator before the section.

Readable | Writable

Implements

[trait@glib::ObjectExt], gtk::prelude::BuildableExt

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl SidebarSection

pub fn new() -> SidebarSection

Creates a new SidebarSection.

Returns

the newly created SidebarSection

pub fn append(&self, item: impl IsA<SidebarItem>)

Appends @item to @self.

Cannot be used while a model is bound via bind_model().

item

an item to append

pub fn bind_model<P: Fn(&Object) -> SidebarItem + 'static>( &self, model: Option<&impl IsA<ListModel>>, create_item_func: P, )

Binds @model to @self.

If @self was already bound to a model, that previous binding is destroyed.

The contents of @self are cleared and then filled with items that represent items from @model. @self is updated whenever @model changes.

If @model is NULL, @self is left empty.

Calling prepend(), insert(), append(), remove() or remove_all() while a model is bound is not allowed.

Accessing items and modifying them is allowed, but the changes will be erased whenever that part of the model changes, so it’s not recommended.

model

the model to be bound

create_item_func
a function that creates [`SidebarItem`][crate::SidebarItem] for model items, or `NULL` in
case @model is also `NULL`
pub fn item(&self, index: u32) -> Option<SidebarItem>

Gets the item at @index within @self.

The index starts from 0 at the top of the section, and is same as the one returned by SidebarItemExt::section_index().

Can return NULL if @index is larger or equal to the number of items.

index

index of the item

Returns

the item at @index

pub fn items(&self) -> ListModel

Gets a list model with @self’s items.

This can be used to keep an up-to-date view.

Returns

a model containing the items

pub fn menu_model(&self) -> Option<MenuModel>

Gets the context menu model for @self’s items.

Returns

the context menu model

pub fn sidebar(&self) -> Option<Sidebar>

Gets the sidebar @self is in.

Returns

the sidebar of @self

pub fn title(&self) -> Option<GString>

Gets the title of @self.

Returns

the title

pub fn insert(&self, item: impl IsA<SidebarItem>, position: i32)

Inserts @item at @position to @self.

If @position is -1, or larger than the total number of items in @self, the item will be appended to the end.

Cannot be used while a model is bound via bind_model().

item

an item to insert

position

position to insert @item at

pub fn prepend(&self, item: impl IsA<SidebarItem>)

Prepends @item to @self.

Cannot be used while a model is bound via bind_model().

item

an item to prepend

pub fn remove(&self, item: &impl IsA<SidebarItem>)

Removes @item from @self.

Cannot be used while a model is bound via bind_model().

item

an item to remove

pub fn remove_all(&self)

Removes all items from @self.

Cannot be used while a model is bound via bind_model().

pub fn set_menu_model(&self, menu_model: Option<&impl IsA<MenuModel>>)

Sets the context menu model for @self’s items.

When a context menu is shown for an item, it will be constructed from the provided menu model. Use the setup-menu signal to set up the menu actions for the particular item.

If not set, menu-model will be used instead.

a menu model

pub fn set_title(&self, title: Option<&str>)

Sets the title of @self.

If set, it will be displayed instead of the separator before the section.

title

the title

pub fn connect_items_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_menu_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_sidebar_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Source

impl SidebarSection

pub fn unbind_model(&self)