pub struct SpinRow { /* private fields */ }v1_4 only.Expand description
See `Gtk::SpinButton` for details.
## CSS nodes
[`SpinRow`][crate::SpinRow] has the same structure as [`ActionRow`][crate::ActionRow], as well as the
`.spin` style class on the main node.
## Accessibility
[`SpinRow`][crate::SpinRow] uses an internal `GtkSpinButton` with the
[enum@Gtk.AccessibleRole.spin-button] role.
## Properties
#### `adjustment`
The adjustment that holds the value of the spin row.
Readable | Writable
#### `climb-rate`
The acceleration rate when you hold down a button or key.
Readable | Writable
#### `digits`
The number of decimal places to display.
Readable | Writable
#### `numeric`
Whether non-numeric characters should be ignored.
Readable | Writable
#### `snap-to-ticks`
Whether invalid values are snapped to the nearest step increment.
Readable | Writable
#### `update-policy`
The policy for updating the spin row.
The options are always, or only when the value is invalid.
Readable | Writable
#### `value`
The current value.
Readable | Writable
#### `wrap`
Whether the spin row should wrap upon reaching its limits.
Readable | Writable
<details><summary><h4>ActionRow</h4></summary>
#### `activatable-widget`
The widget to activate when the row is activated.
The row can be activated either by clicking on it, calling
[`ActionRowExt::activate()`][crate::prelude::ActionRowExt::activate()], or via mnemonics in the title.
See the [`use-underline`][struct@crate::PreferencesRow#use-underline] property to enable
mnemonics.
The target widget will be activated by emitting the
[`mnemonic-activate`][struct@crate::gtk::Widget#mnemonic-activate] signal on it.
Readable | Writable
#### `icon-name`
The icon name for this row.
Readable | Writable
#### `subtitle`
The subtitle for this row.
The subtitle is interpreted as Pango markup unless
[`use-markup`][struct@crate::PreferencesRow#use-markup] is set to `FALSE`.
Readable | Writable
#### `subtitle-lines`
The number of lines at the end of which the subtitle label will be
ellipsized.
If the value is 0, the number of lines won't be limited.
Readable | Writable
#### `subtitle-selectable`
Whether the user can copy the subtitle from the label.
See also [`selectable`][struct@crate::Gtk::Label#selectable].
Readable | Writable
#### `title-lines`
The number of lines at the end of which the title label will be ellipsized.
If the value is 0, the number of lines won't be limited.
Readable | Writable
</details>
<details><summary><h4>PreferencesRow</h4></summary>
#### `title`
The title of the preference represented by this row.
The title is interpreted as Pango markup unless
[`use-markup`][struct@crate::PreferencesRow#use-markup] is set to `FALSE`.
Readable | Writable
#### `title-selectable`
Whether the user can copy the title from the label.
See also [`selectable`][struct@crate::Gtk::Label#selectable].
Readable | Writable
#### `use-markup`
Whether to use Pango markup for the title label.
Subclasses may also use it for other labels, such as subtitle.
See also `parse_markup()`.
Readable | Writable
#### `use-underline`
Whether an embedded underline in the title indicates a mnemonic.
Readable | Writable
</details>
<details><summary><h4>ListBoxRow</h4></summary>
#### `activatable`
Determines whether the ::row-activated
signal will be emitted for this row.
Readable | Writable
#### `child`
The child widget.
Readable | Writable
#### `selectable`
Determines whether this row can be selected.
Readable | Writable
</details>
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`gtk::LayoutManager`][crate::gtk::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See `Gtk::EventController::set_propagation_limit()`.
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`gtk::Root`][crate::gtk::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see `Gtk::Tooltip::set_markup()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see `Gtk::Tooltip::set_text()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`gtk::Accessible`][crate::gtk::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
<details><summary><h4>Actionable</h4></summary>
#### `action-name`
The name of the action with which this widget should be associated.
Readable | Writable
#### `action-target`
The target value of the actionable widget's action.
Readable | Writable
</details>
<details><summary><h4>Editable</h4></summary>
#### `complete-text`
The contents of the entry, including uncommited content such as the
preedit.
Readable
#### `cursor-position`
The current position of the insertion cursor in chars.
Readable
#### `editable`
Whether the entry contents can be edited.
Readable | Writable
#### `enable-undo`
If undo/redo should be enabled for the editable.
Readable | Writable
#### `max-width-chars`
The desired maximum width of the entry, in characters.
Readable | Writable
#### `selection-bound`
The position of the opposite end of the selection from the cursor in chars.
Readable
#### `text`
The contents of the entry.
Readable | Writable
#### `width-chars`
Number of characters to leave space for in the entry.
Readable | Writable
#### `xalign`
The horizontal alignment, from 0 (left) to 1 (right).
Reversed for RTL layouts.
Readable | Writable
</details>
## Signals
#### `input`
Emitted to convert the user's input into a double value.
The signal handler is expected to use [`EditableExtManual::text()`][crate::gtk::prelude::EditableExtManual::text()] to
retrieve the text of the spinbutton and set new_value to the new value.
The default conversion uses `strtod()`.
See [`input`][struct@crate::Gtk::SpinButton#input].
#### `output`
Emitted to tweak the formatting of the value for display.
See [`output`][struct@crate::Gtk::SpinButton#output].
#### `wrapped`
Emitted right after the spinbutton wraps.
See [`wrapped`][struct@crate::Gtk::SpinButton#wrapped].
<details><summary><h4>ActionRow</h4></summary>
#### `activated`
This signal is emitted after the row has been activated.
</details>
<details><summary><h4>ListBoxRow</h4></summary>
#### `activate`
s parent
`GtkListBox`.
Action
</details>
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExtManual::keynav_failed()`][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::gtk::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::gtk::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a `GdkSurface`.
This means that [`WidgetExtManual::realize()`][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExtManual::state_flags()`][crate::gtk::prelude::WidgetExtManual::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the `GdkSurface` associated with @widget is destroyed.
This means that [`WidgetExtManual::unrealize()`][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
<details><summary><h4>Editable</h4></summary>
#### `changed`
Emitted at the end of a single user-visible operation on the
contents.
E.g., a paste operation that replaces the contents of the
selection will cause only one signal emission (even though it
is implemented by first deleting the selection, then inserting
the new content, and may cause multiple ::notify::text signals
to be emitted).
#### `delete-text`
Emitted when text is deleted from the widget by the user.
The default handler for this signal will normally be responsible for
deleting the text, so by connecting to this signal and then stopping
the signal with g_signal_stop_emission(), it is possible to modify the
range of deleted text, or prevent it from being deleted entirely.
The @start_pos and @end_pos parameters are interpreted as for
[`EditableExtManual::delete_text()`][crate::gtk::prelude::EditableExtManual::delete_text()].
#### `insert-text`
Emitted when text is inserted into the widget by the user.
The default handler for this signal will normally be responsible
for inserting the text, so by connecting to this signal and then
stopping the signal with g_signal_stop_emission(), it is possible
to modify the inserted text, or prevent it from being inserted entirely.
</details>
# Implements
[`ActionRowExt`][trait@crate::prelude::ActionRowExt], [`PreferencesRowExt`][trait@crate::prelude::PreferencesRowExt], [`trait@gtk::prelude::ListBoxRowExt`], [`trait@gtk::prelude::WidgetExt`], [`trait@glib::ObjectExt`], [`trait@gtk::prelude::AccessibleExt`], [`trait@gtk::prelude::BuildableExt`], [`trait@gtk::prelude::ConstraintTargetExt`], [`trait@gtk::prelude::ActionableExt`], [`trait@gtk::prelude::EditableExt`]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl SpinRow
impl SpinRow
Sourcepub fn new(
adjustment: Option<&impl IsA<Adjustment>>,
climb_rate: f64,
digits: u32,
) -> SpinRow
pub fn new( adjustment: Option<&impl IsA<Adjustment>>, climb_rate: f64, digits: u32, ) -> SpinRow
Sourcepub fn with_range(min: f64, max: f64, step: f64) -> SpinRow
pub fn with_range(min: f64, max: f64, step: f64) -> SpinRow
Creates a new SpinRow with the given properties.
This is a convenience constructor that allows creation of a numeric
SpinRow without manually creating an adjustment. The value is initially
set to the minimum value and a page increment of 10 * @step is the default.
The precision of the spin row is equivalent to the precisions of @step.
::: note
The way in which the precision is derived works best if @step is a power
of ten. If the resulting precision is not suitable for your needs, use
set_digits() to correct it.
min
minimum allowable value
max
maximum allowable value
step
increment added or subtracted by spinning the widget
Returns
the new SpinRow
Sourcepub fn builder() -> SpinRowBuilder
pub fn builder() -> SpinRowBuilder
Creates a new builder-pattern struct instance to construct SpinRow objects.
This method returns an instance of SpinRowBuilder which can be used to create SpinRow objects.
Sourcepub fn configure(
&self,
adjustment: Option<&impl IsA<Adjustment>>,
climb_rate: f64,
digits: u32,
)
pub fn configure( &self, adjustment: Option<&impl IsA<Adjustment>>, climb_rate: f64, digits: u32, )
Sourcepub fn adjustment(&self) -> Adjustment
pub fn adjustment(&self) -> Adjustment
Gets the adjustment that holds the value for the spin row.
Returns
the adjustment that holds the spin row’s value
Sourcepub fn climb_rate(&self) -> f64
pub fn climb_rate(&self) -> f64
Gets the acceleration rate when you hold down a button or key.
Returns
the acceleration rate when you hold down a button or key
Sourcepub fn is_numeric(&self) -> bool
pub fn is_numeric(&self) -> bool
Gets whether non-numeric characters should be ignored.
Returns
whether non-numeric characters should be ignored.
Sourcepub fn snaps_to_ticks(&self) -> bool
pub fn snaps_to_ticks(&self) -> bool
Gets whether invalid values are snapped to nearest step increment.
Returns
whether invalid values are snapped to the nearest step increment
Sourcepub fn update_policy(&self) -> SpinButtonUpdatePolicy
pub fn update_policy(&self) -> SpinButtonUpdatePolicy
Sourcepub fn wraps(&self) -> bool
pub fn wraps(&self) -> bool
Gets whether the spin row should wrap upon reaching its limits.
Returns
whether the spin row should wrap upon reaching its limits
Sourcepub fn set_adjustment(&self, adjustment: Option<&impl IsA<Adjustment>>)
pub fn set_adjustment(&self, adjustment: Option<&impl IsA<Adjustment>>)
Sourcepub fn set_climb_rate(&self, climb_rate: f64)
pub fn set_climb_rate(&self, climb_rate: f64)
Sets the acceleration rate when you hold down a button or key.
climb_rate
the acceleration rate when you hold down a button or key
Sourcepub fn set_digits(&self, digits: u32)
pub fn set_digits(&self, digits: u32)
Sourcepub fn set_numeric(&self, numeric: bool)
pub fn set_numeric(&self, numeric: bool)
Sets whether non-numeric characters should be ignored.
numeric
whether non-numeric characters should be ignored
Sourcepub fn set_snap_to_ticks(&self, snap_to_ticks: bool)
pub fn set_snap_to_ticks(&self, snap_to_ticks: bool)
Sets whether invalid values are snapped to the nearest step increment.
snap_to_ticks
whether invalid values are snapped to the nearest step increment
Sourcepub fn set_update_policy(&self, policy: SpinButtonUpdatePolicy)
pub fn set_update_policy(&self, policy: SpinButtonUpdatePolicy)
Sets the policy for updating the spin row.
The options are always, or only when the value is invalid.
policy
the policy for updating the spin row
Sourcepub fn set_wrap(&self, wrap: bool)
pub fn set_wrap(&self, wrap: bool)
Sets whether the spin row should wrap upon reaching its limits.
wrap
whether the spin row should wrap upon reaching its limits
Sourcepub fn connect_output<F: Fn(&Self) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_output<F: Fn(&Self) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted to tweak the formatting of the value for display.
See [output][struct@crate::Gtk::SpinButton#output].
Returns
TRUE if the value has been displayed
Sourcepub fn connect_wrapped<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_wrapped<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted right after the spinbutton wraps.
See [wrapped][struct@crate::Gtk::SpinButton#wrapped].
pub fn connect_adjustment_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_climb_rate_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_digits_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_numeric_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_snap_to_ticks_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_update_policy_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_value_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_wrap_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl SpinRow
impl SpinRow
Sourcepub fn connect_input<F>(&self, f: F) -> SignalHandlerId
pub fn connect_input<F>(&self, f: F) -> SignalHandlerId
Emitted to convert the user’s input into a double value.
The signal handler is expected to use [EditableExtManual::text()][crate::gtk::prelude::EditableExtManual::text()] to
retrieve the text of the spinbutton and set new_value to the new value.
The default conversion uses strtod().
See [input][struct@crate::Gtk::SpinButton#input].
Returns
TRUE for a successful conversion, FALSE if the input was not
handled, and Gtk::INPUT_ERROR if the conversion failed.
new_value
return location for the new value