pub struct SplitButton { /* private fields */ }Expand description
A combined button and dropdown widget.
SplitButton is typically used to present a set of actions in a menu,
but allow access to one of them with a single click.
The API is very similar to Gtk::Button and Gtk::MenuButton, see
their documentation for details.
CSS nodes
splitbutton[.image-button][.text-button]
├── button
│ ╰── <content>
├── separator
╰── menubutton
╰── button.toggle
╰── arrowSplitButton’s CSS node is called splitbutton. It contains the css
nodes: button, separator, menubutton. See Gtk::MenuButton
documentation for the menubutton contents.
The main CSS node will contain the .image-button or .text-button style
classes matching the button contents. The nested button nodes will never
contain them.
Style classes
SplitButton can use some of the same style classes as Gtk::Button:
Other style classes, like .pill, cannot be used.
Accessibility
SplitButton uses the GTK_ACCESSIBLE_ROLE_GROUP role.
Properties
can-shrink
Whether the button can be smaller than the natural size of its contents.
If set to TRUE, the label will ellipsize.
See [can-shrink][struct@crate::Gtk::Button#can-shrink] and
[can-shrink][struct@crate::Gtk::MenuButton#can-shrink].
Readable | Writeable
child
The child widget.
Setting the child widget will set label and
icon-name to NULL.
Readable | Writeable
direction
The direction in which the popup will be popped up.
The dropdown arrow icon will point at the same direction.
If the does not fit in the available space in the given direction, GTK will try its best to keep it inside the screen and fully visible.
If you pass GTK_ARROW_NONE, it’s equivalent to GTK_ARROW_DOWN.
Readable | Writeable
dropdown-tooltip
The tooltip of the dropdown button.
The tooltip can be marked up with the Pango text markup language.
Readable | Writeable
icon-name
The name of the icon used to automatically populate the button.
Setting the icon name will set label and
child to NULL.
Readable | Writeable
label
The label for the button.
Setting the label will set icon-name and
child to NULL.
Readable | Writeable
menu-model
The GMenuModel from which the popup will be created.
If the menu model is NULL, the dropdown is disabled.
A gtk::Popover will be created from the menu model with
Gtk::PopoverMenu::new_from_model(). Actions will be connected as
documented for this function.
If popover is already set, it will be dissociated
from the button, and the property is set to NULL.
Readable | Writeable
popover
The gtk::Popover that will be popped up when the dropdown is clicked.
If the popover is NULL, the dropdown is disabled.
If menu-model is set, the menu model is dissociated
from the button, and the property is set to NULL.
Readable | Writeable
use-underline
Whether an underline in the text indicates a mnemonic.
See label.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Actionable
action-name
The name of the action with which this widget should be associated.
Readable | Writeable
action-target
The target value of the actionable widget’s action.
Readable | Writeable
Signals
activate
Emitted to animate press then release.
This is an action signal. Applications should never connect to this signal,
but use the clicked signal.
Action
clicked
Emitted when the button has been activated (pressed and released).
Action
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, gtk::prelude::ActionableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl SplitButton
impl SplitButton
Sourcepub fn new() -> SplitButton
pub fn new() -> SplitButton
Sourcepub fn builder() -> SplitButtonBuilder
pub fn builder() -> SplitButtonBuilder
Creates a new builder-pattern struct instance to construct SplitButton objects.
This method returns an instance of SplitButtonBuilder which can be used to create SplitButton objects.
Sourcepub fn can_shrink(&self) -> bool
Available on crate feature v1_4 only.
pub fn can_shrink(&self) -> bool
v1_4 only.gets whether the button can be smaller than the natural size of its contents.
Returns
whether the button can shrink
Sourcepub fn dropdown_tooltip(&self) -> GString
Available on crate feature v1_2 only.
pub fn dropdown_tooltip(&self) -> GString
v1_2 only.Sourcepub fn uses_underline(&self) -> bool
pub fn uses_underline(&self) -> bool
Gets whether an underline in the text indicates a mnemonic.
Returns
whether an underline in the text indicates a mnemonic
Sourcepub fn set_can_shrink(&self, can_shrink: bool)
Available on crate feature v1_4 only.
pub fn set_can_shrink(&self, can_shrink: bool)
v1_4 only.Sets whether the button can be smaller than the natural size of its contents.
If set to TRUE, the label will ellipsize.
See Gtk::Button::set_can_shrink() and
Gtk::MenuButton::set_can_shrink().
can_shrink
whether the button can shrink
Sourcepub fn set_direction(&self, direction: ArrowType)
pub fn set_direction(&self, direction: ArrowType)
Sets the direction in which the popup will be popped up.
The dropdown arrow icon will point at the same direction.
If the does not fit in the available space in the given direction, GTK will try its best to keep it inside the screen and fully visible.
If you pass GTK_ARROW_NONE, it’s equivalent to GTK_ARROW_DOWN.
direction
the direction
Sourcepub fn set_dropdown_tooltip(&self, tooltip: &str)
Available on crate feature v1_2 only.
pub fn set_dropdown_tooltip(&self, tooltip: &str)
v1_2 only.Sets the tooltip of the dropdown button of @self.
The tooltip can be marked up with the Pango text markup language.
tooltip
the dropdown tooltip of @self
Sourcepub fn set_icon_name(&self, icon_name: &str)
pub fn set_icon_name(&self, icon_name: &str)
Sets the menu model from which the popup will be created.
If the menu model is NULL, the dropdown is disabled.
A gtk::Popover will be created from the menu model with
Gtk::PopoverMenu::new_from_model(). Actions will be connected as
documented for this function.
If popover is already set, it will be dissociated from
the button, and the property is set to NULL.
menu_model
the menu model
Sourcepub fn set_popover(&self, popover: Option<&impl IsA<Popover>>)
pub fn set_popover(&self, popover: Option<&impl IsA<Popover>>)
Sets the popover that will be popped up when the dropdown is clicked.
If the popover is NULL, the dropdown is disabled.
If menu-model is set, the menu model is dissociated
from the button, and the property is set to NULL.
popover
the popover
Sourcepub fn set_use_underline(&self, use_underline: bool)
pub fn set_use_underline(&self, use_underline: bool)
Sourcepub fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_activate<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted to animate press then release.
This is an action signal. Applications should never connect to this signal,
but use the clicked signal.
pub fn emit_activate(&self)
Sourcepub fn connect_clicked<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
pub fn connect_clicked<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
Emitted when the button has been activated (pressed and released).
pub fn emit_clicked(&self)
pub fn connect_can_shrink_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_4 only.pub fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_direction_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_dropdown_tooltip_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_2 only.pub fn connect_icon_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_label_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_popover_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_use_underline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId