pub struct TabOverview { /* private fields */ }v1_3 only.Expand description
A tab overview for TabView.
TabOverview is a widget that can display tabs from an TabView in a
grid.
TabOverview shows a thumbnail for each tab. By default thumbnails are
static for all pages except the selected one. They can be made always live
by setting live-thumbnail to TRUE, or refreshed with
TabPage::invalidate_thumbnail() or
TabView::invalidate_thumbnails() otherwise.
If the pages are too tall or too wide, the thumbnails will be cropped; use
thumbnail-xalign and thumbnail-yalign to
control which part of the page should be visible in this case.
Pinned tabs are shown as smaller cards without thumbnails above the other
tabs. Unlike in TabBar, they still have titles, as well as an unpin
button.
TabOverview provides search in open tabs. It searches in tab titles and
tooltips, as well as keyword.
If enable-new-tab is set to TRUE, a new tab button
will be shown. Connect to the create-tab signal to use
it.
secondary-menu can be used to provide a secondary menu
for the overview. Use it to add extra actions, e.g. to open a new window or
undo closed tab.
TabOverview is intended to be used as the direct child of the window,
with the rest of the window contents set as the child.
The child is expected to contain an TabView.
TabOverview shows window buttons by default. They can be disabled by
setting show-start-title-buttons and/or
show-start-title-buttons and/or
show-end-title-buttons to FALSE.
If search and window buttons are disabled, and secondary menu is not set, the header bar will be hidden.
Drag-and-Drop
TabOverview thumbnails can have an additional drop target for arbitrary
content.
Use setup_extra_drop_target() to set it up, specifying the
supported content types and drag actions, then connect to
extra-drag-drop to handle a drop.
In some cases, it may be necessary to determine the used action based on the
content. In that case, set extra-drag-preload to
TRUE and connect to extra-drag-value signal, then
return the action from its handler. To access this action from the
extra-drag-drop handler, use the
extra-drag-preferred-action property.
extra-drag-value is also always emitted when starting to
hover an item, with a NULL value. This happens even when
extra-drag-preload is FALSE.
Actions
TabOverview defines the overview.open and overview.close actions for
opening and closing itself. They can be convenient when used together with
TabButton.
CSS nodes
TabOverview has a single CSS node with name taboverview.
Properties
child
The child widget.
Readable | Writeable
enable-new-tab
Whether to enable new tab button.
Connect to the create-tab signal to use it.
Readable | Writeable
enable-search
Whether to enable search in tabs.
Search matches tab titles and tooltips, as well as keywords, set via
keyword. Use keywords to search in e.g. page URLs in a
web browser.
During search, tab reordering and drag-n-drop are disabled.
Use search-active to check out if search is
currently active.
Readable | Writeable
extra-drag-preferred-action
The current drag action during a drop.
This property should only be used from inside a
extra-drag-drop handler.
The action will be a subset of what was originally passed to
TabOverview::setup_extra_drop_target().
Readable
extra-drag-preload
Whether the drop data should be preloaded on hover.
See [preload][struct@crate::Gtk::DropTarget#preload].
Readable | Writeable
inverted
Whether thumbnails use inverted layout.
If set to TRUE, thumbnails will have the close or unpin buttons at the
beginning and the indicator at the end rather than the other way around.
Readable | Writeable
open
Whether the overview is open.
Readable | Writeable
search-active
Whether search is currently active.
See enable-search.
Readable
secondary-menu
The secondary menu model.
Use it to add extra actions, e.g. to open a new window or undo closed tab.
Readable | Writeable
show-end-title-buttons
Whether to show end title buttons in the overview’s header bar.
See show-start-title-buttons for the other side.
Readable | Writeable
show-start-title-buttons
Whether to show start title buttons in the overview’s header bar.
See show-end-title-buttons for the other side.
Readable | Writeable
view
The tab view the overview controls.
The view must be inside the tab overview, see child.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Signals
create-tab
Emitted when a tab needs to be created.
This can happen after the new tab button has been pressed, see
enable-new-tab.
The signal handler is expected to create a new page in the corresponding
TabView and return it.
extra-drag-drop
Emitted when content is dropped onto a tab.
The content must be of one of the types set up via
TabOverview::setup_extra_drop_target().
See [drop][struct@crate::Gtk::DropTarget#drop].
extra-drag-value
Emitted when the dropped content is preloaded.
In order for data to be preloaded, extra-drag-preload
must be set to TRUE.
The content must be of one of the types set up via
TabOverview::setup_extra_drop_target().
See [value][struct@crate::Gtk::DropTarget#value].
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TabOverview
impl TabOverview
Sourcepub fn new() -> TabOverview
pub fn new() -> TabOverview
Sourcepub fn builder() -> TabOverviewBuilder
pub fn builder() -> TabOverviewBuilder
Creates a new builder-pattern struct instance to construct TabOverview objects.
This method returns an instance of TabOverviewBuilder which can be used to create TabOverview objects.
Sourcepub fn enables_new_tab(&self) -> bool
pub fn enables_new_tab(&self) -> bool
Sourcepub fn enables_search(&self) -> bool
pub fn enables_search(&self) -> bool
Sourcepub fn extra_drag_preferred_action(&self) -> DragAction
Available on crate feature v1_4 only.
pub fn extra_drag_preferred_action(&self) -> DragAction
v1_4 only.Gets the current action during a drop on the extra_drop_target.
Returns
the drag action of the current drop.
Sourcepub fn is_extra_drag_preload(&self) -> bool
pub fn is_extra_drag_preload(&self) -> bool
Gets the current drag action during a drop.
This method should only be used from inside a
extra-drag-drop handler.
The action will be a subset of what was originally passed to
setup_extra_drop_target().
Returns
the drag action of the current drop
Sourcepub fn is_inverted(&self) -> bool
pub fn is_inverted(&self) -> bool
Sourcepub fn is_search_active(&self) -> bool
pub fn is_search_active(&self) -> bool
Gets whether search is currently active for @self.
See enable-search.
Returns
whether search is active
Gets whether end title buttons are shown in @self’s header bar.
Returns
whether end title buttons are shown
Gets whether start title buttons are shown in @self’s header bar.
Returns
whether start title buttons are shown
Sourcepub fn set_enable_new_tab(&self, enable_new_tab: bool)
pub fn set_enable_new_tab(&self, enable_new_tab: bool)
Sets whether to enable new tab button for @self.
Connect to the create-tab signal to use it.
enable_new_tab
whether to enable new tab button
Sourcepub fn set_enable_search(&self, enable_search: bool)
pub fn set_enable_search(&self, enable_search: bool)
Sets whether to enable search in tabs for @self.
Search matches tab titles and tooltips, as well as keywords, set via
keyword. Use keywords to search in e.g. page URLs in a web
browser.
During search, tab reordering and drag-n-drop are disabled.
Use search-active to check out if search is currently
active.
enable_search
whether to enable search
Sourcepub fn set_extra_drag_preload(&self, preload: bool)
pub fn set_extra_drag_preload(&self, preload: bool)
Sets whether drop data should be preloaded on hover.
See [preload][struct@crate::Gtk::DropTarget#preload].
preload
whether to preload drop data
Sourcepub fn set_inverted(&self, inverted: bool)
pub fn set_inverted(&self, inverted: bool)
Sets whether thumbnails use inverted layout.
If set to TRUE, thumbnails will have the close or unpin button at the
beginning and the indicator at the end rather than the other way around.
inverted
whether thumbnails use inverted layout
Sets the secondary menu model for @self.
Use it to add extra actions, e.g. to open a new window or undo closed tab.
secondary_menu
a menu model
Sets whether to show end title buttons in @self’s header bar.
See show-start-title-buttons for the other side.
show_end_title_buttons
whether to show end title buttons
Sets whether to show start title buttons in @self’s header bar.
See show-end-title-buttons for the other side.
show_start_title_buttons
whether to show start title buttons
Sourcepub fn connect_create_tab<F: Fn(&Self) -> TabPage + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_create_tab<F: Fn(&Self) -> TabPage + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when a tab needs to be created.
This can happen after the new tab button has been pressed, see
enable-new-tab.
The signal handler is expected to create a new page in the corresponding
TabView and return it.
Returns
the newly created page
Sourcepub fn connect_extra_drag_drop<F: Fn(&Self, &TabPage, &Value) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_extra_drag_drop<F: Fn(&Self, &TabPage, &Value) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when content is dropped onto a tab.
The content must be of one of the types set up via
setup_extra_drop_target().
See [drop][struct@crate::Gtk::DropTarget#drop].
page
the page matching the tab the content was dropped onto
value
the GValue being dropped
Returns
whether the drop was accepted
Sourcepub fn connect_extra_drag_value<F: Fn(&Self, &TabPage, Option<&Value>) -> DragAction + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_extra_drag_value<F: Fn(&Self, &TabPage, Option<&Value>) -> DragAction + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the dropped content is preloaded.
In order for data to be preloaded, extra-drag-preload
must be set to TRUE.
The content must be of one of the types set up via
setup_extra_drop_target().
See [value][struct@crate::Gtk::DropTarget#value].
page
the page matching the tab the content was dropped onto
value
the GValue being dropped
Returns
the preferred action for the drop
pub fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enable_new_tab_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enable_search_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_extra_drag_preferred_action_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_4 only.pub fn connect_extra_drag_preload_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_inverted_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_open_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_search_active_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_view_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl TabOverview
impl TabOverview
Sourcepub fn setup_extra_drop_target(&self, actions: DragAction, types: &[Type])
pub fn setup_extra_drop_target(&self, actions: DragAction, types: &[Type])
Sets up an extra drop target on tabs.
This allows to drag arbitrary content onto tabs, for example URLs in a web browser.
If a tab is hovered for a certain period of time while dragging the content, it will be automatically selected.
The extra-drag-drop signal can be used to handle the
drop.
actions
the supported actions
types
all supported GTypes that can be dropped