pub struct ToggleGroup { /* private fields */ }v1_7 only.Expand description
A group of exclusive toggles.
ToggleGroup presents a set of exclusive toggles, represented as
Toggle objects. Each toggle can display an icon, a label, an icon
and a label, or a custom child.
Toggles are indexed by their position, with the first toggle being equivalent
to 0, and so on. Use the active to get that position.
Toggles can also have optional names, set via the name
property. The name of the active toggle can be accessed via the
active-name property.
Toggle objects can be retrieved via their index or name, using
toggle() or toggle_by_name()
respectively. ToggleGroup also provides a gtk::SelectionModel of
its toggles via the toggles property.
ToggleGroup is orientable, and the toggles can be displayed horizontally
or vertically. This is mostly useful for icon-only toggles.
Use the homogeneous property to make the toggles take
the same size, and the can-shrink to control whether
the toggles can ellipsize.
Example of an ToggleGroup UI definition:
<object class="AdwToggleGroup">
<property name="active-name">picture</property>
<child>
<object class="AdwToggle">
<property name="icon-name">camera-photo-symbolic</property>
<property name="tooltip" translatable="yes">Picture Mode</property>
<property name="name">picture</property>
</object>
</child>
<child>
<object class="AdwToggle">
<property name="icon-name">camera-video-symbolic</property>
<property name="tooltip" translatable="yes">Recording Mode</property>
<property name="name">recording</property>
</object>
</child>
</object>See also: InlineViewSwitcher.
CSS nodes
ToggleGroup has a main CSS node with the name toggle-group.
Its toggles have CSS nodes with the name toggle, and its separators have nodes
with the name separator.
Toggle nodes will have a different style classes depending on their content:
.text-button for labels, .image-button for icons, .image-text-button
for both or no style class for custom children.
The hidden separators use the .hidden style class.
Style classes
ToggleGroup can use the .flat style class
to remove its background and make it look like a group of buttons.
It can also use the .round style class to make
its toggles and the group itself rounded.
They can also be combined with each other.
Accessibility
ToggleGroup uses the GTK_ACCESSIBLE_ROLE_RADIO_GROUP role. Its toggles
use the GTK_ACCESSIBLE_ROLE_RADIO role.
Properties
active
The index of the active toggle.
Setting the index to a larger value than the number of toggles in the group unsets the current active toggle.
If no toggle is active, the property will be set to
Gtk::INVALID_LIST_POSITION.
Readable | Writeable
active-name
The name of the active toggle.
The name can be set via name. If the currently active
toggle doesn’t have a name, the property will be set to NULL.
Set it to NULL to unset the current active toggle.
Readable | Writeable
can-shrink
Whether the toggles can be smaller than the natural size of their contents.
If set to TRUE, the toggle labels will ellipsize.
See [can-shrink][struct@crate::Gtk::Button#can-shrink].
Readable | Writeable
homogeneous
Whether all toggles take the same size.
Readable | Writeable
n-toggles
The number of toggles within the group.
Readable
toggles
A selection model with the groups’s toggles.
This can be used to keep an up-to-date view. The model also implements
gtk::SelectionModel and can be used to track and change the active
toggle.
Readable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, gtk::prelude::OrientableExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ToggleGroup
impl ToggleGroup
Sourcepub fn new() -> ToggleGroup
pub fn new() -> ToggleGroup
Sourcepub fn builder() -> ToggleGroupBuilder
pub fn builder() -> ToggleGroupBuilder
Creates a new builder-pattern struct instance to construct ToggleGroup objects.
This method returns an instance of ToggleGroupBuilder which can be used to create ToggleGroup objects.
Sourcepub fn active(&self) -> u32
pub fn active(&self) -> u32
Gets the index of the active toggle in @self.
Returns GTK_INVALID_LIST_POSITION if no toggle is active.
Returns
the active toggle index
Sourcepub fn active_name(&self) -> Option<GString>
pub fn active_name(&self) -> Option<GString>
Sourcepub fn can_shrink(&self) -> bool
pub fn can_shrink(&self) -> bool
Gets whether the toggles can be smaller than the natural size of their contents.
Returns
whether the toggles can shrink
Sourcepub fn is_homogeneous(&self) -> bool
pub fn is_homogeneous(&self) -> bool
Sourcepub fn toggle_by_name(&self, name: &str) -> Option<Toggle>
pub fn toggle_by_name(&self, name: &str) -> Option<Toggle>
Sourcepub fn toggles(&self) -> SelectionModel
pub fn toggles(&self) -> SelectionModel
Returns a gio::ListModel that contains the toggles of the group.
This can be used to keep an up-to-date view. The model also implements
gtk::SelectionModel and can be used to track and change the active
toggle.
Returns
a gtk::SelectionModel for the group’s toggles
Sourcepub fn remove_all(&self)
pub fn remove_all(&self)
Removes all toggles from @self.
Sourcepub fn set_active(&self, active: u32)
pub fn set_active(&self, active: u32)
Sets the active toggle for @self.
If the index is larger than the number of toggles in @self, unsets the current active toggle.
active
toggle index
Sourcepub fn set_active_name(&self, name: Option<&str>)
pub fn set_active_name(&self, name: Option<&str>)
Sourcepub fn set_can_shrink(&self, can_shrink: bool)
pub fn set_can_shrink(&self, can_shrink: bool)
Sets whether the toggles can be smaller than the natural size of their contents.
If @can_shrink is TRUE, the toggle labels will ellipsize.
See [can-shrink][struct@crate::Gtk::Button#can-shrink].
can_shrink
whether the toggles can shrink
Sourcepub fn set_homogeneous(&self, homogeneous: bool)
pub fn set_homogeneous(&self, homogeneous: bool)
Sets whether all toggles take the same size.
homogeneous
whether all toggles should take the same size
pub fn connect_active_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_active_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_can_shrink_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_homogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_n_toggles_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_toggles_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId