pub struct ToolbarView { /* private fields */ }v1_4 only.Expand description
A widget containing a page, as well as top and/or bottom bars.
ToolbarView has a single content widget and one or multiple top and
bottom bars, shown at the top and bottom sides respectively.
Example of an ToolbarView UI definition:
<object class="AdwToolbarView">
<child type="top">
<object class="AdwHeaderBar"/>
</child>
<property name="content">
<object class="AdwPreferencesPage">
<!-- ... -->
</object>
</property>
</object>The following kinds of top and bottom bars are supported:
HeaderBarTabBarViewSwitcherBarGtk::ActionBargtk::HeaderBarGtk::PopoverMenuBarGtk::SearchBar- Any
Gtk::Boxor a similar widget with the.toolbarstyle class
By default, top and bottom bars are flat and scrolling content has a subtle
undershoot shadow, same as when using the
.undershoot-top and
.undershoot-bottom style
classes. This works well in most cases, e.g. with StatusPage or
PreferencesPage, where the background at the top and bottom parts of
the page is uniform. Additionally, windows with sidebars should always use
this style.
top-bar-style and
bottom-bar-style properties can be used add an opaque
background and a persistent shadow to top and bottom bars, this can be useful
for content such as utility panes,
where some elements are adjacent to the top/bottom bars, or TabView,
where each page can have a different background.
ToolbarView ensures the top and bottom bars have consistent backdrop
styles and vertical spacing. For comparison:
Any top and bottom bars can also be dragged to move the window, equivalent
to putting them into a Gtk::WindowHandle.
Content is typically place between top and bottom bars, but can also extend
behind them. This is controlled with the
extend-content-to-top-edge and
extend-content-to-bottom-edge properties.
Top and bottom bars can be hidden and revealed with an animation using the
reveal-top-bars and
reveal-bottom-bars properties.
ToolbarView as gtk::Buildable
The ToolbarView implementation of the gtk::Buildable interface
supports adding a top bar by specifying “top” as the “type” attribute of a
<child> element, or adding a bottom bar by specifying “bottom”.
Accessibility
ToolbarView uses the GTK_ACCESSIBLE_ROLE_GROUP role.
Properties
bottom-bar-height
The current bottom bar height.
Bottom bar height does change depending on
reveal-bottom-bars, including during the transition.
See top-bar-height.
Readable
bottom-bar-style
Appearance of the bottom bars.
If set to ADW_TOOLBAR_FLAT, bottom bars are flat and scrolling content
has a subtle undershoot shadow when touching them, same as the
.undershoot-bottom
style class. This works well for simple content, e.g. StatusPage or
PreferencesPage, where the background at the bottom of the page is
uniform. Additionally, windows with sidebars should always use this style.
Undershoot shadow is only present if a bottom bar is actually present and
visible. It is also never present if
extend-content-to-bottom-edge is set to TRUE.
If set to ADW_TOOLBAR_RAISED, bottom bars have an opaque background and a
persistent shadow, this is suitable for content such as
utility panes,
where some elements are directly adjacent to the bottom bars, or
TabView, where each page can have a different background.
ADW_TOOLBAR_RAISED_BORDER is similar to ADW_TOOLBAR_RAISED, but the
shadow is replaced with a more subtle border. This can be useful for
applications like image viewers.
See also top-bar-style.
Readable | Writeable
content
The content widget.
Readable | Writeable
extend-content-to-bottom-edge
Whether the content widget can extend behind bottom bars.
This can be used in combination with
reveal-bottom-bars to show and hide toolbars in
fullscreen.
See extend-content-to-top-edge.
Readable | Writeable
extend-content-to-top-edge
Whether the content widget can extend behind top bars.
This can be used in combination with reveal-top-bars
to show and hide toolbars in fullscreen.
See extend-content-to-bottom-edge.
Readable | Writeable
reveal-bottom-bars
Whether bottom bars are visible.
The transition will be animated.
This can be used in combination with
extend-content-to-bottom-edge to show and hide
toolbars in fullscreen.
See reveal-top-bars.
Readable | Writeable
reveal-top-bars
Whether top bars are revealed.
The transition will be animated.
This can be used in combination with
extend-content-to-top-edge to show and hide toolbars
in fullscreen.
See reveal-bottom-bars.
Readable | Writeable
top-bar-height
The current top bar height.
Top bar height does change depending reveal-top-bars,
including during the transition.
See bottom-bar-height.
Readable
top-bar-style
Appearance of the top bars.
If set to ADW_TOOLBAR_FLAT, top bars are flat and scrolling content has a
subtle undershoot shadow when touching them, same as the
.undershoot-top
style class. This works well for simple content, e.g. StatusPage or
PreferencesPage, where the background at the top of the page is
uniform. Additionally, windows with sidebars should always use this style.
Undershoot shadow is only present if a top bar is actually present and
visible. It is also never present if
extend-content-to-top-edge is set to TRUE.
If set to ADW_TOOLBAR_RAISED, top bars have an opaque background and a
persistent shadow, this is suitable for content such as
utility panes,
where some elements are directly adjacent to the top bars, or
TabView, where each page can have a different background.
ADW_TOOLBAR_RAISED_BORDER is similar to ADW_TOOLBAR_RAISED, but the
shadow is replaced with a more subtle border. This can be useful for
applications like image viewers.
See also bottom-bar-style.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ToolbarView
impl ToolbarView
Sourcepub fn new() -> ToolbarView
pub fn new() -> ToolbarView
Sourcepub fn builder() -> ToolbarViewBuilder
pub fn builder() -> ToolbarViewBuilder
Creates a new builder-pattern struct instance to construct ToolbarView objects.
This method returns an instance of ToolbarViewBuilder which can be used to create ToolbarView objects.
Sourcepub fn add_bottom_bar(&self, widget: &impl IsA<Widget>)
pub fn add_bottom_bar(&self, widget: &impl IsA<Widget>)
Sourcepub fn add_top_bar(&self, widget: &impl IsA<Widget>)
pub fn add_top_bar(&self, widget: &impl IsA<Widget>)
Sourcepub fn bottom_bar_height(&self) -> i32
pub fn bottom_bar_height(&self) -> i32
Gets the current bottom bar height for @self.
Bottom bar height does change depending on
reveal-bottom-bars, including during the transition.
See top_bar_height().
Returns
the current bottom bar height
Sourcepub fn bottom_bar_style(&self) -> ToolbarStyle
pub fn bottom_bar_style(&self) -> ToolbarStyle
Sourcepub fn is_extend_content_to_bottom_edge(&self) -> bool
pub fn is_extend_content_to_bottom_edge(&self) -> bool
Gets whether the content widget can extend behind bottom bars.
Returns
whether content extends behind bottom bars
Sourcepub fn is_extend_content_to_top_edge(&self) -> bool
pub fn is_extend_content_to_top_edge(&self) -> bool
Gets whether the content widget can extend behind top bars.
Returns
whether content extends behind top bars
Sourcepub fn reveals_bottom_bars(&self) -> bool
pub fn reveals_bottom_bars(&self) -> bool
Sourcepub fn reveals_top_bars(&self) -> bool
pub fn reveals_top_bars(&self) -> bool
Sourcepub fn top_bar_height(&self) -> i32
pub fn top_bar_height(&self) -> i32
Gets the current top bar height for @self.
Top bar height does change depending on
reveal-top-bars, including during the transition.
See bottom_bar_height().
Returns
the current top bar height
Sourcepub fn top_bar_style(&self) -> ToolbarStyle
pub fn top_bar_style(&self) -> ToolbarStyle
Sourcepub fn set_bottom_bar_style(&self, style: ToolbarStyle)
pub fn set_bottom_bar_style(&self, style: ToolbarStyle)
Sets appearance of the bottom bars for @self.
If set to ADW_TOOLBAR_FLAT, bottom bars are flat and scrolling content has
a subtle undershoot shadow when touching them, same as the
.undershoot-bottom
style class. This works well for simple content, e.g. StatusPage or
PreferencesPage, where the background at the bottom of the page is
uniform. Additionally, windows with sidebars should always use this style.
Undershoot shadow is only present if a bottom bar is actually present and
visible. It is also never present if
extend-content-to-bottom-edge is set to TRUE.
If set to ADW_TOOLBAR_RAISED, bottom bars have an opaque background and a
persistent shadow, this is suitable for content such as
utility panes,
where some elements are directly adjacent to the bottom bars, or
TabView, where each page can have a different background.
ADW_TOOLBAR_RAISED_BORDER is similar to ADW_TOOLBAR_RAISED, but the
shadow is replaced with a more subtle border. This can be useful for
applications like image viewers.
See also set_top_bar_style().
style
bottom bar style
Sourcepub fn set_content(&self, content: Option<&impl IsA<Widget>>)
pub fn set_content(&self, content: Option<&impl IsA<Widget>>)
Sourcepub fn set_extend_content_to_bottom_edge(&self, extend: bool)
pub fn set_extend_content_to_bottom_edge(&self, extend: bool)
Sets whether the content widget can extend behind bottom bars.
This can be used in combination with reveal-bottom-bars
to show and hide toolbars in fullscreen.
See set_extend_content_to_top_edge().
extend
whether content extends behind bottom bars
Sourcepub fn set_extend_content_to_top_edge(&self, extend: bool)
pub fn set_extend_content_to_top_edge(&self, extend: bool)
Sets whether the content widget can extend behind top bars.
This can be used in combination with reveal-top-bars
to show and hide toolbars in fullscreen.
See set_extend_content_to_bottom_edge().
extend
whether content extends behind top bars
Sourcepub fn set_reveal_bottom_bars(&self, reveal: bool)
pub fn set_reveal_bottom_bars(&self, reveal: bool)
Sets whether bottom bars are revealed for @self.
The transition will be animated.
This can be used in combination with
extend-content-to-bottom-edge to show and hide
toolbars in fullscreen.
reveal
whether to reveal bottom bars
Sourcepub fn set_reveal_top_bars(&self, reveal: bool)
pub fn set_reveal_top_bars(&self, reveal: bool)
Sets whether top bars are revealed for @self.
The transition will be animated.
This can be used in combination with
extend-content-to-top-edge to show and hide toolbars
in fullscreen.
reveal
whether to reveal top bars
Sourcepub fn set_top_bar_style(&self, style: ToolbarStyle)
pub fn set_top_bar_style(&self, style: ToolbarStyle)
Sets appearance of the top bars for @self.
If set to ADW_TOOLBAR_FLAT, top bars are flat and scrolling content has a
subtle undershoot shadow when touching them, same as the
.undershoot-top
style class. This works well for simple content, e.g. StatusPage or
PreferencesPage, where the background at the top of the page is
uniform. Additionally, windows with sidebars should always use this style.
Undershoot shadow is only present if a top bar is actually present and
visible. It is also never present if
extend-content-to-top-edge is set to TRUE.
If set to ADW_TOOLBAR_RAISED, top bars have an opaque background and a
persistent shadow, this is suitable for content such as
utility panes,
where some elements are directly adjacent to the top bars, or
TabView, where each page can have a different background.
ADW_TOOLBAR_RAISED_BORDER is similar to ADW_TOOLBAR_RAISED, but the
shadow is replaced with a more subtle border. This can be useful for
applications like image viewers.
See also set_bottom_bar_style().
style
top bar style
pub fn connect_bottom_bar_height_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_bottom_bar_style_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_content_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_extend_content_to_bottom_edge_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_extend_content_to_top_edge_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_reveal_bottom_bars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_reveal_top_bars_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_top_bar_height_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_top_bar_style_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId