ViewSwitcherSidebar

Struct ViewSwitcherSidebar 

pub struct ViewSwitcherSidebar { /* private fields */ }
Available on crate feature v1_9 only.
An adaptive sidebar that controls an ViewStack.

view-switcher-sidebar

ViewSwitcherSidebar is a view switcher implemented using a Sidebar, in a similar fashion to Gtk::StackSidebar.

ViewSwitcherSidebar items have an icon, a label, as well as an unread dot or a badge.

Unlike other switchers, ViewSwitcherSidebar supports grouping pages into sections, using the starts-section and section-title properties.

Like Sidebar, ViewSwitcherSidebar is adaptive and can behave as a sidebar or a page, via the mode property.

view-switcher-sidebar-modes

Connect to the activated signal to run code when an item has been activated. This can be used to toggle the visible pane when used in a split view.

Like Sidebar, ViewSwitcherSidebar supports filtering items via the filter property.

Use placeholder to provide an empty state widget. It will be shown when all items have been filtered out, or the sidebar has no items otherwise.

CSS nodes

ViewSwitcherSidebar has a single CSS node with name view-switcher-sidebar.

See also: ViewSwitcher, ViewSwitcherBar, InlineViewSwitcher.

Properties

filter

The item filter.

Can be used to implement search within the sidebar.

Use placeholder to provide an empty state.

See filter.

Readable | Writeable

mode

Determines the sidebar’s look and behavior.

If set to [enum@Adw.SidebarMode.SIDEBAR], behaves like a sidebar: with a sidebar style and a persistent selection.

If set to [enum@Adw.SidebarMode.PAGE], behaves like a page of boxed lists.

The page mode is intended to be used with NavigationSplitView when collapsed, as the sidebar pane becomes a page there.

When used with OverlaySplitView, the sidebar should stay in sidebar mode, as the sidebar pane is still a sidebar when collapsed.

See mode.

Readable | Writeable

placeholder

The placeholder widget.

This widget will be shown if the sidebar has no items, or all of its items have been filtered out by filter.

See placeholder.

Readable | Writeable

stack

The stack the sidebar controls.

Readable | Writeable

Widget

can-focus

Whether the widget or any of its descendents can accept the input focus.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writeable

can-target

Whether the widget can receive pointer events.

Readable | Writeable

css-classes

A list of css classes applied to this widget.

Readable | Writeable

css-name

The name of this widget in the CSS tree.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writeable | Construct Only

cursor

The cursor used by @widget.

Readable | Writeable

focus-on-click

Whether the widget should grab focus when it is clicked with the mouse.

This property is only relevant for widgets that can take focus.

Readable | Writeable

focusable

Whether this widget itself will accept the input focus.

Readable | Writeable

halign

How to distribute horizontal space if widget gets extra space.

Readable | Writeable

has-default

Whether the widget is the default widget.

Readable

has-focus

Whether the widget has the input focus.

Readable

has-tooltip

Enables or disables the emission of the query-tooltip signal on @widget.

A true value indicates that @widget can have a tooltip, in this case the widget will be queried using query-tooltip to determine whether it will provide a tooltip or not.

Readable | Writeable

height-request

Overrides for height request of the widget.

If this is -1, the natural request will be used.

Readable | Writeable

hexpand

Whether to expand horizontally.

Readable | Writeable

hexpand-set

Whether to use the hexpand property.

Readable | Writeable

layout-manager

The gtk::LayoutManager instance to use to compute the preferred size of the widget, and allocate its children.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writeable

limit-events

Makes this widget act like a modal dialog, with respect to event delivery.

Global event controllers will not handle events with targets inside the widget, unless they are set up to ignore propagation limits. See Gtk::EventController::set_propagation_limit().

Readable | Writeable

margin-bottom

Margin on bottom side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from [WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writeable

margin-end

Margin on end of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from [WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writeable

margin-start

Margin on start of widget, horizontally.

This property supports left-to-right and right-to-left text directions.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from [WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writeable

margin-top

Margin on top side of widget.

This property adds margin outside of the widget’s normal size request, the margin will be added in addition to the size from [WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.

Readable | Writeable

name

The name of the widget.

Readable | Writeable

opacity

The requested opacity of the widget.

Readable | Writeable

overflow

How content outside the widget’s content area is treated.

This property is meant to be set by widget implementations, typically in their instance init function.

Readable | Writeable

parent

The parent widget of this widget.

Readable

receives-default

Whether the widget will receive the default action when it is focused.

Readable | Writeable

root

The gtk::Root widget of the widget tree containing this widget.

This will be NULL if the widget is not contained in a root widget.

Readable

scale-factor

The scale factor of the widget.

Readable

sensitive

Whether the widget responds to input.

Readable | Writeable

tooltip-markup

Sets the text of tooltip to be the given string, which is marked up with Pango markup.

Also see Gtk::Tooltip::set_markup().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writeable

tooltip-text

Sets the text of tooltip to be the given string.

Also see Gtk::Tooltip::set_text().

This is a convenience property which will take care of getting the tooltip shown if the given string is not NULL: has-tooltip will automatically be set to true and there will be taken care of query-tooltip in the default signal handler.

Note that if both tooltip-text and tooltip-markup are set, the last one wins.

Readable | Writeable

valign

How to distribute vertical space if widget gets extra space.

Readable | Writeable

vexpand

Whether to expand vertically.

Readable | Writeable

vexpand-set

Whether to use the vexpand property.

Readable | Writeable

visible

Whether the widget is visible.

Readable | Writeable

width-request

Overrides for width request of the widget.

If this is -1, the natural request will be used.

Readable | Writeable

Accessible

accessible-role

The accessible role of the given gtk::Accessible implementation.

The accessible role cannot be changed once set.

Readable | Writeable

Signals

activated

Emitted when an item has been activated.

Widget

destroy

Signals that all holders of a reference to the widget should release the reference that they hold.

May result in finalization of the widget if all references are released.

This signal is not suitable for saving widget state.

direction-changed

Emitted when the text direction of a widget changes.

hide

Emitted when @widget is hidden.

keynav-failed

Emitted if keyboard navigation fails.

See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.

map

Emitted when @widget is going to be mapped.

A widget is mapped when the widget is visible (which is controlled with visible) and all its parents up to the toplevel widget are also visible.

The ::map signal can be used to determine whether a widget will be drawn, for instance it can resume an animation that was stopped during the emission of unmap.

mnemonic-activate

Emitted when a widget is activated via a mnemonic.

The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.

move-focus

Emitted when the focus is moved.

The ::move-focus signal is a keybinding signal.

The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.

Action

query-tooltip

Emitted when the widget’s tooltip is about to be shown.

This happens when the has-tooltip property is true and the hover timeout has expired with the cursor hovering above @widget; or emitted when @widget got focus in keyboard mode.

Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.

The signal handler is free to manipulate @tooltip with the therefore destined function calls.

realize

Emitted when @widget is associated with a GdkSurface.

This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called or the widget has been mapped (that is, it is going to be drawn).

show

Emitted when @widget is shown.

state-flags-changed

Emitted when the widget state changes.

See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].

unmap

Emitted when @widget is going to be unmapped.

A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.

As ::unmap indicates that a widget will not be shown any longer, it can be used to, for example, stop an animation on the widget.

unrealize

Emitted when the GdkSurface associated with @widget is destroyed.

This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called or the widget has been unmapped (that is, it is going to be hidden).

Implements

gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl ViewSwitcherSidebar

pub fn new() -> ViewSwitcherSidebar

Creates a new ViewSwitcherSidebar.

Returns

the newly created ViewSwitcherSidebar

pub fn builder() -> ViewSwitcherSidebarBuilder

Creates a new builder-pattern struct instance to construct ViewSwitcherSidebar objects.

This method returns an instance of ViewSwitcherSidebarBuilder which can be used to create ViewSwitcherSidebar objects.

pub fn filter(&self) -> Option<Filter>

Gets the item filter for @self.

Returns

the item filter

pub fn mode(&self) -> SidebarMode

Gets @self’s look and behavior.

See Sidebar::mode().

Returns

the current mode

pub fn placeholder(&self) -> Option<Widget>

Gets the placeholder widget for @self.

Returns

the placeholder widget

pub fn stack(&self) -> Option<ViewStack>

Gets the stack @self controls.

Returns

The stack of @self

pub fn set_filter(&self, filter: Option<&impl IsA<Filter>>)

Sets the item filter for @self.

Can be used to implement search within the sidebar.

Use placeholder to provide an empty state.

See Sidebar::set_filter().

filter

the item filter

pub fn set_mode(&self, mode: SidebarMode)

Sets @self’s look and behavior.

If set to [enum@Adw.SidebarMode.SIDEBAR], behaves like a sidebar: with a sidebar style and a persistent selection.

If set to [enum@Adw.SidebarMode.PAGE], behaves like a page of boxed lists. In this mode, the selection is invisible and only tracked to determine the initially selected item once switched back to sidebar mode.

The page mode is intended to be used with NavigationSplitView when collapsed, as the sidebar pane becomes a page there.

When used with OverlaySplitView, the sidebar should stay in sidebar mode, as the sidebar pane is still a sidebar when collapsed.

See Sidebar::set_mode().

mode

the new mode

pub fn set_placeholder(&self, placeholder: Option<&impl IsA<Widget>>)

Sets the placeholder widget for @self.

This widget will be shown if @self has no items, or all of its items have been filtered out by filter.

See Sidebar::set_placeholder().

placeholder

the placeholder widget

pub fn set_stack(&self, stack: Option<&ViewStack>)

Sets the stack to control.

stack

a stack

pub fn connect_activated<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

Emitted when an item has been activated.

pub fn connect_filter_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_placeholder_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_stack_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId