pub struct ViewSwitcherTitle { /* private fields */ }Since 1.4
## CSS nodes
[`ViewSwitcherTitle`][crate::ViewSwitcherTitle] has a single CSS node with name `viewswitchertitle`.
## Properties
#### `stack`
The stack the view switcher controls.
Readable | Writable
#### `subtitle`
The subtitle to display.
The subtitle should give the user additional details.
Readable | Writable
#### `title`
The title to display.
The title typically identifies the current view or content item, and
generally does not use the application name.
Readable | Writable
#### `title-visible`
Whether the title is currently visible.
If the title is visible, it means the view switcher is hidden an it may be
wanted to show an alternative switcher, e.g. a [`ViewSwitcherBar`][crate::ViewSwitcherBar].
Readable
#### `view-switcher-enabled`
Whether the view switcher is enabled.
If it is disabled, the title will be displayed instead. This allows to
programmatically hide the view switcher even if it fits in the available
space.
This can be used e.g. to ensure the view switcher is hidden below a certain
window width, or any other constraint you find suitable.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`gtk::LayoutManager`][crate::gtk::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See `Gtk::EventController::set_propagation_limit()`.
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`gtk::Root`][crate::gtk::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see `Gtk::Tooltip::set_markup()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see `Gtk::Tooltip::set_text()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`gtk::Accessible`][crate::gtk::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
# Implements
[`trait@gtk::prelude::WidgetExt`], [`trait@glib::ObjectExt`], [`trait@gtk::prelude::AccessibleExt`], [`trait@gtk::prelude::BuildableExt`], [`trait@gtk::prelude::ConstraintTargetExt`]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl ViewSwitcherTitle
impl ViewSwitcherTitle
Sourcepub fn new() -> ViewSwitcherTitle
👎Deprecated: Since 1.4
pub fn new() -> ViewSwitcherTitle
Since 1.4
Sourcepub fn builder() -> ViewSwitcherTitleBuilder
👎Deprecated: Since 1.4
pub fn builder() -> ViewSwitcherTitleBuilder
Since 1.4
Creates a new builder-pattern struct instance to construct ViewSwitcherTitle objects.
This method returns an instance of ViewSwitcherTitleBuilder which can be used to create ViewSwitcherTitle objects.
Sourcepub fn stack(&self) -> Option<ViewStack>
👎Deprecated: Since 1.4
pub fn stack(&self) -> Option<ViewStack>
Since 1.4
Sourcepub fn is_title_visible(&self) -> bool
👎Deprecated: Since 1.4
pub fn is_title_visible(&self) -> bool
Since 1.4
Gets whether the title of @self is currently visible.
If the title is visible, it means the view switcher is hidden an it may be
wanted to show an alternative switcher, e.g. a ViewSwitcherBar.
Deprecated since 1.4
Returns
whether the title of @self is currently visible
Sourcepub fn is_view_switcher_enabled(&self) -> bool
👎Deprecated: Since 1.4
pub fn is_view_switcher_enabled(&self) -> bool
Since 1.4
Sourcepub fn set_subtitle(&self, subtitle: &str)
👎Deprecated: Since 1.4
pub fn set_subtitle(&self, subtitle: &str)
Since 1.4
Sourcepub fn set_title(&self, title: &str)
👎Deprecated: Since 1.4
pub fn set_title(&self, title: &str)
Since 1.4
Sourcepub fn set_view_switcher_enabled(&self, enabled: bool)
👎Deprecated: Since 1.4
pub fn set_view_switcher_enabled(&self, enabled: bool)
Since 1.4
Sets whether @self’s view switcher is enabled.
If it is disabled, the title will be displayed instead. This allows to programmatically hide the view switcher even if it fits in the available space.
This can be used e.g. to ensure the view switcher is hidden below a certain window width, or any other constraint you find suitable.
Deprecated since 1.4
enabled
whether the view switcher is enabled
pub fn connect_stack_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.4
pub fn connect_subtitle_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.4
pub fn connect_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.4
pub fn connect_title_visible_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.4
pub fn connect_view_switcher_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Since 1.4