pub struct SidebarBuilder { /* private fields */ }v1_9 only.Expand description
A builder-pattern type to construct Sidebar objects.
Implementations
Sourceimpl SidebarBuilder
impl SidebarBuilder
Sourcepub fn drop_preload(self, drop_preload: bool) -> Self
pub fn drop_preload(self, drop_preload: bool) -> Self
Whether the drop data should be preloaded on hover.
See [preload][struct@crate::Gtk::DropTarget#preload].
Sourcepub fn filter(self, filter: &impl IsA<Filter>) -> Self
pub fn filter(self, filter: &impl IsA<Filter>) -> Self
The item filter.
Can be used to implement search within the sidebar.
Use placeholder to provide an empty state.
Context menu model for the items.
When a context menu is shown for an item, it will be constructed from the
provided menu model. Use the setup-menu signal to set up
the menu actions for the particular item.
Sourcepub fn mode(self, mode: SidebarMode) -> Self
pub fn mode(self, mode: SidebarMode) -> Self
Determines the sidebar’s look and behavior.
If set to [enum@Adw.SidebarMode.SIDEBAR], behaves like a sidebar: with a sidebar style and a persistent selection.
If set to [enum@Adw.SidebarMode.PAGE], behaves like a page of boxed lists. In this mode, the selection is invisible and only tracked to determine the initially selected item once switched back to sidebar mode.
The page mode is intended to be used with NavigationSplitView when
collapsed, as the sidebar pane becomes a page there.
When used with OverlaySplitView, the sidebar should stay in sidebar
mode, as the sidebar pane is still a sidebar when collapsed.
Sourcepub fn placeholder(self, placeholder: &impl IsA<Widget>) -> Self
pub fn placeholder(self, placeholder: &impl IsA<Widget>) -> Self
The placeholder widget.
This widget will be shown if the sidebar has no items, or all of its items
have been filtered out by filter.
Sourcepub fn selected(self, selected: u32) -> Self
pub fn selected(self, selected: u32) -> Self
The index of the currently selected item.
If set to Gtk::INVALID_LIST_POSITION, no item is selected.
If mode is set to [enum@Adw.SidebarMode.PAGE], the
selection is invisible, but still tracked, indicating which item will be
selected once the mode is changed to [enum@Adw.SidebarMode.SIDEBAR].
See also: selected-item.
Sourcepub fn can_focus(self, can_focus: bool) -> Self
pub fn can_focus(self, can_focus: bool) -> Self
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn can_target(self, can_target: bool) -> Self
pub fn can_target(self, can_target: bool) -> Self
Whether the widget can receive pointer events.
Sourcepub fn css_classes(self, css_classes: impl Into<StrV>) -> Self
pub fn css_classes(self, css_classes: impl Into<StrV>) -> Self
A list of css classes applied to this widget.
Sourcepub fn css_name(self, css_name: impl Into<GString>) -> Self
pub fn css_name(self, css_name: impl Into<GString>) -> Self
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn focus_on_click(self, focus_on_click: bool) -> Self
pub fn focus_on_click(self, focus_on_click: bool) -> Self
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Sourcepub fn focusable(self, focusable: bool) -> Self
pub fn focusable(self, focusable: bool) -> Self
Whether this widget itself will accept the input focus.
Sourcepub fn halign(self, halign: Align) -> Self
pub fn halign(self, halign: Align) -> Self
How to distribute horizontal space if widget gets extra space.
Sourcepub fn has_tooltip(self, has_tooltip: bool) -> Self
pub fn has_tooltip(self, has_tooltip: bool) -> Self
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Sourcepub fn height_request(self, height_request: i32) -> Self
pub fn height_request(self, height_request: i32) -> Self
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Sourcepub fn hexpand_set(self, hexpand_set: bool) -> Self
pub fn hexpand_set(self, hexpand_set: bool) -> Self
Whether to use the hexpand property.
Sourcepub fn layout_manager(self, layout_manager: &impl IsA<LayoutManager>) -> Self
pub fn layout_manager(self, layout_manager: &impl IsA<LayoutManager>) -> Self
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn limit_events(self, limit_events: bool) -> Self
Available on crate feature gtk_v4_18 only.
pub fn limit_events(self, limit_events: bool) -> Self
gtk_v4_18 only.Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Sourcepub fn margin_bottom(self, margin_bottom: i32) -> Self
pub fn margin_bottom(self, margin_bottom: i32) -> Self
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Sourcepub fn margin_end(self, margin_end: i32) -> Self
pub fn margin_end(self, margin_end: i32) -> Self
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Sourcepub fn margin_start(self, margin_start: i32) -> Self
pub fn margin_start(self, margin_start: i32) -> Self
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Sourcepub fn margin_top(self, margin_top: i32) -> Self
pub fn margin_top(self, margin_top: i32) -> Self
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Sourcepub fn overflow(self, overflow: Overflow) -> Self
pub fn overflow(self, overflow: Overflow) -> Self
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Sourcepub fn receives_default(self, receives_default: bool) -> Self
pub fn receives_default(self, receives_default: bool) -> Self
Whether the widget will receive the default action when it is focused.
Sourcepub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self
pub fn tooltip_markup(self, tooltip_markup: impl Into<GString>) -> Self
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Sourcepub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self
pub fn tooltip_text(self, tooltip_text: impl Into<GString>) -> Self
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Sourcepub fn valign(self, valign: Align) -> Self
pub fn valign(self, valign: Align) -> Self
How to distribute vertical space if widget gets extra space.
Sourcepub fn vexpand_set(self, vexpand_set: bool) -> Self
pub fn vexpand_set(self, vexpand_set: bool) -> Self
Whether to use the vexpand property.
Sourcepub fn width_request(self, width_request: i32) -> Self
pub fn width_request(self, width_request: i32) -> Self
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Sourcepub fn accessible_role(self, accessible_role: AccessibleRole) -> Self
pub fn accessible_role(self, accessible_role: AccessibleRole) -> Self
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.