pub fn init() -> Result<(), BoolError>Expand description
Initializes Libadwaita.
This function can be used instead of init() as it initializes GTK
implicitly.
There’s no need to call this function if you’re using Application.
If Libadwaita has already been initialized, the function will simply return.
This makes sure translations, types, themes, and icons for the Adwaita library are set up properly.