pub trait AdwWindowExt: IsA<Window> + 'static {
Show 13 methods
// Provided methods
fn add_breakpoint(&self, breakpoint: Breakpoint) { ... }
fn is_adaptive_preview(&self) -> bool { ... }
fn content(&self) -> Option<Widget> { ... }
fn current_breakpoint(&self) -> Option<Breakpoint> { ... }
fn dialogs(&self) -> ListModel { ... }
fn visible_dialog(&self) -> Option<Dialog> { ... }
fn set_adaptive_preview(&self, adaptive_preview: bool) { ... }
fn set_content(&self, content: Option<&impl IsA<Widget>>) { ... }
fn connect_adaptive_preview_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_content_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_current_breakpoint_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_dialogs_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_visible_dialog_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Expand description
Provided Methods
Sourcefn add_breakpoint(&self, breakpoint: Breakpoint)
Available on crate feature v1_4 only.
fn add_breakpoint(&self, breakpoint: Breakpoint)
v1_4 only.Sourcefn is_adaptive_preview(&self) -> bool
Available on crate feature v1_7 only.
fn is_adaptive_preview(&self) -> bool
v1_7 only.Gets whether adaptive preview for @self is currently open.
Returns
whether adaptive preview is open.
Sourcefn content(&self) -> Option<Widget>
fn content(&self) -> Option<Widget>
Gets the content widget of @self.
This method should always be used instead of [GtkWindowExtManual::child()][crate::gtk::prelude::GtkWindowExtManual::child()].
Returns
the content widget of @self
Sourcefn current_breakpoint(&self) -> Option<Breakpoint>
Available on crate feature v1_4 only.
fn current_breakpoint(&self) -> Option<Breakpoint>
v1_4 only.Sourcefn dialogs(&self) -> ListModel
Available on crate feature v1_5 only.
fn dialogs(&self) -> ListModel
v1_5 only.Returns a gio::ListModel that contains the open dialogs of @self.
This can be used to keep an up-to-date view.
Returns
a list model for the dialogs of @self
Sourcefn visible_dialog(&self) -> Option<Dialog>
Available on crate feature v1_5 only.
fn visible_dialog(&self) -> Option<Dialog>
v1_5 only.Sourcefn set_adaptive_preview(&self, adaptive_preview: bool)
Available on crate feature v1_7 only.
fn set_adaptive_preview(&self, adaptive_preview: bool)
v1_7 only.Sets whether adaptive preview for @self is currently open.
Adaptive preview is a debugging tool used for testing the window contents at specific screen sizes, simulating mobile environment.
Adaptive preview can always be accessed from inspector. This function allows applications to open it manually.
Most applications should not use this function.
adaptive_preview
whether to open adaptive preview
Sourcefn set_content(&self, content: Option<&impl IsA<Widget>>)
fn set_content(&self, content: Option<&impl IsA<Widget>>)
Sets the content widget of @self.
This method should always be used instead of [GtkWindowExtManual::set_child()][crate::gtk::prelude::GtkWindowExtManual::set_child()].
content
the content widget
fn connect_adaptive_preview_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.fn connect_content_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_current_breakpoint_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_4 only.fn connect_dialogs_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_5 only.fn connect_visible_dialog_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_5 only.Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.