pub struct AlertDialog { /* private fields */ }Available on crate feature
v1_5 only.Expand description
## Properties
#### `body`
The body text of the dialog.
Readable | Writable
#### `body-use-markup`
Whether the body text includes Pango markup.
See `parse_markup()`.
Readable | Writable
#### `close-response`
or with a system action.
It doesn't have to correspond to any of the responses in the dialog.
The default close response is `close`.
Readable | Writable
#### `default-response`
The response ID of the default response.
The button corresponding to this response will be set as the default widget
of the dialog.
If not set, the default widget will not be set, and the last added response
will be focused by default.
See [`default-widget`][struct@crate::Dialog#default-widget].
Readable | Writable
#### `extra-child`
The child widget.
Displayed below the heading and body.
Readable | Writable
#### `heading`
The heading of the dialog.
Readable | Writable
#### `heading-use-markup`
Whether the heading includes Pango markup.
See `parse_markup()`.
Readable | Writable
#### `prefer-wide-layout`
Whether to prefer horizontal button layout.
[`AlertDialog`][crate::AlertDialog] can present buttons horizontally or vertically depending
on available space, how many buttons there are and how wide they are.
By default it will prefer to stack buttons vertically at medium sizes.
Set to `TRUE` to prefer horizontal layout in these cases instead. This will
make the dialog slightly wider as well.
Vertical layout may still be used if the dialog would get too wide
otherwise.
Does nothing with just one button, or when the buttons are already
horizontal.
Readable | Writable
<details><summary><h4>Dialog</h4></summary>
#### `can-close`
Whether the dialog can be closed.
If set to `FALSE`, the close button, shortcuts and
[`AdwDialogExt::close()`][crate::prelude::AdwDialogExt::close()] will result in [`close-attempt`][struct@crate::Dialog#close-attempt] being
emitted instead, and bottom sheet close swipe will be disabled.
[`AdwDialogExt::force_close()`][crate::prelude::AdwDialogExt::force_close()] still works.
Readable | Writable
#### `child`
The child widget of the [`Dialog`][crate::Dialog].
Readable | Writable
#### `content-height`
The height of the dialog's contents.
Set it to -1 to reset it to the content's natural height.
See also: [`default-height`][struct@crate::gtk::Window#default-height]
Readable | Writable
#### `content-width`
The width of the dialog's contents.
Set it to -1 to reset it to the content's natural width.
See also: [`default-width`][struct@crate::gtk::Window#default-width]
Readable | Writable
#### `current-breakpoint`
The current breakpoint.
Readable
#### `default-widget`
The default widget.
It's activated when the user presses Enter.
Readable | Writable
#### `focus-widget`
The focus widget.
Readable | Writable
#### `follows-content-size`
Whether to size content automatically.
If set to `TRUE`, always use the content's natural size instead of
[`content-width`][struct@crate::Dialog#content-width] and [`content-height`][struct@crate::Dialog#content-height]. If
the content resizes, the dialog will immediately resize as well.
See also: [`resizable`][struct@crate::gtk::Window#resizable]
Readable | Writable
#### `presentation-mode`
The dialog's presentation mode.
When set to [enum@Adw.DialogPresentationMode.auto], the dialog appears as a
bottom sheet when the following condition is met:
`max-width: 450px or max-height: 360px`, and as a floating window otherwise.
Set it to [enum@Adw.DialogPresentationMode.floating] or
[enum@Adw.DialogPresentationMode.bottom-sheet] to always present it a
floating window or a bottom sheet respectively, regardless of available
size.
Presentation mode does nothing for dialogs presented as a window.
Readable | Writable
#### `title`
The title of the dialog.
Readable | Writable
</details>
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`gtk::LayoutManager`][crate::gtk::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See `Gtk::EventController::set_propagation_limit()`.
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`gtk::Root`][crate::gtk::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see `Gtk::Tooltip::set_markup()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see `Gtk::Tooltip::set_text()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`gtk::Accessible`][crate::gtk::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
## Signals
#### `response`
or with a system
action, @response will be set to the value of
[`close-response`][struct@crate::AlertDialog#close-response].
Detailed
<details><summary><h4>Dialog</h4></summary>
#### `close-attempt`
Emitted when the close button or shortcut is used, or
[`AdwDialogExt::close()`][crate::prelude::AdwDialogExt::close()] is called while [`can-close`][struct@crate::Dialog#can-close] is set to
`FALSE`.
#### `closed`
Emitted when the dialog is successfully closed.
</details>
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExtManual::keynav_failed()`][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::gtk::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::gtk::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a `GdkSurface`.
This means that [`WidgetExtManual::realize()`][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExtManual::state_flags()`][crate::gtk::prelude::WidgetExtManual::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the `GdkSurface` associated with @widget is destroyed.
This means that [`WidgetExtManual::unrealize()`][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
# Implements
[`AlertDialogExt`][trait@crate::prelude::AlertDialogExt], [`AdwDialogExt`][trait@crate::prelude::AdwDialogExt], [`trait@gtk::prelude::WidgetExt`], [`trait@glib::ObjectExt`], [`trait@gtk::prelude::AccessibleExt`], [`trait@gtk::prelude::BuildableExt`], [`trait@gtk::prelude::ConstraintTargetExt`], [`trait@gtk::prelude::ShortcutManagerExt`], [`AlertDialogExtManual`][trait@crate::prelude::AlertDialogExtManual]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl AlertDialog
impl AlertDialog
pub const NONE: Option<&'static AlertDialog> = None
Sourcepub fn new(heading: Option<&str>, body: Option<&str>) -> AlertDialog
pub fn new(heading: Option<&str>, body: Option<&str>) -> AlertDialog
Creates a new AlertDialog.
@heading and @body can be set to NULL. This can be useful if they need to
be formatted or use markup. In that case, set them to NULL and call
AlertDialog::format_body() or similar methods afterwards:
⚠️ The following code is in c ⚠️
AdwDialog *dialog;
dialog = adw_alert_dialog_new (_("Replace File?"), NULL);
adw_alert_dialog_format_body (ADW_ALERT_DIALOG (dialog),
_("A file named “%s” already exists. Do you want to replace it?"),
filename);heading
the heading
body
the body text
Returns
the newly created AlertDialog
Sourcepub fn builder() -> AlertDialogBuilder
pub fn builder() -> AlertDialogBuilder
Creates a new builder-pattern struct instance to construct AlertDialog objects.
This method returns an instance of AlertDialogBuilder which can be used to create AlertDialog objects.