pub struct MessageDialog { /* private fields */ }v1_2 only.Expand description
Use AlertDialog.
A dialog presenting a message or a question.
Message dialogs have a heading, a body, an optional child widget, and one or multiple responses, each presented as a button.
Each response has a unique string ID, and a button label. Additionally, each response can be enabled or disabled, and can have a suggested or destructive appearance.
When one of the responses is activated, or the dialog is closed, the
response signal will be emitted. This signal is
detailed, and the detail, as well as the response parameter will be set to
the ID of the activated response, or to the value of the
close-response property if the dialog had been
closed without activating any of the responses.
Response buttons can be presented horizontally or vertically depending on available space.
When a response is activated, MessageDialog is closed automatically.
An example of using a message dialog:
⚠️ The following code is in c ⚠️
GtkWidget *dialog;
dialog = adw_message_dialog_new (parent, _("Replace File?"), NULL);
adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog),
_("A file named “%s” already exists. Do you want to replace it?"),
filename);
adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
"cancel", _("_Cancel"),
"replace", _("_Replace"),
NULL);
adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog), "replace", ADW_RESPONSE_DESTRUCTIVE);
adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dialog), "cancel");
adw_message_dialog_set_close_response (ADW_MESSAGE_DIALOG (dialog), "cancel");
g_signal_connect (dialog, "response", G_CALLBACK (response_cb), self);
gtk_window_present (GTK_WINDOW (dialog));Async API
MessageDialog can also be used via the MessageDialogExtManual::choose()
method. This API follows the GIO async pattern, for example:
⚠️ The following code is in c ⚠️
static void
dialog_cb (AdwMessageDialog *dialog,
GAsyncResult *result,
MyWindow *self)
{
const char *response = adw_message_dialog_choose_finish (dialog, result);
// ...
}
static void
show_dialog (MyWindow *self)
{
GtkWidget *dialog;
dialog = adw_message_dialog_new (GTK_WINDOW (self), _("Replace File?"), NULL);
adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog),
_("A file named “%s” already exists. Do you want to replace it?"),
filename);
adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
"cancel", _("_Cancel"),
"replace", _("_Replace"),
NULL);
adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog), "replace", ADW_RESPONSE_DESTRUCTIVE);
adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dialog), "cancel");
adw_message_dialog_set_close_response (ADW_MESSAGE_DIALOG (dialog), "cancel");
adw_message_dialog_choose (ADW_MESSAGE_DIALOG (dialog), NULL, (GAsyncReadyCallback) dialog_cb, self);
}AdwMessageDialog as GtkBuildable
MessageDialog supports adding responses in UI definitions by via the
<responses> element that may contain multiple <response> elements, each
representing a response.
Each of the <response> elements must have the id attribute specifying the
response ID. The contents of the element are used as the response label.
Response labels can be translated with the usual translatable, context
and comments attributes.
The <response> elements can also have enabled and/or appearance
attributes. See MessageDialogExt::set_response_enabled() and
MessageDialogExt::set_response_appearance() for details.
Example of an MessageDialog UI definition:
<object class="AdwMessageDialog" id="dialog">
<property name="heading" translatable="yes">Save Changes?</property>
<property name="body" translatable="yes">Open documents contain unsaved changes. Changes which are not saved will be permanently lost.</property>
<property name="default-response">save</property>
<property name="close-response">cancel</property>
<signal name="response" handler="response_cb"/>
<responses>
<response id="cancel" translatable="yes">_Cancel</response>
<response id="discard" translatable="yes" appearance="destructive">_Discard</response>
<response id="save" translatable="yes" appearance="suggested" enabled="false">_Save</response>
</responses>
</object>Accessibility
MessageDialog uses the GTK_ACCESSIBLE_ROLE_DIALOG role.
Properties
body
The body text of the dialog.
Readable | Writeable
body-use-markup
Whether the body text includes Pango markup.
See parse_markup().
Readable | Writeable
close-response
The ID of the close response.
It will be passed to response if the window is
closed by pressing Escape or with a system action.
It doesn’t have to correspond to any of the responses in the dialog.
The default close response is close.
Readable | Writeable
default-response
The response ID of the default response.
The button corresponding to this response will be set as the default widget of the dialog.
If not set, the default widget will not be set, and the last added response will be focused by default.
See default-widget.
Readable | Writeable
extra-child
The child widget.
Displayed below the heading and body.
Readable | Writeable
heading
The heading of the dialog.
Readable | Writeable
heading-use-markup
Whether the heading includes Pango markup.
See parse_markup().
Readable | Writeable
Window
application
The gtk::Application associated with the window.
The application will be kept alive for at least as long as it has any windows associated with it (see g_application_hold() for a way to keep it alive without windows).
Normally, the connection between the application and the window
will remain until the window is destroyed, but you can explicitly
remove it by setting the this property to NULL.
Readable | Writeable
child
The child widget.
Readable | Writeable
decorated
Whether the window should have a frame (also known as decorations).
Readable | Writeable
default-height
The default height of the window.
Readable | Writeable
default-widget
The default widget.
Readable | Writeable
default-width
The default width of the window.
Readable | Writeable
deletable
Whether the window frame should have a close button.
Readable | Writeable
destroy-with-parent
If this window should be destroyed when the parent is destroyed.
Readable | Writeable
display
The display that will display this window.
Readable | Writeable
focus-visible
Whether ‘focus rectangles’ are currently visible in this window.
This property is maintained by GTK based on user input and should not be set by applications.
Readable | Writeable
focus-widget
The focus widget.
Readable | Writeable
fullscreened
Whether the window is fullscreen.
Setting this property is the equivalent of calling
[GtkWindowExtManual::fullscreen()][crate::gtk::prelude::GtkWindowExtManual::fullscreen()] or [GtkWindowExtManual::unfullscreen()][crate::gtk::prelude::GtkWindowExtManual::unfullscreen()];
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writeable
gravity
The gravity to use when resizing the window programmatically.
Gravity describes which point of the window we want to keep
fixed (meaning that the window will grow in the opposite direction).
For example, a gravity of GTK_WINDOW_GRAVITY_TOP_RIGHT means that we
want the to fix top right corner of the window.
Readable | Writeable
handle-menubar-accel
Whether the window frame should handle F10 for activating menubars.
Readable | Writeable
hide-on-close
If this window should be hidden instead of destroyed when the user clicks the close button.
Readable | Writeable
icon-name
Specifies the name of the themed icon to use as the window icon.
See Gtk::IconTheme for more details.
Readable | Writeable
is-active
Whether the toplevel is the currently active window.
Readable
maximized
Whether the window is maximized.
Setting this property is the equivalent of calling
[GtkWindowExtManual::maximize()][crate::gtk::prelude::GtkWindowExtManual::maximize()] or [GtkWindowExtManual::unmaximize()][crate::gtk::prelude::GtkWindowExtManual::unmaximize()];
either operation is asynchronous, which means you will need to
connect to the ::notify signal in order to know whether the
operation was successful.
Readable | Writeable
mnemonics-visible
Whether mnemonics are currently visible in this window.
This property is maintained by GTK based on user input, and should not be set by applications.
Readable | Writeable
modal
If true, the window is modal.
Readable | Writeable
resizable
If true, users can resize the window.
Readable | Writeable
startup-id
A write-only property for setting window’s startup notification identifier.
Writeable
suspended
Whether the window is suspended.
See [GtkWindowExtManual::is_suspended()][crate::gtk::prelude::GtkWindowExtManual::is_suspended()] for details about what suspended means.
Readable
title
The title of the window.
Readable | Writeable
titlebar
The titlebar widget.
Readable | Writeable
transient-for
The transient parent of the window.
Readable | Writeable | Construct
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Signals
response
This signal is emitted when the dialog is closed.
@response will be set to the response ID of the button that had been activated.
if the dialog was closed by pressing Escape or with a system
action, @response will be set to the value of
close-response.
Detailed
Window
activate-default
Emitted when the user activates the default widget.
This is a keybinding signal.
The keybindings for this signal are all forms of the Enter key.
Action
activate-focus
Emitted when the user activates the currently focused widget of @window.
This is a keybinding signal.
The default binding for this signal is ␣.
Action
close-request
Emitted when the user clicks on the close button of the window.
enable-debugging
Emitted when the user enables or disables interactive debugging.
When @toggle is true, interactive debugging is toggled on or off, when it is false, the debugger will be pointed at the widget under the pointer.
This is a keybinding signal.
The default bindings for this signal are Ctrl+Shift+I and Ctrl+Shift+D.
Action
keys-changed
Emitted when the set of accelerators or mnemonics that are associated with the window changes.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
MessageDialogExt, gtk::prelude::GtkWindowExt, gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, gtk::prelude::NativeExt, gtk::prelude::RootExt, gtk::prelude::ShortcutManagerExt, MessageDialogExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl MessageDialog
impl MessageDialog
pub const NONE: Option<&'static MessageDialog> = None
Sourcepub fn new(
parent: Option<&impl IsA<Window>>,
heading: Option<&str>,
body: Option<&str>,
) -> MessageDialog
👎Deprecated: Since 1.6
pub fn new( parent: Option<&impl IsA<Window>>, heading: Option<&str>, body: Option<&str>, ) -> MessageDialog
Creates a new MessageDialog.
@heading and @body can be set to NULL. This can be useful if they need to
be formatted or use markup. In that case, set them to NULL and call
MessageDialog::format_body() or similar methods afterwards:
⚠️ The following code is in c ⚠️
GtkWidget *dialog;
dialog = adw_message_dialog_new (parent, _("Replace File?"), NULL);
adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog),
_("A file named “%s” already exists. Do you want to replace it?"),
filename);Deprecated since 1.6
Use AlertDialog.
parent
transient parent
heading
the heading
body
the body text
Returns
the newly created MessageDialog
Sourcepub fn builder() -> MessageDialogBuilder
👎Deprecated: Since 1.6
pub fn builder() -> MessageDialogBuilder
Creates a new builder-pattern struct instance to construct MessageDialog objects.
This method returns an instance of MessageDialogBuilder which can be used to create MessageDialog objects.