pub struct Sidebar { /* private fields */ }v1_9 only.Expand description
## CSS nodes
[`Sidebar`][crate::Sidebar] has a main CSS node with the name `sidebar`.
Internally, it's using a `Gtk::ListBox` with the
[`.navigation-sidebar`](style-classes.html#sidebars) style class in sidebar
mode, or an [`PreferencesPage`][crate::PreferencesPage] in page mode.
## Accessibility
[`Sidebar`][crate::Sidebar] uses the [enum@Gtk.AccessibleRole.generic] role.
## Properties
#### `drop-preload`
Whether the drop data should be preloaded on hover.
See [`preload`][struct@crate::Gtk::DropTarget#preload].
Readable | Writable
#### `filter`
The item filter.
Can be used to implement search within the sidebar.
Use [`placeholder`][struct@crate::Sidebar#placeholder] to provide an empty state.
Readable | Writable
#### `items`
A list model with the sidebar's items.
This can be used to keep an up-to-date view.
The model implements `Gtk::SectionModel` and creates sections
corresponding to the sidebar's sections.
The model also implements [`gtk::SelectionModel`][crate::gtk::SelectionModel] and can be used to
track and change the selection.
To only track sections, use [`sections`][struct@crate::Sidebar#sections] instead.
Readable
#### `menu-model`
Context menu model for the items.
When a context menu is shown for an item, it will be constructed from the
provided menu model. Use the [`setup-menu`][struct@crate::Sidebar#setup-menu] signal to set up
the menu actions for the particular item.
[`menu-model`][struct@crate::Sidebar#menu-model] will be preferred over this model if set.
Readable | Writable
#### `mode`
If set to [enum@Adw.SidebarMode.sidebar], behaves like a sidebar: with a
sidebar style and a persistent selection.
If set to [enum@Adw.SidebarMode.page], behaves like a page of boxed lists.
In this mode, the selection is invisible and only tracked to determine the
initially selected item once switched back to sidebar mode.
The page mode is intended to be used with [`NavigationSplitView`][crate::NavigationSplitView] when
collapsed, as the sidebar pane becomes a page there.
When used with [`OverlaySplitView`][crate::OverlaySplitView], the sidebar should stay in sidebar
mode, as the sidebar pane is still a sidebar when collapsed.
Readable | Writable
#### `placeholder`
The placeholder widget.
This widget will be shown if the sidebar has no items, or all of its items
have been filtered out by [`filter`][struct@crate::Sidebar#filter].
Readable | Writable
#### `prefix`
A widget to be displayed before the sidebar items.
Readable | Writable
#### `sections`
A list model with the sidebar's sections.
This can be used to keep an up-to-date view.
To track items, use [`items`][struct@crate::Sidebar#items] instead.
Readable
#### `selected`
The index of the currently selected item.
If set to `Gtk::INVALID_LIST_POSITION`, no item is selected.
If [`mode`][struct@crate::Sidebar#mode] is set to [enum@Adw.SidebarMode.page], the
selection is invisible, but still tracked, indicating which item will be
selected once the mode is changed to [enum@Adw.SidebarMode.sidebar].
See also: [`selected-item`][struct@crate::Sidebar#selected-item].
Readable | Writable
#### `selected-item`
The currently selected item.
This is a convenience property, equivalent to calling
[`Sidebar::item()`][crate::Sidebar::item()] with [`selected`][struct@crate::Sidebar#selected] provided as the
index.
To change selection, use [`selected`][struct@crate::Sidebar#selected].
Readable
#### `suffix`
A widget to be displayed after the sidebar items.
Readable | Writable
<details><summary><h4>Widget</h4></summary>
#### `can-focus`
Whether the widget or any of its descendents can accept
the input focus.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `can-target`
Whether the widget can receive pointer events.
Readable | Writable
#### `css-classes`
A list of css classes applied to this widget.
Readable | Writable
#### `css-name`
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable | Construct Only
#### `cursor`
The cursor used by @widget.
Readable | Writable
#### `focus-on-click`
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writable
#### `focusable`
Whether this widget itself will accept the input focus.
Readable | Writable
#### `halign`
How to distribute horizontal space if widget gets extra space.
Readable | Writable
#### `has-default`
Whether the widget is the default widget.
Readable
#### `has-focus`
Whether the widget has the input focus.
Readable
#### `has-tooltip`
Enables or disables the emission of the [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip]
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] to
determine whether it will provide a tooltip or not.
Readable | Writable
#### `height-request`
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
#### `hexpand`
Whether to expand horizontally.
Readable | Writable
#### `hexpand-set`
Whether to use the `hexpand` property.
Readable | Writable
#### `layout-manager`
The [`gtk::LayoutManager`][crate::gtk::LayoutManager] instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `limit-events`
Makes this widget act like a modal dialog, with respect to
event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See `Gtk::EventController::set_propagation_limit()`.
Readable | Writable
#### `margin-bottom`
Margin on bottom side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-end`
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-start`
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text
directions.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `margin-top`
Margin on top side of widget.
This property adds margin outside of the widget's normal size
request, the margin will be added in addition to the size from
[`WidgetExtManual::set_size_request()`][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writable
#### `name`
The name of the widget.
Readable | Writable
#### `opacity`
The requested opacity of the widget.
Readable | Writable
#### `overflow`
How content outside the widget's content area is treated.
This property is meant to be set by widget implementations,
typically in their instance init function.
Readable | Writable
#### `parent`
The parent widget of this widget.
Readable
#### `receives-default`
Whether the widget will receive the default action when it is focused.
Readable | Writable
#### `root`
The [`gtk::Root`][crate::gtk::Root] widget of the widget tree containing this widget.
This will be `NULL` if the widget is not contained in a root widget.
Readable
#### `scale-factor`
The scale factor of the widget.
Readable
#### `sensitive`
Whether the widget responds to input.
Readable | Writable
#### `tooltip-markup`
Sets the text of tooltip to be the given string, which is marked up
with Pango markup.
Also see `Gtk::Tooltip::set_markup()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `tooltip-text`
Sets the text of tooltip to be the given string.
Also see `Gtk::Tooltip::set_text()`.
This is a convenience property which will take care of getting the
tooltip shown if the given string is not `NULL`:
[`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] will automatically be set to true
and there will be taken care of [`query-tooltip`][struct@crate::gtk::Widget#query-tooltip] in
the default signal handler.
Note that if both [`tooltip-text`][struct@crate::gtk::Widget#tooltip-text] and
[`tooltip-markup`][struct@crate::gtk::Widget#tooltip-markup] are set, the last one wins.
Readable | Writable
#### `valign`
How to distribute vertical space if widget gets extra space.
Readable | Writable
#### `vexpand`
Whether to expand vertically.
Readable | Writable
#### `vexpand-set`
Whether to use the `vexpand` property.
Readable | Writable
#### `visible`
Whether the widget is visible.
Readable | Writable
#### `width-request`
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writable
</details>
<details><summary><h4>Accessible</h4></summary>
#### `accessible-role`
The accessible role of the given [`gtk::Accessible`][crate::gtk::Accessible] implementation.
The accessible role cannot be changed once set.
Readable | Writable
</details>
## Signals
#### `activated`
Emitted when an item at @index has been activated.
#### `drop`
Emitted when content is dropped onto the item at @index.
The content must be of one of the types set up via
[`Sidebar::setup_drop_target()`][crate::Sidebar::setup_drop_target()].
See [`drop`][struct@crate::Gtk::DropTarget#drop].
#### `drop-enter`
Emitted when the pointer enters the item at @index.
Applications can use this to set their default drop action even when
[`drop-preload`][struct@crate::Sidebar#drop-preload] is set to `FALSE`.
See [`enter`][struct@crate::Gtk::DropTarget#enter].
#### `drop-value-loaded`
Emitted when the dropped content is preloaded for the item at @index.
In order for data to be preloaded, [`drop-preload`][struct@crate::Sidebar#drop-preload]
must be set to `TRUE`.
The content must be of one of the types set up via
[`Sidebar::setup_drop_target()`][crate::Sidebar::setup_drop_target()].
See [`value`][struct@crate::Gtk::DropTarget#value].
#### `setup-menu`
Emitted when a context menu is opened or closed for @item.
If the menu has been closed, @item will be set to `NULL`.
It can be used to set up menu actions before showing the menu, for example
disable actions not applicable to @item.
<details><summary><h4>Widget</h4></summary>
#### `destroy`
Signals that all holders of a reference to the widget should release
the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
#### `direction-changed`
Emitted when the text direction of a widget changes.
#### `hide`
Emitted when @widget is hidden.
#### `keynav-failed`
Emitted if keyboard navigation fails.
See [`WidgetExtManual::keynav_failed()`][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
#### `map`
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
[`visible`][struct@crate::gtk::Widget#visible]) and all its parents up to the toplevel widget
are also visible.
The `::map` signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of [`unmap`][struct@crate::gtk::Widget#unmap].
#### `mnemonic-activate`
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling
is false, or just makes @widget grab focus if @group_cycling is true.
#### `move-focus`
to move backward.
Action
#### `query-tooltip`
s tooltip is about to be shown.
This happens when the [`has-tooltip`][struct@crate::gtk::Widget#has-tooltip] property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine
whether a tooltip should be shown for @widget. If this is the case
true should be returned, false otherwise. Note that if @keyboard_mode
is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore
destined function calls.
#### `realize`
Emitted when @widget is associated with a `GdkSurface`.
This means that [`WidgetExtManual::realize()`][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
#### `show`
Emitted when @widget is shown.
#### `state-flags-changed`
Emitted when the widget state changes.
See [`WidgetExtManual::state_flags()`][crate::gtk::prelude::WidgetExtManual::state_flags()].
#### `unmap`
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the
toplevel widget have been set as hidden.
As `::unmap` indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
#### `unrealize`
Emitted when the `GdkSurface` associated with @widget is destroyed.
This means that [`WidgetExtManual::unrealize()`][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
</details>
# Implements
[`trait@gtk::prelude::WidgetExt`], [`trait@glib::ObjectExt`], [`trait@gtk::prelude::AccessibleExt`], [`trait@gtk::prelude::BuildableExt`], [`trait@gtk::prelude::ConstraintTargetExt`]
GLib type: GObject with reference counted clone semantics.Implementations
Sourceimpl Sidebar
impl Sidebar
Sourcepub fn builder() -> SidebarBuilder
pub fn builder() -> SidebarBuilder
Creates a new builder-pattern struct instance to construct Sidebar objects.
This method returns an instance of SidebarBuilder which can be used to create Sidebar objects.
Sourcepub fn append(&self, section: SidebarSection)
pub fn append(&self, section: SidebarSection)
Sourcepub fn is_drop_preload(&self) -> bool
pub fn is_drop_preload(&self) -> bool
Gets whether drop data should be preloaded on hover.
Returns
whether drop data should be preloaded on hover
Sourcepub fn item(&self, index: u32) -> Option<SidebarItem>
pub fn item(&self, index: u32) -> Option<SidebarItem>
Gets the item at @index within @self.
The index starts from 0 at the top of the sidebar, and is same as the one
returned by SidebarItemExt::index().
Can return NULL if @index is larger or equal to the number of items.
index
index of the item
Returns
the item at @index
Sourcepub fn items(&self) -> SelectionModel
pub fn items(&self) -> SelectionModel
Gets a list model with @self’s items.
This can be used to keep an up-to-date view.
The model implements Gtk::SectionModel and creates sections
corresponding to the sidebar’s sections.
The model also implements gtk::SelectionModel and can be used to
track and change the selection.
To only track sections, use sections instead.
Returns
a model containing the items
Sourcepub fn mode(&self) -> SidebarMode
pub fn mode(&self) -> SidebarMode
Sourcepub fn placeholder(&self) -> Option<Widget>
pub fn placeholder(&self) -> Option<Widget>
Sourcepub fn section(&self, index: u32) -> Option<SidebarSection>
pub fn section(&self, index: u32) -> Option<SidebarSection>
Sourcepub fn selected(&self) -> u32
pub fn selected(&self) -> u32
Gets the index of the currently selected item.
See also: selected_item().
Returns
index of the currently selected item
Sourcepub fn selected_item(&self) -> Option<SidebarItem>
pub fn selected_item(&self) -> Option<SidebarItem>
Gets the currently selected item.
This is a convenience method, equivalent to calling item()
with selected provided as the index.
To change selection, use set_selected().
Returns
the selected item
Sourcepub fn insert(&self, section: SidebarSection, position: i32)
pub fn insert(&self, section: SidebarSection, position: i32)
Sourcepub fn prepend(&self, section: SidebarSection)
pub fn prepend(&self, section: SidebarSection)
Sourcepub fn remove(&self, section: &SidebarSection)
pub fn remove(&self, section: &SidebarSection)
Sourcepub fn remove_all(&self)
pub fn remove_all(&self)
Removes all sections from @self.
Sourcepub fn set_drop_preload(&self, preload: bool)
pub fn set_drop_preload(&self, preload: bool)
Sets whether drop data should be preloaded on hover.
See [preload][struct@crate::Gtk::DropTarget#preload].
preload
whether to preload drop data
Sourcepub fn set_filter(&self, filter: Option<&impl IsA<Filter>>)
pub fn set_filter(&self, filter: Option<&impl IsA<Filter>>)
Sets the item filter for @self.
Can be used to implement search within the sidebar.
Use placeholder to provide an empty state.
filter
the item filter
Sets the context menu model for @self’s items.
When a context menu is shown for an item, it will be constructed from the
provided menu model. Use the setup-menu signal to set up
the menu actions for the particular item.
menu-model will be preferred over this model if set.
menu_model
a menu model
Sourcepub fn set_mode(&self, mode: SidebarMode)
pub fn set_mode(&self, mode: SidebarMode)
If set to [enum@Adw.SidebarMode.sidebar], behaves like a sidebar: with a sidebar style and a persistent selection.
If set to [enum@Adw.SidebarMode.page], behaves like a page of boxed lists. In this mode, the selection is invisible and only tracked to determine the initially selected item once switched back to sidebar mode.
The page mode is intended to be used with NavigationSplitView when
collapsed, as the sidebar pane becomes a page there.
When used with OverlaySplitView, the sidebar should stay in sidebar
mode, as the sidebar pane is still a sidebar when collapsed.
mode
the new mode
Sourcepub fn set_placeholder(&self, placeholder: Option<&impl IsA<Widget>>)
pub fn set_placeholder(&self, placeholder: Option<&impl IsA<Widget>>)
Sourcepub fn set_prefix(&self, prefix: Option<&impl IsA<Widget>>)
Available on crate feature v1_10 only.
pub fn set_prefix(&self, prefix: Option<&impl IsA<Widget>>)
v1_10 only.Sourcepub fn set_selected(&self, selected: u32)
pub fn set_selected(&self, selected: u32)
Selects the item at @selected.
If set to Gtk::INVALID_LIST_POSITION, no item is selected.
If mode is set to [enum@Adw.SidebarMode.page], the
selection is invisible, but still tracked, indicating which item will be
selected once the mode is changed to [enum@Adw.SidebarMode.sidebar].
See also: selected-item.
selected
index of the newly selected item
Sourcepub fn set_suffix(&self, suffix: Option<&impl IsA<Widget>>)
Available on crate feature v1_10 only.
pub fn set_suffix(&self, suffix: Option<&impl IsA<Widget>>)
v1_10 only.Sourcepub fn connect_activated<F: Fn(&Self, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_activated<F: Fn(&Self, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_drop<F: Fn(&Self, u32, &Value, DragAction) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop<F: Fn(&Self, u32, &Value, DragAction) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when content is dropped onto the item at @index.
The content must be of one of the types set up via
setup_drop_target().
See [drop][struct@crate::Gtk::DropTarget#drop].
index
index of the item the content was dropped onto
value
the GValue being dropped
preferred_action
the preferred drop action
Returns
whether the drop was accepted
SinceL 1.9
Sourcepub fn connect_drop_enter<F: Fn(&Self, u32) -> DragAction + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop_enter<F: Fn(&Self, u32) -> DragAction + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the pointer enters the item at @index.
Applications can use this to set their default drop action even when
drop-preload is set to FALSE.
See [enter][struct@crate::Gtk::DropTarget#enter].
index
index of the hovered item
Returns
the preferred action for the drop
Sourcepub fn connect_drop_value_loaded<F: Fn(&Self, u32, &Value) -> DragAction + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop_value_loaded<F: Fn(&Self, u32, &Value) -> DragAction + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the dropped content is preloaded for the item at @index.
In order for data to be preloaded, drop-preload
must be set to TRUE.
The content must be of one of the types set up via
setup_drop_target().
See [value][struct@crate::Gtk::DropTarget#value].
index
index of the hovered item
value
the GValue being dropped
Returns
the preferred action for the drop
Emitted when a context menu is opened or closed for @item.
If the menu has been closed, @item will be set to NULL.
It can be used to set up menu actions before showing the menu, for example disable actions not applicable to @item.
item
an item in @self_
pub fn connect_drop_preload_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_filter_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_items_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_placeholder_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_prefix_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_10 only.pub fn connect_sections_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_selected_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_selected_item_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_suffix_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_10 only.Sourceimpl Sidebar
impl Sidebar
Sourcepub fn setup_drop_target(&self, actions: DragAction, types: &[Type])
pub fn setup_drop_target(&self, actions: DragAction, types: &[Type])