pub struct Sidebar { /* private fields */ }v1_9 only.Expand description
Adaptive sidebar widget.
Sidebar contains SidebarSection objects, which in turn contain
SidebarItem objects.
To add sections, use append(), prepend() or
insert().
To remove sections, use remove() or
remove_all().
To inspect the items, use item() or
items.
To inspect sections themselves, use section() or
sections.
Selection and activation
Sidebar has zero or one selected items. The index of the item can be
accessed and changed via selected. Set it to
Gtk::INVALID_LIST_POSITION to remove selection.
Selection cannot be permanently disabled.
selected-item can be used to access the selected item.
Connect to the activated signal to run code when an item
has been activated. This can be used to toggle the visible pane when used in
a split view.
See also: ViewSwitcherSidebar.
Modes
Sidebar is adaptive and can act as either a regular sidebar, or a page
of boxed lists.
Use the mode to determine its look and behavior.
A typical use case involves using Sidebar inside the sidebar pane of a
NavigationSplitView, and switching mode to page whenever it’s
collapsed, as follows:
<object class="AdwWindow">
<property name="default-width">800</property>
<property name="default-height">600</property>
<child>
<object class="AdwBreakpoint">
<condition>max-width: 400sp</condition>
<setter object="split_view" property="collapsed">True</setter>
<setter object="sidebar" property="mode">page</setter>
</object>
</child>
<property name="content">
<object class="AdwNavigationSplitView" id="split_view">
<property name="sidebar">
<object class="AdwNavigationPage">
<property name="title" translatable="yes">Sidebar</property>
<property name="child">
<object class="AdwToolbarView">
<child type="top">
<object class="AdwHeaderBar"/>
</child>
<property name="content">
<object class="AdwSidebar" id="sidebar">
<!-- Calls adw_navigation_split_view_set_show_content (split_view, TRUE); -->
<signal name="activated" handler="sidebar_activated_cb"/>
<!-- ... -->
</object>
</property>
</object>
</property>
</object>
</property>
<property name="content">
<object class="AdwNavigationPage">
<property name="title" translatable="yes">Content</property>
<property name="child">
<!-- ... -->
</property>
</object>
</property>
</object>
</property>
</object>When used with OverlaySplitView, the sidebar should stay in sidebar
mode, as the sidebar pane is still a sidebar when collapsed.
Search
Sidebar supports filtering items via the filter
property.
Use placeholder to provide an empty state widget. It will
be shown when all items have been filtered out, or the sidebar has no items
otherwise.
Context Menu
To create a context menu for the sidebar items, use the
menu-model property to provide a menu model, and the
setup-menu signal to set up actions for the given item.
Drag-and-Drop
Sidebar items can have a drop target for arbitrary content.
Use setup_drop_target() to set it up, specifying the
supported content types and drag actions, then connect to
drop to handle drops.
In some cases, it may be necessary to determine the used action based on the dragged content, or the hovered item.
To determine it based on the sidebar item, connect to the
drop-enter signal and return the action from its handler.
To determine it based on the content, set drop-preload to
TRUE, then connect to drop-value-loaded signal and return
the action from its handler.
In both cases the action will be passed as a parameter to the
drop signal.
Regardless of whether a drop target was set up, dragging content over sidebar
items activates them after a timeout. To disable this behavior for specific
items, set drag-motion-activate to FALSE on them.
Sidebar as gtk::Buildable
Sidebar allows adding sections as children.
Example of an Sidebar UI definition:
<object class="AdwSidebar">
<child>
<object class="AdwSidebarSection">
<child>
<object class="AdwSidebarItem">
<property name="title" translatable="yes">Recent</property>
<property name="icon-name">document-open-recent-symbolic</property>
</object>
</child>
<child>
<object class="AdwSidebarItem">
<property name="title" translatable="yes">Starred</property>
<property name="icon-name">starred-symbolic</property>
</object>
</child>
</object>
</child>
<child>
<object class="AdwSidebarSection">
<property name="title" translatable="yes">Places</property>
<child>
<object class="AdwSidebarItem">
<property name="title" translatable="yes">Music</property>
<property name="icon-name">folder-music-symbolic</property>
</object>
</child>
<child>
<object class="AdwSidebarItem">
<property name="title" translatable="yes">Pictures</property>
<property name="icon-name">folder-pictures-symbolic</property>
</object>
</child>
<child>
<object class="AdwSidebarItem">
<property name="title" translatable="yes">Videos</property>
<property name="icon-name">folder-videos-symbolic</property>
</object>
</child>
</object>
</child>
<child>
<object class="AdwSidebarSection">
<child>
<object class="AdwSidebarItem">
<property name="title" translatable="yes">Trash</property>
<property name="icon-name">user-trash-symbolic</property>
</object>
</child>
</object>
</child>
</object>CSS nodes
Sidebar has a main CSS node with the name sidebar.
Internally, it’s using a Gtk::ListBox with the
.navigation-sidebar style class in sidebar
mode, or an PreferencesPage in page mode.
Accessibility
Sidebar uses the [enum@Gtk.AccessibleRole.generic] role.
Properties
drop-preload
Whether the drop data should be preloaded on hover.
See [preload][struct@crate::Gtk::DropTarget#preload].
Readable | Writeable
filter
The item filter.
Can be used to implement search within the sidebar.
Use placeholder to provide an empty state.
Readable | Writeable
items
A list model with the sidebar’s items.
This can be used to keep an up-to-date view.
The model implements Gtk::SectionModel and creates sections
corresponding to the sidebar’s sections.
The model also implements gtk::SelectionModel and can be used to
track and change the selection.
To only track sections, use sections instead.
Readable
menu-model
Context menu model for the items.
When a context menu is shown for an item, it will be constructed from the
provided menu model. Use the setup-menu signal to set up
the menu actions for the particular item.
Readable | Writeable
mode
Determines the sidebar’s look and behavior.
If set to [enum@Adw.SidebarMode.SIDEBAR], behaves like a sidebar: with a sidebar style and a persistent selection.
If set to [enum@Adw.SidebarMode.PAGE], behaves like a page of boxed lists. In this mode, the selection is invisible and only tracked to determine the initially selected item once switched back to sidebar mode.
The page mode is intended to be used with NavigationSplitView when
collapsed, as the sidebar pane becomes a page there.
When used with OverlaySplitView, the sidebar should stay in sidebar
mode, as the sidebar pane is still a sidebar when collapsed.
Readable | Writeable
placeholder
The placeholder widget.
This widget will be shown if the sidebar has no items, or all of its items
have been filtered out by filter.
Readable | Writeable
sections
A list model with the sidebar’s sections.
This can be used to keep an up-to-date view.
To track items, use items instead.
Readable
selected
The index of the currently selected item.
If set to Gtk::INVALID_LIST_POSITION, no item is selected.
If mode is set to [enum@Adw.SidebarMode.PAGE], the
selection is invisible, but still tracked, indicating which item will be
selected once the mode is changed to [enum@Adw.SidebarMode.SIDEBAR].
See also: selected-item.
Readable | Writeable
selected-item
The currently selected item.
This is a convenience property, equivalent to calling
Sidebar::item() with selected provided as the
index.
To change selection, use selected.
Readable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Signals
activated
Emitted when an item at @index has been activated.
drop
Emitted when content is dropped onto the item at @index.
The content must be of one of the types set up via
Sidebar::setup_drop_target().
See [drop][struct@crate::Gtk::DropTarget#drop].
drop-enter
Emitted when the pointer enters the item at @index.
Applications can use this to set their default drop action even when
drop-preload is set to FALSE.
See [enter][struct@crate::Gtk::DropTarget#enter].
drop-value-loaded
Emitted when the dropped content is preloaded for the item at @index.
In order for data to be preloaded, drop-preload
must be set to TRUE.
The content must be of one of the types set up via
Sidebar::setup_drop_target().
See [value][struct@crate::Gtk::DropTarget#value].
setup-menu
Emitted when a context menu is opened or closed for @item.
If the menu has been closed, @item will be set to NULL.
It can be used to set up menu actions before showing the menu, for example disable actions not applicable to @item.
Widget
destroy
Signals that all holders of a reference to the widget should release the reference that they hold.
May result in finalization of the widget if all references are released.
This signal is not suitable for saving widget state.
direction-changed
Emitted when the text direction of a widget changes.
hide
Emitted when @widget is hidden.
keynav-failed
Emitted if keyboard navigation fails.
See [WidgetExtManual::keynav_failed()][crate::gtk::prelude::WidgetExtManual::keynav_failed()] for details.
map
Emitted when @widget is going to be mapped.
A widget is mapped when the widget is visible (which is controlled with
visible) and all its parents up to the toplevel widget
are also visible.
The ::map signal can be used to determine whether a widget will be drawn,
for instance it can resume an animation that was stopped during the
emission of unmap.
mnemonic-activate
Emitted when a widget is activated via a mnemonic.
The default handler for this signal activates @widget if @group_cycling is false, or just makes @widget grab focus if @group_cycling is true.
move-focus
Emitted when the focus is moved.
The ::move-focus signal is a keybinding signal.
The default bindings for this signal are Tab to move forward, and Shift+Tab to move backward.
Action
query-tooltip
Emitted when the widget’s tooltip is about to be shown.
This happens when the has-tooltip property
is true and the hover timeout has expired with the cursor hovering
above @widget; or emitted when @widget got focus in keyboard mode.
Using the given coordinates, the signal handler should determine whether a tooltip should be shown for @widget. If this is the case true should be returned, false otherwise. Note that if @keyboard_mode is true, the values of @x and @y are undefined and should not be used.
The signal handler is free to manipulate @tooltip with the therefore destined function calls.
realize
Emitted when @widget is associated with a GdkSurface.
This means that [WidgetExtManual::realize()][crate::gtk::prelude::WidgetExtManual::realize()] has been called
or the widget has been mapped (that is, it is going to be drawn).
show
Emitted when @widget is shown.
state-flags-changed
Emitted when the widget state changes.
See [WidgetExtManual::state_flags()][crate::gtk::prelude::WidgetExtManual::state_flags()].
unmap
Emitted when @widget is going to be unmapped.
A widget is unmapped when either it or any of its parents up to the toplevel widget have been set as hidden.
As ::unmap indicates that a widget will not be shown any longer,
it can be used to, for example, stop an animation on the widget.
unrealize
Emitted when the GdkSurface associated with @widget is destroyed.
This means that [WidgetExtManual::unrealize()][crate::gtk::prelude::WidgetExtManual::unrealize()] has been called
or the widget has been unmapped (that is, it is going to be hidden).
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Sidebar
impl Sidebar
Sourcepub fn builder() -> SidebarBuilder
pub fn builder() -> SidebarBuilder
Creates a new builder-pattern struct instance to construct Sidebar objects.
This method returns an instance of SidebarBuilder which can be used to create Sidebar objects.
Sourcepub fn append(&self, section: SidebarSection)
pub fn append(&self, section: SidebarSection)
Sourcepub fn is_drop_preload(&self) -> bool
pub fn is_drop_preload(&self) -> bool
Gets whether drop data should be preloaded on hover.
Returns
whether drop data should be preloaded on hover
Sourcepub fn item(&self, index: u32) -> Option<SidebarItem>
pub fn item(&self, index: u32) -> Option<SidebarItem>
Gets the item at @index within @self.
The index starts from 0 at the top of the sidebar, and is same as the one
returned by SidebarItemExt::index().
Can return NULL if @index is larger or equal to the number of items.
index
index of the item
Returns
the item at @index
Sourcepub fn items(&self) -> SelectionModel
pub fn items(&self) -> SelectionModel
Gets a list model with @self’s items.
This can be used to keep an up-to-date view.
The model implements Gtk::SectionModel and creates sections
corresponding to the sidebar’s sections.
The model also implements gtk::SelectionModel and can be used to
track and change the selection.
To only track sections, use sections instead.
Returns
a model containing the items
Sourcepub fn mode(&self) -> SidebarMode
pub fn mode(&self) -> SidebarMode
Sourcepub fn placeholder(&self) -> Option<Widget>
pub fn placeholder(&self) -> Option<Widget>
Sourcepub fn section(&self, index: u32) -> Option<SidebarSection>
pub fn section(&self, index: u32) -> Option<SidebarSection>
Sourcepub fn selected(&self) -> u32
pub fn selected(&self) -> u32
Gets the index of the currently selected item.
See also: selected_item().
Returns
index of the currently selected item
Sourcepub fn selected_item(&self) -> Option<SidebarItem>
pub fn selected_item(&self) -> Option<SidebarItem>
Gets the currently selected item.
This is a convenience method, equivalent to calling item()
with selected provided as the index.
To change selection, use set_selected().
Returns
the selected item
Sourcepub fn insert(&self, section: SidebarSection, position: i32)
pub fn insert(&self, section: SidebarSection, position: i32)
Sourcepub fn prepend(&self, section: SidebarSection)
pub fn prepend(&self, section: SidebarSection)
Sourcepub fn remove(&self, section: &SidebarSection)
pub fn remove(&self, section: &SidebarSection)
Sourcepub fn remove_all(&self)
pub fn remove_all(&self)
Removes all sections from @self.
Sourcepub fn set_drop_preload(&self, preload: bool)
pub fn set_drop_preload(&self, preload: bool)
Sets whether drop data should be preloaded on hover.
See [preload][struct@crate::Gtk::DropTarget#preload].
preload
whether to preload drop data
Sourcepub fn set_filter(&self, filter: Option<&impl IsA<Filter>>)
pub fn set_filter(&self, filter: Option<&impl IsA<Filter>>)
Sets the item filter for @self.
Can be used to implement search within the sidebar.
Use placeholder to provide an empty state.
filter
the item filter
Sets the context menu model for @self’s items.
When a context menu is shown for an item, it will be constructed from the
provided menu model. Use the setup-menu signal to set up
the menu actions for the particular item.
menu_model
a menu model
Sourcepub fn set_mode(&self, mode: SidebarMode)
pub fn set_mode(&self, mode: SidebarMode)
Sets @self’s look and behavior.
If set to [enum@Adw.SidebarMode.SIDEBAR], behaves like a sidebar: with a sidebar style and a persistent selection.
If set to [enum@Adw.SidebarMode.PAGE], behaves like a page of boxed lists. In this mode, the selection is invisible and only tracked to determine the initially selected item once switched back to sidebar mode.
The page mode is intended to be used with NavigationSplitView when
collapsed, as the sidebar pane becomes a page there.
When used with OverlaySplitView, the sidebar should stay in sidebar
mode, as the sidebar pane is still a sidebar when collapsed.
mode
the new mode
Sourcepub fn set_placeholder(&self, placeholder: Option<&impl IsA<Widget>>)
pub fn set_placeholder(&self, placeholder: Option<&impl IsA<Widget>>)
Sourcepub fn set_selected(&self, selected: u32)
pub fn set_selected(&self, selected: u32)
Selects the item at @selected.
If set to Gtk::INVALID_LIST_POSITION, no item is selected.
If mode is set to [enum@Adw.SidebarMode.PAGE], the
selection is invisible, but still tracked, indicating which item will be
selected once the mode is changed to [enum@Adw.SidebarMode.SIDEBAR].
See also: selected-item.
selected
index of the newly selected item
Sourcepub fn connect_activated<F: Fn(&Self, u32) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_activated<F: Fn(&Self, u32) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourcepub fn connect_drop<F: Fn(&Self, u32, &Value, DragAction) -> bool + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop<F: Fn(&Self, u32, &Value, DragAction) -> bool + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when content is dropped onto the item at @index.
The content must be of one of the types set up via
setup_drop_target().
See [drop][struct@crate::Gtk::DropTarget#drop].
index
index of the item the content was dropped onto
value
the GValue being dropped
preferred_action
the preferred drop action
Returns
whether the drop was accepted
SinceL 1.9
Sourcepub fn connect_drop_enter<F: Fn(&Self, u32) -> DragAction + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop_enter<F: Fn(&Self, u32) -> DragAction + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the pointer enters the item at @index.
Applications can use this to set their default drop action even when
drop-preload is set to FALSE.
See [enter][struct@crate::Gtk::DropTarget#enter].
index
index of the hovered item
Returns
the preferred action for the drop
Sourcepub fn connect_drop_value_loaded<F: Fn(&Self, u32, &Value) -> DragAction + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_drop_value_loaded<F: Fn(&Self, u32, &Value) -> DragAction + 'static>( &self, f: F, ) -> SignalHandlerId
Emitted when the dropped content is preloaded for the item at @index.
In order for data to be preloaded, drop-preload
must be set to TRUE.
The content must be of one of the types set up via
setup_drop_target().
See [value][struct@crate::Gtk::DropTarget#value].
index
index of the hovered item
value
the GValue being dropped
Returns
the preferred action for the drop
Emitted when a context menu is opened or closed for @item.
If the menu has been closed, @item will be set to NULL.
It can be used to set up menu actions before showing the menu, for example disable actions not applicable to @item.
item
an item in @self_
pub fn connect_drop_preload_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_filter_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_items_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_mode_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_placeholder_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_sections_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_selected_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_selected_item_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Sourceimpl Sidebar
impl Sidebar
Sourcepub fn setup_drop_target(&self, actions: DragAction, types: &[Type])
pub fn setup_drop_target(&self, actions: DragAction, types: &[Type])