pub struct ViewStack { /* private fields */ }Expand description
A view container for ViewSwitcher.
ViewStack is a container which only shows one page at a time.
It is typically used to hold an application’s main views.
It doesn’t provide a way to transition between pages.
Instead, a separate widget such as ViewSwitcher,
InlineViewSwitcher or ViewSwitcherSidebar can be used with
ViewStack to provide this functionality.
ViewStack pages can have a title, an icon, an attention request, and a
numbered badge that ViewSwitcher will use to let users identify which
page is which. Set them using the title,
icon-name,
needs-attention, and
badge-number properties.
ViewStack pages can also be grouped into sections, using the
starts-section and
section-title properties. Currently, only
ViewSwitcherSidebar displays groups.
Unlike gtk::Stack, transitions between views can only be animated via
a crossfade and size changes are always interpolated. Animations are disabled
by default. Use enable-transitions to enable them.
ViewStack maintains a ViewStackPage object for each added child,
which holds additional per-child properties. You obtain the
ViewStackPage for a child with page() and you
can obtain a gtk::SelectionModel containing all the pages with
pages().
AdwViewStack as GtkBuildable
To set child-specific properties in a .ui file, create
ViewStackPage objects explicitly, and set the child widget as a
property on it:
<object class="AdwViewStack" id="stack">
<child>
<object class="AdwViewStackPage">
<property name="name">overview</property>
<property name="title">Overview</property>
<property name="child">
<object class="AdwStatusPage">
<property name="title">Welcome!</property>
</object>
</property>
</object>
</child>
</object>CSS nodes
ViewStack has a single CSS node named stack.
Accessibility
ViewStack uses the GTK_ACCESSIBLE_ROLE_TAB_PANEL for the stack pages
which are the accessible parent objects of the child widgets.
Properties
enable-transitions
Whether the stack uses a crossfade transition between pages.
Use transition-duration to control the duration, and
transition-running to know when the transition is
running.
Readable | Writeable
hhomogeneous
Whether the stack is horizontally homogeneous.
If the stack is horizontally homogeneous, it allocates the same width for all children.
If it’s FALSE, the stack may change width when a different child becomes
visible.
Readable | Writeable
pages
A selection model with the stack’s pages.
This can be used to keep an up-to-date view.
The model implements Gtk::SectionModel and creates sections based on
starts-section values.
The model also implements gtk::SelectionModel and can be used to
track and change the visible page.
Readable
transition-duration
The transition animation duration, in milliseconds.
Only used when enable-transitions is set to TRUE.
Readable | Writeable
transition-running
Whether a transition is currently running.
If a transition is impossible, the property value will be set to TRUE and
then immediately to FALSE, so it’s possible to rely on its notifications
to know that a transition has happened.
Readable
vhomogeneous
Whether the stack is vertically homogeneous.
If the stack is vertically homogeneous, it allocates the same height for all children.
If it’s FALSE, the stack may change height when a different child becomes
visible.
Readable | Writeable
visible-child
The widget currently visible in the stack.
Readable | Writeable
visible-child-name
The name of the widget currently visible in the stack.
See visible-child.
Readable | Writeable
Widget
can-focus
Whether the widget or any of its descendents can accept the input focus.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
can-target
Whether the widget can receive pointer events.
Readable | Writeable
css-classes
A list of css classes applied to this widget.
Readable | Writeable
css-name
The name of this widget in the CSS tree.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable | Construct Only
cursor
The cursor used by @widget.
Readable | Writeable
focus-on-click
Whether the widget should grab focus when it is clicked with the mouse.
This property is only relevant for widgets that can take focus.
Readable | Writeable
focusable
Whether this widget itself will accept the input focus.
Readable | Writeable
halign
How to distribute horizontal space if widget gets extra space.
Readable | Writeable
has-default
Whether the widget is the default widget.
Readable
has-focus
Whether the widget has the input focus.
Readable
has-tooltip
Enables or disables the emission of the query-tooltip
signal on @widget.
A true value indicates that @widget can have a tooltip, in this case
the widget will be queried using query-tooltip to
determine whether it will provide a tooltip or not.
Readable | Writeable
height-request
Overrides for height request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
hexpand
Whether to expand horizontally.
Readable | Writeable
hexpand-set
Whether to use the hexpand property.
Readable | Writeable
layout-manager
The gtk::LayoutManager instance to use to compute
the preferred size of the widget, and allocate its children.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
limit-events
Makes this widget act like a modal dialog, with respect to event delivery.
Global event controllers will not handle events with targets
inside the widget, unless they are set up to ignore propagation
limits. See Gtk::EventController::set_propagation_limit().
Readable | Writeable
margin-bottom
Margin on bottom side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-end
Margin on end of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-start
Margin on start of widget, horizontally.
This property supports left-to-right and right-to-left text directions.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
margin-top
Margin on top side of widget.
This property adds margin outside of the widget’s normal size
request, the margin will be added in addition to the size from
[WidgetExtManual::set_size_request()][crate::gtk::prelude::WidgetExtManual::set_size_request()] for example.
Readable | Writeable
name
The name of the widget.
Readable | Writeable
opacity
The requested opacity of the widget.
Readable | Writeable
overflow
How content outside the widget’s content area is treated.
This property is meant to be set by widget implementations, typically in their instance init function.
Readable | Writeable
parent
The parent widget of this widget.
Readable
receives-default
Whether the widget will receive the default action when it is focused.
Readable | Writeable
root
The gtk::Root widget of the widget tree containing this widget.
This will be NULL if the widget is not contained in a root widget.
Readable
scale-factor
The scale factor of the widget.
Readable
sensitive
Whether the widget responds to input.
Readable | Writeable
tooltip-markup
Sets the text of tooltip to be the given string, which is marked up with Pango markup.
Also see Gtk::Tooltip::set_markup().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
tooltip-text
Sets the text of tooltip to be the given string.
Also see Gtk::Tooltip::set_text().
This is a convenience property which will take care of getting the
tooltip shown if the given string is not NULL:
has-tooltip will automatically be set to true
and there will be taken care of query-tooltip in
the default signal handler.
Note that if both tooltip-text and
tooltip-markup are set, the last one wins.
Readable | Writeable
valign
How to distribute vertical space if widget gets extra space.
Readable | Writeable
vexpand
Whether to expand vertically.
Readable | Writeable
vexpand-set
Whether to use the vexpand property.
Readable | Writeable
visible
Whether the widget is visible.
Readable | Writeable
width-request
Overrides for width request of the widget.
If this is -1, the natural request will be used.
Readable | Writeable
Accessible
accessible-role
The accessible role of the given gtk::Accessible implementation.
The accessible role cannot be changed once set.
Readable | Writeable
Implements
gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl ViewStack
impl ViewStack
Sourcepub fn builder() -> ViewStackBuilder
pub fn builder() -> ViewStackBuilder
Creates a new builder-pattern struct instance to construct ViewStack objects.
This method returns an instance of ViewStackBuilder which can be used to create ViewStack objects.
Sourcepub fn add(&self, child: &impl IsA<Widget>) -> ViewStackPage
pub fn add(&self, child: &impl IsA<Widget>) -> ViewStackPage
Sourcepub fn add_named(
&self,
child: &impl IsA<Widget>,
name: Option<&str>,
) -> ViewStackPage
pub fn add_named( &self, child: &impl IsA<Widget>, name: Option<&str>, ) -> ViewStackPage
Adds a child to @self.
The child is identified by the @name.
child
the widget to add
name
the name for @child
Returns
the ViewStackPage for @child
Sourcepub fn add_titled(
&self,
child: &impl IsA<Widget>,
name: Option<&str>,
title: &str,
) -> ViewStackPage
pub fn add_titled( &self, child: &impl IsA<Widget>, name: Option<&str>, title: &str, ) -> ViewStackPage
Adds a child to @self.
The child is identified by the @name. The @title will be used by
ViewSwitcher to represent @child, so it should be short.
child
the widget to add
name
the name for @child
title
a human-readable title for @child
Returns
the ViewStackPage for @child
Sourcepub fn add_titled_with_icon(
&self,
child: &impl IsA<Widget>,
name: Option<&str>,
title: &str,
icon_name: &str,
) -> ViewStackPage
Available on crate feature v1_2 only.
pub fn add_titled_with_icon( &self, child: &impl IsA<Widget>, name: Option<&str>, title: &str, icon_name: &str, ) -> ViewStackPage
v1_2 only.Adds a child to @self.
The child is identified by the @name. The @title and @icon_name will be used
by ViewSwitcher to represent @child.
child
the widget to add
name
the name for @child
title
a human-readable title for @child
icon_name
an icon name for @child
Returns
the ViewStackPage for @child
Sourcepub fn child_by_name(&self, name: &str) -> Option<Widget>
pub fn child_by_name(&self, name: &str) -> Option<Widget>
Sourcepub fn enables_transitions(&self) -> bool
Available on crate feature v1_7 only.
pub fn enables_transitions(&self) -> bool
v1_7 only.Gets whether @self uses a crossfade transition between pages.
Use transition-duration to control the duration, and
transition-running to know when the transition is
running.
Returns
whether to enable page transitions
Sourcepub fn is_hhomogeneous(&self) -> bool
pub fn is_hhomogeneous(&self) -> bool
Sourcepub fn page(&self, child: &impl IsA<Widget>) -> ViewStackPage
pub fn page(&self, child: &impl IsA<Widget>) -> ViewStackPage
Gets the ViewStackPage object for @child.
child
a child of @self
Returns
the page object for @child
Sourcepub fn pages(&self) -> SelectionModel
pub fn pages(&self) -> SelectionModel
Returns a gio::ListModel that contains the pages of the stack.
This can be used to keep an up-to-date view.
The model implements Gtk::SectionModel and creates sections based on
starts-section values.
The model also implements gtk::SelectionModel and can be used to track
and change the visible page.
Returns
a gtk::SelectionModel for the stack’s children
Sourcepub fn transition_duration(&self) -> u32
Available on crate feature v1_7 only.
pub fn transition_duration(&self) -> u32
v1_7 only.Sourcepub fn is_transition_running(&self) -> bool
Available on crate feature v1_7 only.
pub fn is_transition_running(&self) -> bool
v1_7 only.Gets whether a transition is currently running for @self.
If a transition is impossible, the property value will be set to TRUE and
then immediately to FALSE, so it’s possible to rely on its notifications
to know that a transition has happened.
Returns
whether a transition is currently running
Sourcepub fn is_vhomogeneous(&self) -> bool
pub fn is_vhomogeneous(&self) -> bool
Sourcepub fn visible_child(&self) -> Option<Widget>
pub fn visible_child(&self) -> Option<Widget>
Sourcepub fn visible_child_name(&self) -> Option<GString>
pub fn visible_child_name(&self) -> Option<GString>
Sourcepub fn set_enable_transitions(&self, enable_transitions: bool)
Available on crate feature v1_7 only.
pub fn set_enable_transitions(&self, enable_transitions: bool)
v1_7 only.Sets whether @self uses a crossfade transition between pages.
enable_transitions
whether to enable page transitions
Sourcepub fn set_hhomogeneous(&self, hhomogeneous: bool)
pub fn set_hhomogeneous(&self, hhomogeneous: bool)
Sets @self to be horizontally homogeneous or not.
If the stack is horizontally homogeneous, it allocates the same width for all children.
If it’s FALSE, the stack may change width when a different child becomes
visible.
hhomogeneous
whether to make @self horizontally homogeneous
Sourcepub fn set_transition_duration(&self, duration: u32)
Available on crate feature v1_7 only.
pub fn set_transition_duration(&self, duration: u32)
v1_7 only.Sets the transition animation duration for @self.
Only used when enable-transitions is set to TRUE.
duration
the new duration, in milliseconds
Sourcepub fn set_vhomogeneous(&self, vhomogeneous: bool)
pub fn set_vhomogeneous(&self, vhomogeneous: bool)
Sets @self to be vertically homogeneous or not.
If the stack is vertically homogeneous, it allocates the same height for all children.
If it’s FALSE, the stack may change height when a different child becomes
visible.
vhomogeneous
whether to make @self vertically homogeneous
Sourcepub fn set_visible_child(&self, child: &impl IsA<Widget>)
pub fn set_visible_child(&self, child: &impl IsA<Widget>)
Sourcepub fn set_visible_child_name(&self, name: &str)
pub fn set_visible_child_name(&self, name: &str)
pub fn connect_enable_transitions_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.pub fn connect_hhomogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_pages_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_transition_duration_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.pub fn connect_transition_running_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
v1_7 only.pub fn connect_vhomogeneous_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_visible_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_visible_child_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId